<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'soen: volwassene, volwassene, ligte velkleur, medium-ligte velkleur',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'soen: volwassene, volwassene, ligte velkleur, medium velkleur',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'soen: volwassene, volwassene, ligte velkleur, medium-donker velkleur',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'soen: volwassene, volwassene, ligte velkleur, donker velkleur',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'soen: volwassene, volwassene, medium-ligte velkleur, ligte velkleur',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'soen: volwassene, volwassene, medium-ligte velkleur, medium velkleur',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'soen: volwassene, volwassene, medium-ligte velkleur, medium-donker velkleur',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'soen: volwassene, volwassene, medium-ligte velkleur, donker velkleur',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'soen: volwassene, volwassene, medium velkleur, ligte velkleur',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'soen: volwassene, volwassene, medium velkleur, medium-ligte velkleur',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'soen: volwassene, volwassene, medium velkleur, medium-donker velkleur',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'soen: volwassene, volwassene, medium velkleur, donker velkleur',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'soen: volwassene, volwassene, medium-donker velkleur, ligte velkleur',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'soen: volwassene, volwassene, medium-donker velkleur, medium-ligte velkleur',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'soen: volwassene, volwassene, medium-donker velkleur, medium velkleur',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'soen: volwassene, volwassene, medium-donker velkleur, donker velkleur',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'soen: volwassene, volwassene, donker velkleur, ligte velkleur',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'soen: volwassene, volwassene, donker velkleur, medium-ligte velkleur',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'soen: volwassene, volwassene, donker velkleur, medium velkleur',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'soen: volwassene, volwassene, donker velkleur, medium-donker velkleur',
    '👨🏻‍❤‍💋‍👨🏻' => 'soen: man, man, ligte velkleur',
    '👨🏻‍❤‍💋‍👨🏼' => 'soen: man, man, ligte velkleur, medium-ligte velkleur',
    '👨🏻‍❤‍💋‍👨🏽' => 'soen: man, man, ligte velkleur, medium velkleur',
    '👨🏻‍❤‍💋‍👨🏾' => 'soen: man, man, ligte velkleur, medium-donker velkleur',
    '👨🏻‍❤‍💋‍👨🏿' => 'soen: man, man, ligte velkleur, donker velkleur',
    '👨🏼‍❤‍💋‍👨🏻' => 'soen: man, man, medium-ligte velkleur, ligte velkleur',
    '👨🏼‍❤‍💋‍👨🏼' => 'soen: man, man, medium-ligte velkleur',
    '👨🏼‍❤‍💋‍👨🏽' => 'soen: man, man, medium-ligte velkleur, medium velkleur',
    '👨🏼‍❤‍💋‍👨🏾' => 'soen: man, man, medium-ligte velkleur, medium-donker velkleur',
    '👨🏼‍❤‍💋‍👨🏿' => 'soen: man, man, medium-ligte velkleur, donker velkleur',
    '👨🏽‍❤‍💋‍👨🏻' => 'soen: man, man, medium velkleur, ligte velkleur',
    '👨🏽‍❤‍💋‍👨🏼' => 'soen: man, man, medium velkleur, medium-ligte velkleur',
    '👨🏽‍❤‍💋‍👨🏽' => 'soen: man, man, medium velkleur',
    '👨🏽‍❤‍💋‍👨🏾' => 'soen: man, man, medium velkleur, medium-donker velkleur',
    '👨🏽‍❤‍💋‍👨🏿' => 'soen: man, man, medium velkleur, donker velkleur',
    '👨🏾‍❤‍💋‍👨🏻' => 'soen: man, man, medium-donker velkleur, ligte velkleur',
    '👨🏾‍❤‍💋‍👨🏼' => 'soen: man, man, medium-donker velkleur, medium-ligte velkleur',
    '👨🏾‍❤‍💋‍👨🏽' => 'soen: man, man, medium-donker velkleur, medium velkleur',
    '👨🏾‍❤‍💋‍👨🏾' => 'soen: man, man, medium-donker velkleur',
    '👨🏾‍❤‍💋‍👨🏿' => 'soen: man, man, medium-donker velkleur, donker velkleur',
    '👨🏿‍❤‍💋‍👨🏻' => 'soen: man, man, donker velkleur, ligte velkleur',
    '👨🏿‍❤‍💋‍👨🏼' => 'soen: man, man, donker velkleur, medium-ligte velkleur',
    '👨🏿‍❤‍💋‍👨🏽' => 'soen: man, man, donker velkleur, medium velkleur',
    '👨🏿‍❤‍💋‍👨🏾' => 'soen: man, man, donker velkleur, medium-donker velkleur',
    '👨🏿‍❤‍💋‍👨🏿' => 'soen: man, man, donker velkleur',
    '👩🏻‍❤‍💋‍👨🏻' => 'soen: vrou, man, ligte velkleur',
    '👩🏻‍❤‍💋‍👨🏼' => 'soen: vrou, man, ligte velkleur, medium-ligte velkleur',
    '👩🏻‍❤‍💋‍👨🏽' => 'soen: vrou, man, ligte velkleur, medium velkleur',
    '👩🏻‍❤‍💋‍👨🏾' => 'soen: vrou, man, ligte velkleur, medium-donker velkleur',
    '👩🏻‍❤‍💋‍👨🏿' => 'soen: vrou, man, ligte velkleur, donker velkleur',
    '👩🏼‍❤‍💋‍👨🏻' => 'soen: vrou, man, medium-ligte velkleur, ligte velkleur',
    '👩🏼‍❤‍💋‍👨🏼' => 'soen: vrou, man, medium-ligte velkleur',
    '👩🏼‍❤‍💋‍👨🏽' => 'soen: vrou, man, medium-ligte velkleur, medium velkleur',
    '👩🏼‍❤‍💋‍👨🏾' => 'soen: vrou, man, medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍❤‍💋‍👨🏿' => 'soen: vrou, man, medium-ligte velkleur, donker velkleur',
    '👩🏽‍❤‍💋‍👨🏻' => 'soen: vrou, man, medium velkleur, ligte velkleur',
    '👩🏽‍❤‍💋‍👨🏼' => 'soen: vrou, man, medium velkleur, medium-ligte velkleur',
    '👩🏽‍❤‍💋‍👨🏽' => 'soen: vrou, man, medium velkleur',
    '👩🏽‍❤‍💋‍👨🏾' => 'soen: vrou, man, medium velkleur, medium-donker velkleur',
    '👩🏽‍❤‍💋‍👨🏿' => 'soen: vrou, man, medium velkleur, donker velkleur',
    '👩🏾‍❤‍💋‍👨🏻' => 'soen: vrou, man, medium-donker velkleur, ligte velkleur',
    '👩🏾‍❤‍💋‍👨🏼' => 'soen: vrou, man, medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍❤‍💋‍👨🏽' => 'soen: vrou, man, medium-donker velkleur, medium velkleur',
    '👩🏾‍❤‍💋‍👨🏾' => 'soen: vrou, man, medium-donker velkleur',
    '👩🏾‍❤‍💋‍👨🏿' => 'soen: vrou, man, medium-donker velkleur, donker velkleur',
    '👩🏿‍❤‍💋‍👨🏻' => 'soen: vrou, man, donker velkleur, ligte velkleur',
    '👩🏿‍❤‍💋‍👨🏼' => 'soen: vrou, man, donker velkleur, medium-ligte velkleur',
    '👩🏿‍❤‍💋‍👨🏽' => 'soen: vrou, man, donker velkleur, medium velkleur',
    '👩🏿‍❤‍💋‍👨🏾' => 'soen: vrou, man, donker velkleur, medium-donker velkleur',
    '👩🏿‍❤‍💋‍👨🏿' => 'soen: vrou, man, donker velkleur',
    '👩🏻‍❤‍💋‍👩🏻' => 'soen: vrou, vrou, ligte velkleur',
    '👩🏻‍❤‍💋‍👩🏼' => 'soen: vrou, vrou, ligte velkleur, medium-ligte velkleur',
    '👩🏻‍❤‍💋‍👩🏽' => 'soen: vrou, vrou, ligte velkleur, medium velkleur',
    '👩🏻‍❤‍💋‍👩🏾' => 'soen: vrou, vrou, ligte velkleur, medium-donker velkleur',
    '👩🏻‍❤‍💋‍👩🏿' => 'soen: vrou, vrou, ligte velkleur, donker velkleur',
    '👩🏼‍❤‍💋‍👩🏻' => 'soen: vrou, vrou, medium-ligte velkleur, ligte velkleur',
    '👩🏼‍❤‍💋‍👩🏼' => 'soen: vrou, vrou, medium-ligte velkleur',
    '👩🏼‍❤‍💋‍👩🏽' => 'soen: vrou, vrou, medium-ligte velkleur, medium velkleur',
    '👩🏼‍❤‍💋‍👩🏾' => 'soen: vrou, vrou, medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍❤‍💋‍👩🏿' => 'soen: vrou, vrou, medium-ligte velkleur, donker velkleur',
    '👩🏽‍❤‍💋‍👩🏻' => 'soen: vrou, vrou, medium velkleur, ligte velkleur',
    '👩🏽‍❤‍💋‍👩🏼' => 'soen: vrou, vrou, medium velkleur, medium-ligte velkleur',
    '👩🏽‍❤‍💋‍👩🏽' => 'soen: vrou, vrou, medium velkleur',
    '👩🏽‍❤‍💋‍👩🏾' => 'soen: vrou, vrou, medium velkleur, medium-donker velkleur',
    '👩🏽‍❤‍💋‍👩🏿' => 'soen: vrou, vrou, medium velkleur, donker velkleur',
    '👩🏾‍❤‍💋‍👩🏻' => 'soen: vrou, vrou, medium-donker velkleur, ligte velkleur',
    '👩🏾‍❤‍💋‍👩🏼' => 'soen: vrou, vrou, medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍❤‍💋‍👩🏽' => 'soen: vrou, vrou, medium-donker velkleur, medium velkleur',
    '👩🏾‍❤‍💋‍👩🏾' => 'soen: vrou, vrou, medium-donker velkleur',
    '👩🏾‍❤‍💋‍👩🏿' => 'soen: vrou, vrou, medium-donker velkleur, donker velkleur',
    '👩🏿‍❤‍💋‍👩🏻' => 'soen: vrou, vrou, donker velkleur, ligte velkleur',
    '👩🏿‍❤‍💋‍👩🏼' => 'soen: vrou, vrou, donker velkleur, medium-ligte velkleur',
    '👩🏿‍❤‍💋‍👩🏽' => 'soen: vrou, vrou, donker velkleur, medium velkleur',
    '👩🏿‍❤‍💋‍👩🏾' => 'soen: vrou, vrou, donker velkleur, medium-donker velkleur',
    '👩🏿‍❤‍💋‍👩🏿' => 'soen: vrou, vrou, donker velkleur',
    '🧑🏻‍🫯‍🧑🏼' => 'stoeiers: ligte velkleur, medium-ligte velkleur',
    '🧑🏻‍🫯‍🧑🏽' => 'stoeiers: ligte velkleur, medium velkleur',
    '🧑🏻‍🫯‍🧑🏾' => 'stoeiers: ligte velkleur, medium-donker velkleur',
    '🧑🏻‍🫯‍🧑🏿' => 'stoeiers: ligte velkleur, donker velkleur',
    '🧑🏼‍🫯‍🧑🏻' => 'stoeiers: medium-ligte velkleur, ligte velkleur',
    '🧑🏼‍🫯‍🧑🏽' => 'stoeiers: medium-ligte velkleur, medium velkleur',
    '🧑🏼‍🫯‍🧑🏾' => 'stoeiers: medium-ligte velkleur, medium-donker velkleur',
    '🧑🏼‍🫯‍🧑🏿' => 'stoeiers: medium-ligte velkleur, donker velkleur',
    '🧑🏽‍🫯‍🧑🏻' => 'stoeiers: medium velkleur, ligte velkleur',
    '🧑🏽‍🫯‍🧑🏼' => 'stoeiers: medium velkleur, medium-ligte velkleur',
    '🧑🏽‍🫯‍🧑🏾' => 'stoeiers: medium velkleur, medium-donker velkleur',
    '🧑🏽‍🫯‍🧑🏿' => 'stoeiers: medium velkleur, donker velkleur',
    '🧑🏾‍🫯‍🧑🏻' => 'stoeiers: medium-donker velkleur, ligte velkleur',
    '🧑🏾‍🫯‍🧑🏼' => 'stoeiers: medium-donker velkleur, medium-ligte velkleur',
    '🧑🏾‍🫯‍🧑🏽' => 'stoeiers: medium-donker velkleur, medium velkleur',
    '🧑🏾‍🫯‍🧑🏿' => 'stoeiers: medium-donker velkleur, donker velkleur',
    '🧑🏿‍🫯‍🧑🏻' => 'stoeiers: donker velkleur, ligte velkleur',
    '🧑🏿‍🫯‍🧑🏼' => 'stoeiers: donker velkleur, medium-ligte velkleur',
    '🧑🏿‍🫯‍🧑🏽' => 'stoeiers: donker velkleur, medium velkleur',
    '🧑🏿‍🫯‍🧑🏾' => 'stoeiers: donker velkleur, medium-donker velkleur',
    '🧑🏻‍❤‍🧑🏼' => 'paartjie met hartjie: volwassene, volwassene, ligte velkleur, medium-ligte velkleur',
    '🧑🏻‍❤‍🧑🏽' => 'paartjie met hartjie: volwassene, volwassene, ligte velkleur, medium velkleur',
    '🧑🏻‍❤‍🧑🏾' => 'paartjie met hartjie: volwassene, volwassene, ligte velkleur, medium-donker velkleur',
    '🧑🏻‍❤‍🧑🏿' => 'paartjie met hartjie: volwassene, volwassene, ligte velkleur, donker velkleur',
    '🧑🏼‍❤‍🧑🏻' => 'paartjie met hartjie: volwassene, volwassene, medium-ligte velkleur, ligte velkleur',
    '🧑🏼‍❤‍🧑🏽' => 'paartjie met hartjie: volwassene, volwassene, medium-ligte velkleur, medium velkleur',
    '🧑🏼‍❤‍🧑🏾' => 'paartjie met hartjie: volwassene, volwassene, medium-ligte velkleur, medium-donker velkleur',
    '🧑🏼‍❤‍🧑🏿' => 'paartjie met hartjie: volwassene, volwassene, medium-ligte velkleur, donker velkleur',
    '🧑🏽‍❤‍🧑🏻' => 'paartjie met hartjie: volwassene, volwassene, medium velkleur, ligte velkleur',
    '🧑🏽‍❤‍🧑🏼' => 'paartjie met hartjie: volwassene, volwassene, medium velkleur, medium-ligte velkleur',
    '🧑🏽‍❤‍🧑🏾' => 'paartjie met hartjie: volwassene, volwassene, medium velkleur, medium-donker velkleur',
    '🧑🏽‍❤‍🧑🏿' => 'paartjie met hartjie: volwassene, volwassene, medium velkleur, donker velkleur',
    '🧑🏾‍❤‍🧑🏻' => 'paartjie met hartjie: volwassene, volwassene, medium-donker velkleur, ligte velkleur',
    '🧑🏾‍❤‍🧑🏼' => 'paartjie met hartjie: volwassene, volwassene, medium-donker velkleur, medium-ligte velkleur',
    '🧑🏾‍❤‍🧑🏽' => 'paartjie met hartjie: volwassene, volwassene, medium-donker velkleur, medium velkleur',
    '🧑🏾‍❤‍🧑🏿' => 'paartjie met hartjie: volwassene, volwassene, medium-donker velkleur, donker velkleur',
    '🧑🏿‍❤‍🧑🏻' => 'paartjie met hartjie: volwassene, volwassene, donker velkleur, ligte velkleur',
    '🧑🏿‍❤‍🧑🏼' => 'paartjie met hartjie: volwassene, volwassene, donker velkleur, medium-ligte velkleur',
    '🧑🏿‍❤‍🧑🏽' => 'paartjie met hartjie: volwassene, volwassene, donker velkleur, medium velkleur',
    '🧑🏿‍❤‍🧑🏾' => 'paartjie met hartjie: volwassene, volwassene, donker velkleur, medium-donker velkleur',
    '🧑🏻‍🐰‍🧑🏼' => 'mense met haasore: ligte velkleur, medium-ligte velkleur',
    '🧑🏻‍🐰‍🧑🏽' => 'mense met haasore: ligte velkleur, medium velkleur',
    '🧑🏻‍🐰‍🧑🏾' => 'mense met haasore: ligte velkleur, medium-donker velkleur',
    '🧑🏻‍🐰‍🧑🏿' => 'mense met haasore: ligte velkleur, donker velkleur',
    '🧑🏼‍🐰‍🧑🏻' => 'mense met haasore: medium-ligte velkleur, ligte velkleur',
    '🧑🏼‍🐰‍🧑🏽' => 'mense met haasore: medium-ligte velkleur, medium velkleur',
    '🧑🏼‍🐰‍🧑🏾' => 'mense met haasore: medium-ligte velkleur, medium-donker velkleur',
    '🧑🏼‍🐰‍🧑🏿' => 'mense met haasore: medium-ligte velkleur, donker velkleur',
    '🧑🏽‍🐰‍🧑🏻' => 'mense met haasore: medium velkleur, ligte velkleur',
    '🧑🏽‍🐰‍🧑🏼' => 'mense met haasore: medium velkleur, medium-ligte velkleur',
    '🧑🏽‍🐰‍🧑🏾' => 'mense met haasore: medium velkleur, medium-donker velkleur',
    '🧑🏽‍🐰‍🧑🏿' => 'mense met haasore: medium velkleur, donker velkleur',
    '🧑🏾‍🐰‍🧑🏻' => 'mense met haasore: medium-donker velkleur, ligte velkleur',
    '🧑🏾‍🐰‍🧑🏼' => 'mense met haasore: medium-donker velkleur, medium-ligte velkleur',
    '🧑🏾‍🐰‍🧑🏽' => 'mense met haasore: medium-donker velkleur, medium velkleur',
    '🧑🏾‍🐰‍🧑🏿' => 'mense met haasore: medium-donker velkleur, donker velkleur',
    '🧑🏿‍🐰‍🧑🏻' => 'mense met haasore: donker velkleur, ligte velkleur',
    '🧑🏿‍🐰‍🧑🏼' => 'mense met haasore: donker velkleur, medium-ligte velkleur',
    '🧑🏿‍🐰‍🧑🏽' => 'mense met haasore: donker velkleur, medium velkleur',
    '🧑🏿‍🐰‍🧑🏾' => 'mense met haasore: donker velkleur, medium-donker velkleur',
    '👨🏻‍🫯‍👨🏼' => 'manlike stoeiers: ligte velkleur, medium-ligte velkleur',
    '👨🏻‍🫯‍👨🏽' => 'manlike stoeiers: ligte velkleur, medium velkleur',
    '👨🏻‍🫯‍👨🏾' => 'manlike stoeiers: ligte velkleur, medium-donker velkleur',
    '👨🏻‍🫯‍👨🏿' => 'manlike stoeiers: ligte velkleur, donker velkleur',
    '👨🏼‍🫯‍👨🏻' => 'manlike stoeiers: medium-ligte velkleur, ligte velkleur',
    '👨🏼‍🫯‍👨🏽' => 'manlike stoeiers: medium-ligte velkleur, medium velkleur',
    '👨🏼‍🫯‍👨🏾' => 'manlike stoeiers: medium-ligte velkleur, medium-donker velkleur',
    '👨🏼‍🫯‍👨🏿' => 'manlike stoeiers: medium-ligte velkleur, donker velkleur',
    '👨🏽‍🫯‍👨🏻' => 'manlike stoeiers: medium velkleur, ligte velkleur',
    '👨🏽‍🫯‍👨🏼' => 'manlike stoeiers: medium velkleur, medium-ligte velkleur',
    '👨🏽‍🫯‍👨🏾' => 'manlike stoeiers: medium velkleur, medium-donker velkleur',
    '👨🏽‍🫯‍👨🏿' => 'manlike stoeiers: medium velkleur, donker velkleur',
    '👨🏾‍🫯‍👨🏻' => 'manlike stoeiers: medium-donker velkleur, ligte velkleur',
    '👨🏾‍🫯‍👨🏼' => 'manlike stoeiers: medium-donker velkleur, medium-ligte velkleur',
    '👨🏾‍🫯‍👨🏽' => 'manlike stoeiers: medium-donker velkleur, medium velkleur',
    '👨🏾‍🫯‍👨🏿' => 'manlike stoeiers: medium-donker velkleur, donker velkleur',
    '👨🏿‍🫯‍👨🏻' => 'manlike stoeiers: donker velkleur, ligte velkleur',
    '👨🏿‍🫯‍👨🏼' => 'manlike stoeiers: donker velkleur, medium-ligte velkleur',
    '👨🏿‍🫯‍👨🏽' => 'manlike stoeiers: donker velkleur, medium velkleur',
    '👨🏿‍🫯‍👨🏾' => 'manlike stoeiers: donker velkleur, medium-donker velkleur',
    '👨🏻‍❤‍👨🏻' => 'paartjie met hartjie: man, man, ligte velkleur',
    '👨🏻‍❤‍👨🏼' => 'paartjie met hartjie: man, man, ligte velkleur, medium-ligte velkleur',
    '👨🏻‍❤‍👨🏽' => 'paartjie met hartjie: man, man, ligte velkleur, medium velkleur',
    '👨🏻‍❤‍👨🏾' => 'paartjie met hartjie: man, man, ligte velkleur, medium-donker velkleur',
    '👨🏻‍❤‍👨🏿' => 'paartjie met hartjie: man, man, ligte velkleur, donker velkleur',
    '👨🏼‍❤‍👨🏻' => 'paartjie met hartjie: man, man, medium-ligte velkleur, ligte velkleur',
    '👨🏼‍❤‍👨🏼' => 'paartjie met hartjie: man, man, medium-ligte velkleur',
    '👨🏼‍❤‍👨🏽' => 'paartjie met hartjie: man, man, medium-ligte velkleur, medium velkleur',
    '👨🏼‍❤‍👨🏾' => 'paartjie met hartjie: man, man, medium-ligte velkleur, medium-donker velkleur',
    '👨🏼‍❤‍👨🏿' => 'paartjie met hartjie: man, man, medium-ligte velkleur, donker velkleur',
    '👨🏽‍❤‍👨🏻' => 'paartjie met hartjie: man, man, medium velkleur, ligte velkleur',
    '👨🏽‍❤‍👨🏼' => 'paartjie met hartjie: man, man, medium velkleur, medium-ligte velkleur',
    '👨🏽‍❤‍👨🏽' => 'paartjie met hartjie: man, man, medium velkleur',
    '👨🏽‍❤‍👨🏾' => 'paartjie met hartjie: man, man, medium velkleur, medium-donker velkleur',
    '👨🏽‍❤‍👨🏿' => 'paartjie met hartjie: man, man, medium velkleur, donker velkleur',
    '👨🏾‍❤‍👨🏻' => 'paartjie met hartjie: man, man, medium-donker velkleur, ligte velkleur',
    '👨🏾‍❤‍👨🏼' => 'paartjie met hartjie: man, man, medium-donker velkleur, medium-ligte velkleur',
    '👨🏾‍❤‍👨🏽' => 'paartjie met hartjie: man, man, medium-donker velkleur, medium velkleur',
    '👨🏾‍❤‍👨🏾' => 'paartjie met hartjie: man, man, medium-donker velkleur',
    '👨🏾‍❤‍👨🏿' => 'paartjie met hartjie: man, man, medium-donker velkleur, donker velkleur',
    '👨🏿‍❤‍👨🏻' => 'paartjie met hartjie: man, man, donker velkleur, ligte velkleur',
    '👨🏿‍❤‍👨🏼' => 'paartjie met hartjie: man, man, donker velkleur, medium-ligte velkleur',
    '👨🏿‍❤‍👨🏽' => 'paartjie met hartjie: man, man, donker velkleur, medium velkleur',
    '👨🏿‍❤‍👨🏾' => 'paartjie met hartjie: man, man, donker velkleur, medium-donker velkleur',
    '👨🏿‍❤‍👨🏿' => 'paartjie met hartjie: man, man, donker velkleur',
    '👨🏻‍🐰‍👨🏼' => 'mans met haasore: ligte velkleur, medium-ligte velkleur',
    '👨🏻‍🐰‍👨🏽' => 'mans met haasore: ligte velkleur, medium velkleur',
    '👨🏻‍🐰‍👨🏾' => 'mans met haasore: ligte velkleur, medium-donker velkleur',
    '👨🏻‍🐰‍👨🏿' => 'mans met haasore: ligte velkleur, donker velkleur',
    '👨🏼‍🐰‍👨🏻' => 'mans met haasore: medium-ligte velkleur, ligte velkleur',
    '👨🏼‍🐰‍👨🏽' => 'mans met haasore: medium-ligte velkleur, medium velkleur',
    '👨🏼‍🐰‍👨🏾' => 'mans met haasore: medium-ligte velkleur, medium-donker velkleur',
    '👨🏼‍🐰‍👨🏿' => 'mans met haasore: medium-ligte velkleur, donker velkleur',
    '👨🏽‍🐰‍👨🏻' => 'mans met haasore: medium velkleur, ligte velkleur',
    '👨🏽‍🐰‍👨🏼' => 'mans met haasore: medium velkleur, medium-ligte velkleur',
    '👨🏽‍🐰‍👨🏾' => 'mans met haasore: medium velkleur, medium-donker velkleur',
    '👨🏽‍🐰‍👨🏿' => 'mans met haasore: medium velkleur, donker velkleur',
    '👨🏾‍🐰‍👨🏻' => 'mans met haasore: medium-donker velkleur, ligte velkleur',
    '👨🏾‍🐰‍👨🏼' => 'mans met haasore: medium-donker velkleur, medium-ligte velkleur',
    '👨🏾‍🐰‍👨🏽' => 'mans met haasore: medium-donker velkleur, medium velkleur',
    '👨🏾‍🐰‍👨🏿' => 'mans met haasore: medium-donker velkleur, donker velkleur',
    '👨🏿‍🐰‍👨🏻' => 'mans met haasore: donker velkleur, ligte velkleur',
    '👨🏿‍🐰‍👨🏼' => 'mans met haasore: donker velkleur, medium-ligte velkleur',
    '👨🏿‍🐰‍👨🏽' => 'mans met haasore: donker velkleur, medium velkleur',
    '👨🏿‍🐰‍👨🏾' => 'mans met haasore: donker velkleur, medium-donker velkleur',
    '👩🏻‍🫯‍👩🏼' => 'vroulike stoeiers: ligte velkleur, medium-ligte velkleur',
    '👩🏻‍🫯‍👩🏽' => 'vroulike stoeiers: ligte velkleur, medium velkleur',
    '👩🏻‍🫯‍👩🏾' => 'vroulike stoeiers: ligte velkleur, medium-donker velkleur',
    '👩🏻‍🫯‍👩🏿' => 'vroulike stoeiers: ligte velkleur, donker velkleur',
    '👩🏼‍🫯‍👩🏻' => 'vroulike stoeiers: medium-ligte velkleur, ligte velkleur',
    '👩🏼‍🫯‍👩🏽' => 'vroulike stoeiers: medium-ligte velkleur, medium velkleur',
    '👩🏼‍🫯‍👩🏾' => 'vroulike stoeiers: medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍🫯‍👩🏿' => 'vroulike stoeiers: medium-ligte velkleur, donker velkleur',
    '👩🏽‍🫯‍👩🏻' => 'vroulike stoeiers: medium velkleur, ligte velkleur',
    '👩🏽‍🫯‍👩🏼' => 'vroulike stoeiers: medium velkleur, medium-ligte velkleur',
    '👩🏽‍🫯‍👩🏾' => 'vroulike stoeiers: medium velkleur, medium-donker velkleur',
    '👩🏽‍🫯‍👩🏿' => 'vroulike stoeiers: medium velkleur, donker velkleur',
    '👩🏾‍🫯‍👩🏻' => 'vroulike stoeiers: medium-donker velkleur, ligte velkleur',
    '👩🏾‍🫯‍👩🏼' => 'vroulike stoeiers: medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍🫯‍👩🏽' => 'vroulike stoeiers: medium-donker velkleur, medium velkleur',
    '👩🏾‍🫯‍👩🏿' => 'vroulike stoeiers: medium-donker velkleur, donker velkleur',
    '👩🏿‍🫯‍👩🏻' => 'vroulike stoeiers: donker velkleur, ligte velkleur',
    '👩🏿‍🫯‍👩🏼' => 'vroulike stoeiers: donker velkleur, medium-ligte velkleur',
    '👩🏿‍🫯‍👩🏽' => 'vroulike stoeiers: donker velkleur, medium velkleur',
    '👩🏿‍🫯‍👩🏾' => 'vroulike stoeiers: donker velkleur, medium-donker velkleur',
    '👩🏻‍❤‍👨🏻' => 'paartjie met hartjie: vrou, man, ligte velkleur',
    '👩🏻‍❤‍👨🏼' => 'paartjie met hartjie: vrou, man, ligte velkleur, medium-ligte velkleur',
    '👩🏻‍❤‍👨🏽' => 'paartjie met hartjie: vrou, man, ligte velkleur, medium velkleur',
    '👩🏻‍❤‍👨🏾' => 'paartjie met hartjie: vrou, man, ligte velkleur, medium-donker velkleur',
    '👩🏻‍❤‍👨🏿' => 'paartjie met hartjie: vrou, man, ligte velkleur, donker velkleur',
    '👩🏼‍❤‍👨🏻' => 'paartjie met hartjie: vrou, man, medium-ligte velkleur, ligte velkleur',
    '👩🏼‍❤‍👨🏼' => 'paartjie met hartjie: vrou, man, medium-ligte velkleur',
    '👩🏼‍❤‍👨🏽' => 'paartjie met hartjie: vrou, man, medium-ligte velkleur, medium velkleur',
    '👩🏼‍❤‍👨🏾' => 'paartjie met hartjie: vrou, man, medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍❤‍👨🏿' => 'paartjie met hartjie: vrou, man, medium-ligte velkleur, donker velkleur',
    '👩🏽‍❤‍👨🏻' => 'paartjie met hartjie: vrou, man, medium velkleur, ligte velkleur',
    '👩🏽‍❤‍👨🏼' => 'paartjie met hartjie: vrou, man, medium velkleur, medium-ligte velkleur',
    '👩🏽‍❤‍👨🏽' => 'paartjie met hartjie: vrou, man, medium velkleur',
    '👩🏽‍❤‍👨🏾' => 'paartjie met hartjie: vrou, man, medium velkleur, medium-donker velkleur',
    '👩🏽‍❤‍👨🏿' => 'paartjie met hartjie: vrou, man, medium velkleur, donker velkleur',
    '👩🏾‍❤‍👨🏻' => 'paartjie met hartjie: vrou, man, medium-donker velkleur, ligte velkleur',
    '👩🏾‍❤‍👨🏼' => 'paartjie met hartjie: vrou, man, medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍❤‍👨🏽' => 'paartjie met hartjie: vrou, man, medium-donker velkleur, medium velkleur',
    '👩🏾‍❤‍👨🏾' => 'paartjie met hartjie: vrou, man, medium-donker velkleur',
    '👩🏾‍❤‍👨🏿' => 'paartjie met hartjie: vrou, man, medium-donker velkleur, donker velkleur',
    '👩🏿‍❤‍👨🏻' => 'paartjie met hartjie: vrou, man, donker velkleur, ligte velkleur',
    '👩🏿‍❤‍👨🏼' => 'paartjie met hartjie: vrou, man, donker velkleur, medium-ligte velkleur',
    '👩🏿‍❤‍👨🏽' => 'paartjie met hartjie: vrou, man, donker velkleur, medium velkleur',
    '👩🏿‍❤‍👨🏾' => 'paartjie met hartjie: vrou, man, donker velkleur, medium-donker velkleur',
    '👩🏿‍❤‍👨🏿' => 'paartjie met hartjie: vrou, man, donker velkleur',
    '👩🏻‍❤‍👩🏻' => 'paartjie met hartjie: vrou, vrou, ligte velkleur',
    '👩🏻‍❤‍👩🏼' => 'paartjie met hartjie: vrou, vrou, ligte velkleur, medium-ligte velkleur',
    '👩🏻‍❤‍👩🏽' => 'paartjie met hartjie: vrou, vrou, ligte velkleur, medium velkleur',
    '👩🏻‍❤‍👩🏾' => 'paartjie met hartjie: vrou, vrou, ligte velkleur, medium-donker velkleur',
    '👩🏻‍❤‍👩🏿' => 'paartjie met hartjie: vrou, vrou, ligte velkleur, donker velkleur',
    '👩🏼‍❤‍👩🏻' => 'paartjie met hartjie: vrou, vrou, medium-ligte velkleur, ligte velkleur',
    '👩🏼‍❤‍👩🏼' => 'paartjie met hartjie: vrou, vrou, medium-ligte velkleur',
    '👩🏼‍❤‍👩🏽' => 'paartjie met hartjie: vrou, vrou, medium-ligte velkleur, medium velkleur',
    '👩🏼‍❤‍👩🏾' => 'paartjie met hartjie: vrou, vrou, medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍❤‍👩🏿' => 'paartjie met hartjie: vrou, vrou, medium-ligte velkleur, donker velkleur',
    '👩🏽‍❤‍👩🏻' => 'paartjie met hartjie: vrou, vrou, medium velkleur, ligte velkleur',
    '👩🏽‍❤‍👩🏼' => 'paartjie met hartjie: vrou, vrou, medium velkleur, medium-ligte velkleur',
    '👩🏽‍❤‍👩🏽' => 'paartjie met hartjie: vrou, vrou, medium velkleur',
    '👩🏽‍❤‍👩🏾' => 'paartjie met hartjie: vrou, vrou, medium velkleur, medium-donker velkleur',
    '👩🏽‍❤‍👩🏿' => 'paartjie met hartjie: vrou, vrou, medium velkleur, donker velkleur',
    '👩🏾‍❤‍👩🏻' => 'paartjie met hartjie: vrou, vrou, medium-donker velkleur, ligte velkleur',
    '👩🏾‍❤‍👩🏼' => 'paartjie met hartjie: vrou, vrou, medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍❤‍👩🏽' => 'paartjie met hartjie: vrou, vrou, medium-donker velkleur, medium velkleur',
    '👩🏾‍❤‍👩🏾' => 'paartjie met hartjie: vrou, vrou, medium-donker velkleur',
    '👩🏾‍❤‍👩🏿' => 'paartjie met hartjie: vrou, vrou, medium-donker velkleur, donker velkleur',
    '👩🏿‍❤‍👩🏻' => 'paartjie met hartjie: vrou, vrou, donker velkleur, ligte velkleur',
    '👩🏿‍❤‍👩🏼' => 'paartjie met hartjie: vrou, vrou, donker velkleur, medium-ligte velkleur',
    '👩🏿‍❤‍👩🏽' => 'paartjie met hartjie: vrou, vrou, donker velkleur, medium velkleur',
    '👩🏿‍❤‍👩🏾' => 'paartjie met hartjie: vrou, vrou, donker velkleur, medium-donker velkleur',
    '👩🏿‍❤‍👩🏿' => 'paartjie met hartjie: vrou, vrou, donker velkleur',
    '👩🏻‍🐰‍👩🏼' => 'vroue met haasore: ligte velkleur, medium-ligte velkleur',
    '👩🏻‍🐰‍👩🏽' => 'vroue met haasore: ligte velkleur, medium velkleur',
    '👩🏻‍🐰‍👩🏾' => 'vroue met haasore: ligte velkleur, medium-donker velkleur',
    '👩🏻‍🐰‍👩🏿' => 'vroue met haasore: ligte velkleur, donker velkleur',
    '👩🏼‍🐰‍👩🏻' => 'vroue met haasore: medium-ligte velkleur, ligte velkleur',
    '👩🏼‍🐰‍👩🏽' => 'vroue met haasore: medium-ligte velkleur, medium velkleur',
    '👩🏼‍🐰‍👩🏾' => 'vroue met haasore: medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍🐰‍👩🏿' => 'vroue met haasore: medium-ligte velkleur, donker velkleur',
    '👩🏽‍🐰‍👩🏻' => 'vroue met haasore: medium velkleur, ligte velkleur',
    '👩🏽‍🐰‍👩🏼' => 'vroue met haasore: medium velkleur, medium-ligte velkleur',
    '👩🏽‍🐰‍👩🏾' => 'vroue met haasore: medium velkleur, medium-donker velkleur',
    '👩🏽‍🐰‍👩🏿' => 'vroue met haasore: medium velkleur, donker velkleur',
    '👩🏾‍🐰‍👩🏻' => 'vroue met haasore: medium-donker velkleur, ligte velkleur',
    '👩🏾‍🐰‍👩🏼' => 'vroue met haasore: medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍🐰‍👩🏽' => 'vroue met haasore: medium-donker velkleur, medium velkleur',
    '👩🏾‍🐰‍👩🏿' => 'vroue met haasore: medium-donker velkleur, donker velkleur',
    '👩🏿‍🐰‍👩🏻' => 'vroue met haasore: donker velkleur, ligte velkleur',
    '👩🏿‍🐰‍👩🏼' => 'vroue met haasore: donker velkleur, medium-ligte velkleur',
    '👩🏿‍🐰‍👩🏽' => 'vroue met haasore: donker velkleur, medium velkleur',
    '👩🏿‍🐰‍👩🏾' => 'vroue met haasore: donker velkleur, medium-donker velkleur',
    '🧑🏻‍🤝‍🧑🏻' => 'mense wat hande vashou: ligte velkleur',
    '🧑🏻‍🤝‍🧑🏼' => 'mense wat hande vashou: ligte velkleur, medium-ligte velkleur',
    '🧑🏻‍🤝‍🧑🏽' => 'mense wat hande vashou: ligte velkleur, medium velkleur',
    '🧑🏻‍🤝‍🧑🏾' => 'mense wat hande vashou: ligte velkleur, medium-donker velkleur',
    '🧑🏻‍🤝‍🧑🏿' => 'mense wat hande vashou: ligte velkleur, donker velkleur',
    '🧑🏼‍🤝‍🧑🏻' => 'mense wat hande vashou: medium-ligte velkleur, ligte velkleur',
    '🧑🏼‍🤝‍🧑🏼' => 'mense wat hande vashou: medium-ligte velkleur',
    '🧑🏼‍🤝‍🧑🏽' => 'mense wat hande vashou: medium-ligte velkleur, medium velkleur',
    '🧑🏼‍🤝‍🧑🏾' => 'mense wat hande vashou: medium-ligte velkleur, medium-donker velkleur',
    '🧑🏼‍🤝‍🧑🏿' => 'mense wat hande vashou: medium-ligte velkleur, donker velkleur',
    '🧑🏽‍🤝‍🧑🏻' => 'mense wat hande vashou: medium velkleur, ligte velkleur',
    '🧑🏽‍🤝‍🧑🏼' => 'mense wat hande vashou: medium velkleur, medium-ligte velkleur',
    '🧑🏽‍🤝‍🧑🏽' => 'mense wat hande vashou: medium velkleur',
    '🧑🏽‍🤝‍🧑🏾' => 'mense wat hande vashou: medium velkleur, medium-donker velkleur',
    '🧑🏽‍🤝‍🧑🏿' => 'mense wat hande vashou: medium velkleur, donker velkleur',
    '🧑🏾‍🤝‍🧑🏻' => 'mense wat hande vashou: medium-donker velkleur, ligte velkleur',
    '🧑🏾‍🤝‍🧑🏼' => 'mense wat hande vashou: medium-donker velkleur, medium-ligte velkleur',
    '🧑🏾‍🤝‍🧑🏽' => 'mense wat hande vashou: medium-donker velkleur, medium velkleur',
    '🧑🏾‍🤝‍🧑🏾' => 'mense wat hande vashou: medium-donker velkleur',
    '🧑🏾‍🤝‍🧑🏿' => 'mense wat hande vashou: medium-donker velkleur, donker velkleur',
    '🧑🏿‍🤝‍🧑🏻' => 'mense wat hande vashou: donker velkleur, ligte velkleur',
    '🧑🏿‍🤝‍🧑🏼' => 'mense wat hande vashou: donker velkleur, medium-ligte velkleur',
    '🧑🏿‍🤝‍🧑🏽' => 'mense wat hande vashou: donker velkleur, medium velkleur',
    '🧑🏿‍🤝‍🧑🏾' => 'mense wat hande vashou: donker velkleur, medium-donker velkleur',
    '🧑🏿‍🤝‍🧑🏿' => 'mense wat hande vashou: donker velkleur',
    '👩🏻‍🤝‍👩🏼' => 'twee vroue wat hande vashou: ligte velkleur, medium-ligte velkleur',
    '👩🏻‍🤝‍👩🏽' => 'twee vroue wat hande vashou: ligte velkleur, medium velkleur',
    '👩🏻‍🤝‍👩🏾' => 'twee vroue wat hande vashou: ligte velkleur, medium-donker velkleur',
    '👩🏻‍🤝‍👩🏿' => 'twee vroue wat hande vashou: ligte velkleur, donker velkleur',
    '👩🏼‍🤝‍👩🏻' => 'twee vroue wat hande vashou: medium-ligte velkleur, ligte velkleur',
    '👩🏼‍🤝‍👩🏽' => 'twee vroue wat hande vashou: medium-ligte velkleur, medium velkleur',
    '👩🏼‍🤝‍👩🏾' => 'twee vroue wat hande vashou: medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍🤝‍👩🏿' => 'twee vroue wat hande vashou: medium-ligte velkleur, donker velkleur',
    '👩🏽‍🤝‍👩🏻' => 'twee vroue wat hande vashou: medium velkleur, ligte velkleur',
    '👩🏽‍🤝‍👩🏼' => 'twee vroue wat hande vashou: medium velkleur, medium-ligte velkleur',
    '👩🏽‍🤝‍👩🏾' => 'twee vroue wat hande vashou: medium velkleur, medium-donker velkleur',
    '👩🏽‍🤝‍👩🏿' => 'twee vroue wat hande vashou: medium velkleur, donker velkleur',
    '👩🏾‍🤝‍👩🏻' => 'twee vroue wat hande vashou: medium-donker velkleur, ligte velkleur',
    '👩🏾‍🤝‍👩🏼' => 'twee vroue wat hande vashou: medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍🤝‍👩🏽' => 'twee vroue wat hande vashou: medium-donker velkleur, medium velkleur',
    '👩🏾‍🤝‍👩🏿' => 'twee vroue wat hande vashou: medium-donker velkleur, donker velkleur',
    '👩🏿‍🤝‍👩🏻' => 'twee vroue wat hande vashou: donker velkleur, ligte velkleur',
    '👩🏿‍🤝‍👩🏼' => 'twee vroue wat hande vashou: donker velkleur, medium-ligte velkleur',
    '👩🏿‍🤝‍👩🏽' => 'twee vroue wat hande vashou: donker velkleur, medium velkleur',
    '👩🏿‍🤝‍👩🏾' => 'twee vroue wat hande vashou: donker velkleur, medium-donker velkleur',
    '👩🏻‍🤝‍👨🏼' => 'man en vrou wat hande vashou: ligte velkleur, medium-ligte velkleur',
    '👩🏻‍🤝‍👨🏽' => 'man en vrou wat hande vashou: ligte velkleur, medium velkleur',
    '👩🏻‍🤝‍👨🏾' => 'man en vrou wat hande vashou: ligte velkleur, medium-donker velkleur',
    '👩🏻‍🤝‍👨🏿' => 'man en vrou wat hande vashou: ligte velkleur, donker velkleur',
    '👩🏼‍🤝‍👨🏻' => 'man en vrou wat hande vashou: medium-ligte velkleur, ligte velkleur',
    '👩🏼‍🤝‍👨🏽' => 'man en vrou wat hande vashou: medium-ligte velkleur, medium velkleur',
    '👩🏼‍🤝‍👨🏾' => 'man en vrou wat hande vashou: medium-ligte velkleur, medium-donker velkleur',
    '👩🏼‍🤝‍👨🏿' => 'man en vrou wat hande vashou: medium-ligte velkleur, donker velkleur',
    '👩🏽‍🤝‍👨🏻' => 'man en vrou wat hande vashou: medium velkleur, ligte velkleur',
    '👩🏽‍🤝‍👨🏼' => 'man en vrou wat hande vashou: medium velkleur, medium-ligte velkleur',
    '👩🏽‍🤝‍👨🏾' => 'man en vrou wat hande vashou: medium velkleur, medium-donker velkleur',
    '👩🏽‍🤝‍👨🏿' => 'man en vrou wat hande vashou: medium velkleur, donker velkleur',
    '👩🏾‍🤝‍👨🏻' => 'man en vrou wat hande vashou: medium-donker velkleur, ligte velkleur',
    '👩🏾‍🤝‍👨🏼' => 'man en vrou wat hande vashou: medium-donker velkleur, medium-ligte velkleur',
    '👩🏾‍🤝‍👨🏽' => 'man en vrou wat hande vashou: medium-donker velkleur, medium velkleur',
    '👩🏾‍🤝‍👨🏿' => 'man en vrou wat hande vashou: medium-donker velkleur, donker velkleur',
    '👩🏿‍🤝‍👨🏻' => 'man en vrou wat hande vashou: donker velkleur, ligte velkleur',
    '👩🏿‍🤝‍👨🏼' => 'man en vrou wat hande vashou: donker velkleur, medium-ligte velkleur',
    '👩🏿‍🤝‍👨🏽' => 'man en vrou wat hande vashou: donker velkleur, medium velkleur',
    '👩🏿‍🤝‍👨🏾' => 'man en vrou wat hande vashou: donker velkleur, medium-donker velkleur',
    '👨🏻‍🤝‍👨🏼' => 'twee mans wat hande vashou: ligte velkleur, medium-ligte velkleur',
    '👨🏻‍🤝‍👨🏽' => 'twee mans wat hande vashou: ligte velkleur, medium velkleur',
    '👨🏻‍🤝‍👨🏾' => 'twee mans wat hande vashou: ligte velkleur, medium-donker velkleur',
    '👨🏻‍🤝‍👨🏿' => 'twee mans wat hande vashou: ligte velkleur, donker velkleur',
    '👨🏼‍🤝‍👨🏻' => 'twee mans wat hande vashou: medium-ligte velkleur, ligte velkleur',
    '👨🏼‍🤝‍👨🏽' => 'twee mans wat hande vashou: medium-ligte velkleur, medium velkleur',
    '👨🏼‍🤝‍👨🏾' => 'twee mans wat hande vashou: medium-ligte velkleur, medium-donker velkleur',
    '👨🏼‍🤝‍👨🏿' => 'twee mans wat hande vashou: medium-ligte velkleur, donker velkleur',
    '👨🏽‍🤝‍👨🏻' => 'twee mans wat hande vashou: medium velkleur, ligte velkleur',
    '👨🏽‍🤝‍👨🏼' => 'twee mans wat hande vashou: medium velkleur, medium-ligte velkleur',
    '👨🏽‍🤝‍👨🏾' => 'twee mans wat hande vashou: medium velkleur, medium-donker velkleur',
    '👨🏽‍🤝‍👨🏿' => 'twee mans wat hande vashou: medium velkleur, donker velkleur',
    '👨🏾‍🤝‍👨🏻' => 'twee mans wat hande vashou: medium-donker velkleur, ligte velkleur',
    '👨🏾‍🤝‍👨🏼' => 'twee mans wat hande vashou: medium-donker velkleur, medium-ligte velkleur',
    '👨🏾‍🤝‍👨🏽' => 'twee mans wat hande vashou: medium-donker velkleur, medium velkleur',
    '👨🏾‍🤝‍👨🏿' => 'twee mans wat hande vashou: medium-donker velkleur, donker velkleur',
    '👨🏿‍🤝‍👨🏻' => 'twee mans wat hande vashou: donker velkleur, ligte velkleur',
    '👨🏿‍🤝‍👨🏼' => 'twee mans wat hande vashou: donker velkleur, medium-ligte velkleur',
    '👨🏿‍🤝‍👨🏽' => 'twee mans wat hande vashou: donker velkleur, medium velkleur',
    '👨🏿‍🤝‍👨🏾' => 'twee mans wat hande vashou: donker velkleur, medium-donker velkleur',
    '👩‍❤‍💋‍👨' => 'soen: vrou, man',
    '👨‍❤‍💋‍👨' => 'soen: man, man',
    '👩‍❤‍💋‍👩' => 'soen: vrou, vrou',
    '👨‍👩‍👧‍👦' => 'gesin: man, vrou, meisie, seun',
    '👨‍👩‍👦‍👦' => 'gesin: man, vrou, seun, seun',
    '👨‍👩‍👧‍👧' => 'gesin: man, vrou, meisie, meisie',
    '👨‍👨‍👧‍👦' => 'gesin: man, man, meisie, seun',
    '👨‍👨‍👦‍👦' => 'gesin: man, man, seun, seun',
    '👨‍👨‍👧‍👧' => 'gesin: man, man, meisie, meisie',
    '👩‍👩‍👧‍👦' => 'gesin: vrou, vrou, meisie, seun',
    '👩‍👩‍👦‍👦' => 'gesin: vrou, vrou, seun, seun',
    '👩‍👩‍👧‍👧' => 'gesin: vrou, vrou, meisie, meisie',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'vlag: Engeland',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'vlag: Skotland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'vlag: Wallis',
    '🧑‍🧑‍🧒‍🧒' => 'gesin: grootmens, volwasse, kind, kind',
    '🚶🏻‍♀‍➡' => 'vrou stap: ligte velkleur, kyk na regs',
    '🚶🏼‍♀‍➡' => 'vrou stap: medium-ligte velkleur, kyk na regs',
    '🚶🏽‍♀‍➡' => 'vrou stap: medium velkleur, kyk na regs',
    '🚶🏾‍♀‍➡' => 'vrou stap: medium-donker velkleur, kyk na regs',
    '🚶🏿‍♀‍➡' => 'vrou stap: donker velkleur, kyk na regs',
    '🚶🏻‍♂‍➡' => 'man stap: ligte velkleur, kyk na regs',
    '🚶🏼‍♂‍➡' => 'man stap: medium-ligte velkleur, kyk na regs',
    '🚶🏽‍♂‍➡' => 'man stap: medium velkleur, kyk na regs',
    '🚶🏾‍♂‍➡' => 'man stap: medium-donker velkleur, kyk na regs',
    '🚶🏿‍♂‍➡' => 'man stap: donker velkleur, kyk na regs',
    '🧎🏻‍♀‍➡' => 'vrou wat kniel: ligte velkleur, kyk na regs',
    '🧎🏼‍♀‍➡' => 'vrou wat kniel: medium-ligte velkleur, kyk na regs',
    '🧎🏽‍♀‍➡' => 'vrou wat kniel: medium velkleur, kyk na regs',
    '🧎🏾‍♀‍➡' => 'vrou wat kniel: medium-donker velkleur, kyk na regs',
    '🧎🏿‍♀‍➡' => 'vrou wat kniel: donker velkleur, kyk na regs',
    '🧎🏻‍♂‍➡' => 'man wat kniel: ligte velkleur, kyk na regs',
    '🧎🏼‍♂‍➡' => 'man wat kniel: medium-ligte velkleur, kyk na regs',
    '🧎🏽‍♂‍➡' => 'man wat kniel: medium velkleur, kyk na regs',
    '🧎🏾‍♂‍➡' => 'man wat kniel: medium-donker velkleur, kyk na regs',
    '🧎🏿‍♂‍➡' => 'man wat kniel: donker velkleur, kyk na regs',
    '🧑🏻‍🦯‍➡' => 'persoon met gidsstok: ligte velkleur, kyk na regs',
    '🧑🏼‍🦯‍➡' => 'persoon met gidsstok: medium-ligte velkleur, kyk na regs',
    '🧑🏽‍🦯‍➡' => 'persoon met gidsstok: medium velkleur, kyk na regs',
    '🧑🏾‍🦯‍➡' => 'persoon met gidsstok: medium-donker velkleur, kyk na regs',
    '🧑🏿‍🦯‍➡' => 'persoon met gidsstok: donker velkleur, kyk na regs',
    '👨🏻‍🦯‍➡' => 'man met gidsstok: ligte velkleur, kyk na regs',
    '👨🏼‍🦯‍➡' => 'man met gidsstok: medium-ligte velkleur, kyk na regs',
    '👨🏽‍🦯‍➡' => 'man met gidsstok: medium velkleur, kyk na regs',
    '👨🏾‍🦯‍➡' => 'man met gidsstok: medium-donker velkleur, kyk na regs',
    '👨🏿‍🦯‍➡' => 'man met gidsstok: donker velkleur, kyk na regs',
    '👩🏻‍🦯‍➡' => 'vrou met gidsstok: ligte velkleur, kyk na regs',
    '👩🏼‍🦯‍➡' => 'vrou met gidsstok: medium-ligte velkleur, kyk na regs',
    '👩🏽‍🦯‍➡' => 'vrou met gidsstok: medium velkleur, kyk na regs',
    '👩🏾‍🦯‍➡' => 'vrou met gidsstok: medium-donker velkleur, kyk na regs',
    '👩🏿‍🦯‍➡' => 'vrou met gidsstok: donker velkleur, kyk na regs',
    '🧑🏻‍🦼‍➡' => 'persoon in motoraangedrewe rolstoel: ligte velkleur, kyk na regs',
    '🧑🏼‍🦼‍➡' => 'persoon in motoraangedrewe rolstoel: medium-ligte velkleur, kyk na regs',
    '🧑🏽‍🦼‍➡' => 'persoon in motoraangedrewe rolstoel: medium velkleur, kyk na regs',
    '🧑🏾‍🦼‍➡' => 'persoon in motoraangedrewe rolstoel: medium-donker velkleur, kyk na regs',
    '🧑🏿‍🦼‍➡' => 'persoon in motoraangedrewe rolstoel: donker velkleur, kyk na regs',
    '👨🏻‍🦼‍➡' => 'man in motoraangedrewe rolstoel: ligte velkleur, kyk na regs',
    '👨🏼‍🦼‍➡' => 'man in motoraangedrewe rolstoel: medium-ligte velkleur, kyk na regs',
    '👨🏽‍🦼‍➡' => 'man in motoraangedrewe rolstoel: medium velkleur, kyk na regs',
    '👨🏾‍🦼‍➡' => 'man in motoraangedrewe rolstoel: medium-donker velkleur, kyk na regs',
    '👨🏿‍🦼‍➡' => 'man in motoraangedrewe rolstoel: donker velkleur, kyk na regs',
    '👩🏻‍🦼‍➡' => 'vrou in motoraangedrewe rolstoel: ligte velkleur, kyk na regs',
    '👩🏼‍🦼‍➡' => 'vrou in motoraangedrewe rolstoel: medium-ligte velkleur, kyk na regs',
    '👩🏽‍🦼‍➡' => 'vrou in motoraangedrewe rolstoel: medium velkleur, kyk na regs',
    '👩🏾‍🦼‍➡' => 'vrou in motoraangedrewe rolstoel: medium-donker velkleur, kyk na regs',
    '👩🏿‍🦼‍➡' => 'vrou in motoraangedrewe rolstoel: donker velkleur, kyk na regs',
    '🧑🏻‍🦽‍➡' => 'persoon in handgedrewe rolstoel: ligte velkleur, kyk na regs',
    '🧑🏼‍🦽‍➡' => 'persoon in handgedrewe rolstoel: medium-ligte velkleur, kyk na regs',
    '🧑🏽‍🦽‍➡' => 'persoon in handgedrewe rolstoel: medium velkleur, kyk na regs',
    '🧑🏾‍🦽‍➡' => 'persoon in handgedrewe rolstoel: medium-donker velkleur, kyk na regs',
    '🧑🏿‍🦽‍➡' => 'persoon in handgedrewe rolstoel: donker velkleur, kyk na regs',
    '👨🏻‍🦽‍➡' => 'man in handgedrewe rolstoel: ligte velkleur, kyk na regs',
    '👨🏼‍🦽‍➡' => 'man in handgedrewe rolstoel: medium-ligte velkleur, kyk na regs',
    '👨🏽‍🦽‍➡' => 'man in handgedrewe rolstoel: medium velkleur, kyk na regs',
    '👨🏾‍🦽‍➡' => 'man in handgedrewe rolstoel: medium-donker velkleur, kyk na regs',
    '👨🏿‍🦽‍➡' => 'man in handgedrewe rolstoel: donker velkleur, kyk na regs',
    '👩🏻‍🦽‍➡' => 'vrou in handgedrewe rolstoel: ligte velkleur, kyk na regs',
    '👩🏼‍🦽‍➡' => 'vrou in handgedrewe rolstoel: medium-ligte velkleur, kyk na regs',
    '👩🏽‍🦽‍➡' => 'vrou in handgedrewe rolstoel: medium velkleur, kyk na regs',
    '👩🏾‍🦽‍➡' => 'vrou in handgedrewe rolstoel: medium-donker velkleur, kyk na regs',
    '👩🏿‍🦽‍➡' => 'vrou in handgedrewe rolstoel: donker velkleur, kyk na regs',
    '🏃🏻‍♀‍➡' => 'vrou hardloop: ligte velkleur, kyk na regs',
    '🏃🏼‍♀‍➡' => 'vrou hardloop: medium-ligte velkleur, kyk na regs',
    '🏃🏽‍♀‍➡' => 'vrou hardloop: medium velkleur, kyk na regs',
    '🏃🏾‍♀‍➡' => 'vrou hardloop: medium-donker velkleur, kyk na regs',
    '🏃🏿‍♀‍➡' => 'vrou hardloop: donker velkleur, kyk na regs',
    '🏃🏻‍♂‍➡' => 'man hardloop: ligte velkleur, kyk na regs',
    '🏃🏼‍♂‍➡' => 'man hardloop: medium-ligte velkleur, kyk na regs',
    '🏃🏽‍♂‍➡' => 'man hardloop: medium velkleur, kyk na regs',
    '🏃🏾‍♂‍➡' => 'man hardloop: medium-donker velkleur, kyk na regs',
    '🏃🏿‍♂‍➡' => 'man hardloop: donker velkleur, kyk na regs',
    '🫱🏻‍🫲🏼' => 'handskud: ligte velkleur, medium-ligte velkleur',
    '🫱🏻‍🫲🏽' => 'handskud: ligte velkleur, medium velkleur',
    '🫱🏻‍🫲🏾' => 'handskud: ligte velkleur, medium-donker velkleur',
    '🫱🏻‍🫲🏿' => 'handskud: ligte velkleur, donker velkleur',
    '🫱🏼‍🫲🏻' => 'handskud: medium-ligte velkleur, ligte velkleur',
    '🫱🏼‍🫲🏽' => 'handskud: medium-ligte velkleur, medium velkleur',
    '🫱🏼‍🫲🏾' => 'handskud: medium-ligte velkleur, medium-donker velkleur',
    '🫱🏼‍🫲🏿' => 'handskud: medium-ligte velkleur, donker velkleur',
    '🫱🏽‍🫲🏻' => 'handskud: medium velkleur, ligte velkleur',
    '🫱🏽‍🫲🏼' => 'handskud: medium velkleur, medium-ligte velkleur',
    '🫱🏽‍🫲🏾' => 'handskud: medium velkleur, medium-donker velkleur',
    '🫱🏽‍🫲🏿' => 'handskud: medium velkleur, donker velkleur',
    '🫱🏾‍🫲🏻' => 'handskud: medium-donker velkleur, ligte velkleur',
    '🫱🏾‍🫲🏼' => 'handskud: medium-donker velkleur, medium-ligte velkleur',
    '🫱🏾‍🫲🏽' => 'handskud: medium-donker velkleur, medium velkleur',
    '🫱🏾‍🫲🏿' => 'handskud: medium-donker velkleur, donker velkleur',
    '🫱🏿‍🫲🏻' => 'handskud: donker velkleur, ligte velkleur',
    '🫱🏿‍🫲🏼' => 'handskud: donker velkleur, medium-ligte velkleur',
    '🫱🏿‍🫲🏽' => 'handskud: donker velkleur, medium velkleur',
    '🫱🏿‍🫲🏾' => 'handskud: donker velkleur, medium-donker velkleur',
    '🚶‍♀‍➡' => 'vrou stap: kyk na regs',
    '🚶‍♂‍➡' => 'man stap: kyk na regs',
    '🧎‍♀‍➡' => 'vrou wat kniel: kyk na regs',
    '🧎‍♂‍➡' => 'man wat kniel: kyk na regs',
    '🧑‍🦯‍➡' => 'persoon met gidsstok: kyk na regs',
    '👨‍🦯‍➡' => 'man met gidsstok: kyk na regs',
    '👩‍🦯‍➡' => 'vrou met gidsstok: kyk na regs',
    '🧑‍🦼‍➡' => 'persoon in motoraangedrewe rolstoel: kyk na regs',
    '👨‍🦼‍➡' => 'man in motoraangedrewe rolstoel: kyk na regs',
    '👩‍🦼‍➡' => 'vrou in motoraangedrewe rolstoel: kyk na regs',
    '🧑‍🦽‍➡' => 'persoon in handgedrewe rolstoel: kyk na regs',
    '👨‍🦽‍➡' => 'man in handgedrewe rolstoel: kyk na regs',
    '👩‍🦽‍➡' => 'vrou in handgedrewe rolstoel: kyk na regs',
    '🏃‍♀‍➡' => 'vrou hardloop: kyk na regs',
    '🏃‍♂‍➡' => 'man hardloop: kyk na regs',
    '👩‍❤‍👨' => 'paartjie met hartjie: vrou, man',
    '👨‍❤‍👨' => 'paartjie met hartjie: man, man',
    '👩‍❤‍👩' => 'paartjie met hartjie: vrou, vrou',
    '👨‍👩‍👦' => 'gesin: man, vrou, seun',
    '👨‍👩‍👧' => 'gesin: man, vrou, meisie',
    '👨‍👨‍👦' => 'gesin: man, man, seun',
    '👨‍👨‍👧' => 'gesin: man, man, meisie',
    '👩‍👩‍👦' => 'gesin: vrou, vrou, seun',
    '👩‍👩‍👧' => 'gesin: vrou, vrou, meisie',
    '👨‍👦‍👦' => 'gesin: man, seun, seun',
    '👨‍👧‍👦' => 'gesin: man, meisie, seun',
    '👨‍👧‍👧' => 'gesin: man, meisie, meisie',
    '👩‍👦‍👦' => 'gesin: vrou, seun, seun',
    '👩‍👧‍👦' => 'gesin: vrou, meisie, seun',
    '👩‍👧‍👧' => 'gesin: vrou, meisie, meisie',
    '🧑‍🤝‍🧑' => 'mense wat hande vashou',
    '🧑‍🧑‍🧒' => 'gesin: grootmens, volwasse, kind',
    '🧑‍🧒‍🧒' => 'gesin: grootmens, kind, kind',
    '🧑🏻‍🦰' => 'volwassene: ligte velkleur, rooi hare',
    '🧑🏼‍🦰' => 'volwassene: medium-ligte velkleur, rooi hare',
    '🧑🏽‍🦰' => 'volwassene: medium velkleur, rooi hare',
    '🧑🏾‍🦰' => 'volwassene: medium-donker velkleur, rooi hare',
    '🧑🏿‍🦰' => 'volwassene: donker velkleur, rooi hare',
    '🧑🏻‍🦱' => 'volwassene: ligte velkleur, krulhare',
    '🧑🏼‍🦱' => 'volwassene: medium-ligte velkleur, krulhare',
    '🧑🏽‍🦱' => 'volwassene: medium velkleur, krulhare',
    '🧑🏾‍🦱' => 'volwassene: medium-donker velkleur, krulhare',
    '🧑🏿‍🦱' => 'volwassene: donker velkleur, krulhare',
    '🧑🏻‍🦳' => 'volwassene: ligte velkleur, wit hare',
    '🧑🏼‍🦳' => 'volwassene: medium-ligte velkleur, wit hare',
    '🧑🏽‍🦳' => 'volwassene: medium velkleur, wit hare',
    '🧑🏾‍🦳' => 'volwassene: medium-donker velkleur, wit hare',
    '🧑🏿‍🦳' => 'volwassene: donker velkleur, wit hare',
    '🧑🏻‍🦲' => 'volwassene: ligte velkleur, bles',
    '🧑🏼‍🦲' => 'volwassene: medium-ligte velkleur, bles',
    '🧑🏽‍🦲' => 'volwassene: medium velkleur, bles',
    '🧑🏾‍🦲' => 'volwassene: medium-donker velkleur, bles',
    '🧑🏿‍🦲' => 'volwassene: donker velkleur, bles',
    '🧑🏻‍🩰' => 'balletdanser: ligte velkleur',
    '🧑🏼‍🩰' => 'balletdanser: medium-ligte velkleur',
    '🧑🏽‍🩰' => 'balletdanser: medium velkleur',
    '🧑🏾‍🩰' => 'balletdanser: medium-donker velkleur',
    '🧑🏿‍🩰' => 'balletdanser: donker velkleur',
    '🧔🏻‍♂' => 'man: ligte velkleur, baard',
    '🧔🏼‍♂' => 'man: medium-ligte velkleur, baard',
    '🧔🏽‍♂' => 'man: medium velkleur, baard',
    '🧔🏾‍♂' => 'man: medium-donker velkleur, baard',
    '🧔🏿‍♂' => 'man: donker velkleur, baard',
    '👱🏻‍♂' => 'blonde man: ligte velkleur',
    '👱🏼‍♂' => 'blonde man: medium-ligte velkleur',
    '👱🏽‍♂' => 'blonde man: medium velkleur',
    '👱🏾‍♂' => 'blonde man: medium-donker velkleur',
    '👱🏿‍♂' => 'blonde man: donker velkleur',
    '👨🏻‍🦰' => 'man: ligte velkleur, rooi hare',
    '👨🏼‍🦰' => 'man: medium-ligte velkleur, rooi hare',
    '👨🏽‍🦰' => 'man: medium velkleur, rooi hare',
    '👨🏾‍🦰' => 'man: medium-donker velkleur, rooi hare',
    '👨🏿‍🦰' => 'man: donker velkleur, rooi hare',
    '👨🏻‍🦱' => 'man: ligte velkleur, krulhare',
    '👨🏼‍🦱' => 'man: medium-ligte velkleur, krulhare',
    '👨🏽‍🦱' => 'man: medium velkleur, krulhare',
    '👨🏾‍🦱' => 'man: medium-donker velkleur, krulhare',
    '👨🏿‍🦱' => 'man: donker velkleur, krulhare',
    '👨🏻‍🦳' => 'man: ligte velkleur, wit hare',
    '👨🏼‍🦳' => 'man: medium-ligte velkleur, wit hare',
    '👨🏽‍🦳' => 'man: medium velkleur, wit hare',
    '👨🏾‍🦳' => 'man: medium-donker velkleur, wit hare',
    '👨🏿‍🦳' => 'man: donker velkleur, wit hare',
    '👨🏻‍🦲' => 'man: ligte velkleur, bles',
    '👨🏼‍🦲' => 'man: medium-ligte velkleur, bles',
    '👨🏽‍🦲' => 'man: medium velkleur, bles',
    '👨🏾‍🦲' => 'man: medium-donker velkleur, bles',
    '👨🏿‍🦲' => 'man: donker velkleur, bles',
    '🧔🏻‍♀' => 'vrou: ligte velkleur, baard',
    '🧔🏼‍♀' => 'vrou: medium-ligte velkleur, baard',
    '🧔🏽‍♀' => 'vrou: medium velkleur, baard',
    '🧔🏾‍♀' => 'vrou: medium-donker velkleur, baard',
    '🧔🏿‍♀' => 'vrou: donker velkleur, baard',
    '👱🏻‍♀' => 'blondine: ligte velkleur',
    '👱🏼‍♀' => 'blondine: medium-ligte velkleur',
    '👱🏽‍♀' => 'blondine: medium velkleur',
    '👱🏾‍♀' => 'blondine: medium-donker velkleur',
    '👱🏿‍♀' => 'blondine: donker velkleur',
    '👩🏻‍🦰' => 'vrou: ligte velkleur, rooi hare',
    '👩🏼‍🦰' => 'vrou: medium-ligte velkleur, rooi hare',
    '👩🏽‍🦰' => 'vrou: medium velkleur, rooi hare',
    '👩🏾‍🦰' => 'vrou: medium-donker velkleur, rooi hare',
    '👩🏿‍🦰' => 'vrou: donker velkleur, rooi hare',
    '👩🏻‍🦱' => 'vrou: ligte velkleur, krulhare',
    '👩🏼‍🦱' => 'vrou: medium-ligte velkleur, krulhare',
    '👩🏽‍🦱' => 'vrou: medium velkleur, krulhare',
    '👩🏾‍🦱' => 'vrou: medium-donker velkleur, krulhare',
    '👩🏿‍🦱' => 'vrou: donker velkleur, krulhare',
    '👩🏻‍🦳' => 'vrou: ligte velkleur, wit hare',
    '👩🏼‍🦳' => 'vrou: medium-ligte velkleur, wit hare',
    '👩🏽‍🦳' => 'vrou: medium velkleur, wit hare',
    '👩🏾‍🦳' => 'vrou: medium-donker velkleur, wit hare',
    '👩🏿‍🦳' => 'vrou: donker velkleur, wit hare',
    '👩🏻‍🦲' => 'vrou: ligte velkleur, bles',
    '👩🏼‍🦲' => 'vrou: medium-ligte velkleur, bles',
    '👩🏽‍🦲' => 'vrou: medium velkleur, bles',
    '👩🏾‍🦲' => 'vrou: medium-donker velkleur, bles',
    '👩🏿‍🦲' => 'vrou: donker velkleur, bles',
    '🙍🏻‍♂' => 'man wat frons: ligte velkleur',
    '🙍🏼‍♂' => 'man wat frons: medium-ligte velkleur',
    '🙍🏽‍♂' => 'man wat frons: medium velkleur',
    '🙍🏾‍♂' => 'man wat frons: medium-donker velkleur',
    '🙍🏿‍♂' => 'man wat frons: donker velkleur',
    '🙍🏻‍♀' => 'vrou wat frons: ligte velkleur',
    '🙍🏼‍♀' => 'vrou wat frons: medium-ligte velkleur',
    '🙍🏽‍♀' => 'vrou wat frons: medium velkleur',
    '🙍🏾‍♀' => 'vrou wat frons: medium-donker velkleur',
    '🙍🏿‍♀' => 'vrou wat frons: donker velkleur',
    '🙎🏻‍♂' => 'dikbek man: ligte velkleur',
    '🙎🏼‍♂' => 'dikbek man: medium-ligte velkleur',
    '🙎🏽‍♂' => 'dikbek man: medium velkleur',
    '🙎🏾‍♂' => 'dikbek man: medium-donker velkleur',
    '🙎🏿‍♂' => 'dikbek man: donker velkleur',
    '🙎🏻‍♀' => 'dikbek vrou: ligte velkleur',
    '🙎🏼‍♀' => 'dikbek vrou: medium-ligte velkleur',
    '🙎🏽‍♀' => 'dikbek vrou: medium velkleur',
    '🙎🏾‍♀' => 'dikbek vrou: medium-donker velkleur',
    '🙎🏿‍♀' => 'dikbek vrou: donker velkleur',
    '🙅🏻‍♂' => 'man wys NEE: ligte velkleur',
    '🙅🏼‍♂' => 'man wys NEE: medium-ligte velkleur',
    '🙅🏽‍♂' => 'man wys NEE: medium velkleur',
    '🙅🏾‍♂' => 'man wys NEE: medium-donker velkleur',
    '🙅🏿‍♂' => 'man wys NEE: donker velkleur',
    '🙅🏻‍♀' => 'vrou wys NEE: ligte velkleur',
    '🙅🏼‍♀' => 'vrou wys NEE: medium-ligte velkleur',
    '🙅🏽‍♀' => 'vrou wys NEE: medium velkleur',
    '🙅🏾‍♀' => 'vrou wys NEE: medium-donker velkleur',
    '🙅🏿‍♀' => 'vrou wys NEE: donker velkleur',
    '🙆🏻‍♂' => 'man wys als is goed: ligte velkleur',
    '🙆🏼‍♂' => 'man wys als is goed: medium-ligte velkleur',
    '🙆🏽‍♂' => 'man wys als is goed: medium velkleur',
    '🙆🏾‍♂' => 'man wys als is goed: medium-donker velkleur',
    '🙆🏿‍♂' => 'man wys als is goed: donker velkleur',
    '🙆🏻‍♀' => 'vrou wys als is goed: ligte velkleur',
    '🙆🏼‍♀' => 'vrou wys als is goed: medium-ligte velkleur',
    '🙆🏽‍♀' => 'vrou wys als is goed: medium velkleur',
    '🙆🏾‍♀' => 'vrou wys als is goed: medium-donker velkleur',
    '🙆🏿‍♀' => 'vrou wys als is goed: donker velkleur',
    '💁🏻‍♂' => 'man hou hand geknak: ligte velkleur',
    '💁🏼‍♂' => 'man hou hand geknak: medium-ligte velkleur',
    '💁🏽‍♂' => 'man hou hand geknak: medium velkleur',
    '💁🏾‍♂' => 'man hou hand geknak: medium-donker velkleur',
    '💁🏿‍♂' => 'man hou hand geknak: donker velkleur',
    '💁🏻‍♀' => 'vrou hou hand geknak: ligte velkleur',
    '💁🏼‍♀' => 'vrou hou hand geknak: medium-ligte velkleur',
    '💁🏽‍♀' => 'vrou hou hand geknak: medium velkleur',
    '💁🏾‍♀' => 'vrou hou hand geknak: medium-donker velkleur',
    '💁🏿‍♀' => 'vrou hou hand geknak: donker velkleur',
    '🙋🏻‍♂' => 'man wat hand opsteek: ligte velkleur',
    '🙋🏼‍♂' => 'man wat hand opsteek: medium-ligte velkleur',
    '🙋🏽‍♂' => 'man wat hand opsteek: medium velkleur',
    '🙋🏾‍♂' => 'man wat hand opsteek: medium-donker velkleur',
    '🙋🏿‍♂' => 'man wat hand opsteek: donker velkleur',
    '🙋🏻‍♀' => 'vrou wat hand opsteek: ligte velkleur',
    '🙋🏼‍♀' => 'vrou wat hand opsteek: medium-ligte velkleur',
    '🙋🏽‍♀' => 'vrou wat hand opsteek: medium velkleur',
    '🙋🏾‍♀' => 'vrou wat hand opsteek: medium-donker velkleur',
    '🙋🏿‍♀' => 'vrou wat hand opsteek: donker velkleur',
    '🧏🏻‍♂' => 'dowe man: ligte velkleur',
    '🧏🏼‍♂' => 'dowe man: medium-ligte velkleur',
    '🧏🏽‍♂' => 'dowe man: medium velkleur',
    '🧏🏾‍♂' => 'dowe man: medium-donker velkleur',
    '🧏🏿‍♂' => 'dowe man: donker velkleur',
    '🧏🏻‍♀' => 'dowe vrou: ligte velkleur',
    '🧏🏼‍♀' => 'dowe vrou: medium-ligte velkleur',
    '🧏🏽‍♀' => 'dowe vrou: medium velkleur',
    '🧏🏾‍♀' => 'dowe vrou: medium-donker velkleur',
    '🧏🏿‍♀' => 'dowe vrou: donker velkleur',
    '🙇🏻‍♂' => 'man buig: ligte velkleur',
    '🙇🏼‍♂' => 'man buig: medium-ligte velkleur',
    '🙇🏽‍♂' => 'man buig: medium velkleur',
    '🙇🏾‍♂' => 'man buig: medium-donker velkleur',
    '🙇🏿‍♂' => 'man buig: donker velkleur',
    '🙇🏻‍♀' => 'vrou buig: ligte velkleur',
    '🙇🏼‍♀' => 'vrou buig: medium-ligte velkleur',
    '🙇🏽‍♀' => 'vrou buig: medium velkleur',
    '🙇🏾‍♀' => 'vrou buig: medium-donker velkleur',
    '🙇🏿‍♀' => 'vrou buig: donker velkleur',
    '🤦🏻‍♂' => 'man slaan hand teen voorkop: ligte velkleur',
    '🤦🏼‍♂' => 'man slaan hand teen voorkop: medium-ligte velkleur',
    '🤦🏽‍♂' => 'man slaan hand teen voorkop: medium velkleur',
    '🤦🏾‍♂' => 'man slaan hand teen voorkop: medium-donker velkleur',
    '🤦🏿‍♂' => 'man slaan hand teen voorkop: donker velkleur',
    '🤦🏻‍♀' => 'vrou slaan hand teen voorkop: ligte velkleur',
    '🤦🏼‍♀' => 'vrou slaan hand teen voorkop: medium-ligte velkleur',
    '🤦🏽‍♀' => 'vrou slaan hand teen voorkop: medium velkleur',
    '🤦🏾‍♀' => 'vrou slaan hand teen voorkop: medium-donker velkleur',
    '🤦🏿‍♀' => 'vrou slaan hand teen voorkop: donker velkleur',
    '🤷🏻‍♂' => 'man skouerophaal: ligte velkleur',
    '🤷🏼‍♂' => 'man skouerophaal: medium-ligte velkleur',
    '🤷🏽‍♂' => 'man skouerophaal: medium velkleur',
    '🤷🏾‍♂' => 'man skouerophaal: medium-donker velkleur',
    '🤷🏿‍♂' => 'man skouerophaal: donker velkleur',
    '🤷🏻‍♀' => 'vrou skouerophaal: ligte velkleur',
    '🤷🏼‍♀' => 'vrou skouerophaal: medium-ligte velkleur',
    '🤷🏽‍♀' => 'vrou skouerophaal: medium velkleur',
    '🤷🏾‍♀' => 'vrou skouerophaal: medium-donker velkleur',
    '🤷🏿‍♀' => 'vrou skouerophaal: donker velkleur',
    '🧑🏻‍⚕' => 'gesondheidswerker: ligte velkleur',
    '🧑🏼‍⚕' => 'gesondheidswerker: medium-ligte velkleur',
    '🧑🏽‍⚕' => 'gesondheidswerker: medium velkleur',
    '🧑🏾‍⚕' => 'gesondheidswerker: medium-donker velkleur',
    '🧑🏿‍⚕' => 'gesondheidswerker: donker velkleur',
    '👨🏻‍⚕' => 'manlike gesondheidswerker: ligte velkleur',
    '👨🏼‍⚕' => 'manlike gesondheidswerker: medium-ligte velkleur',
    '👨🏽‍⚕' => 'manlike gesondheidswerker: medium velkleur',
    '👨🏾‍⚕' => 'manlike gesondheidswerker: medium-donker velkleur',
    '👨🏿‍⚕' => 'manlike gesondheidswerker: donker velkleur',
    '👩🏻‍⚕' => 'vroulike gesondheidswerker: ligte velkleur',
    '👩🏼‍⚕' => 'vroulike gesondheidswerker: medium-ligte velkleur',
    '👩🏽‍⚕' => 'vroulike gesondheidswerker: medium velkleur',
    '👩🏾‍⚕' => 'vroulike gesondheidswerker: medium-donker velkleur',
    '👩🏿‍⚕' => 'vroulike gesondheidswerker: donker velkleur',
    '🧑🏻‍🎓' => 'student: ligte velkleur',
    '🧑🏼‍🎓' => 'student: medium-ligte velkleur',
    '🧑🏽‍🎓' => 'student: medium velkleur',
    '🧑🏾‍🎓' => 'student: medium-donker velkleur',
    '🧑🏿‍🎓' => 'student: donker velkleur',
    '👨🏻‍🎓' => 'manlike student: ligte velkleur',
    '👨🏼‍🎓' => 'manlike student: medium-ligte velkleur',
    '👨🏽‍🎓' => 'manlike student: medium velkleur',
    '👨🏾‍🎓' => 'manlike student: medium-donker velkleur',
    '👨🏿‍🎓' => 'manlike student: donker velkleur',
    '👩🏻‍🎓' => 'vroulike student: ligte velkleur',
    '👩🏼‍🎓' => 'vroulike student: medium-ligte velkleur',
    '👩🏽‍🎓' => 'vroulike student: medium velkleur',
    '👩🏾‍🎓' => 'vroulike student: medium-donker velkleur',
    '👩🏿‍🎓' => 'vroulike student: donker velkleur',
    '🧑🏻‍🏫' => 'onderwyser: ligte velkleur',
    '🧑🏼‍🏫' => 'onderwyser: medium-ligte velkleur',
    '🧑🏽‍🏫' => 'onderwyser: medium velkleur',
    '🧑🏾‍🏫' => 'onderwyser: medium-donker velkleur',
    '🧑🏿‍🏫' => 'onderwyser: donker velkleur',
    '👨🏻‍🏫' => 'manlike onderwyser: ligte velkleur',
    '👨🏼‍🏫' => 'manlike onderwyser: medium-ligte velkleur',
    '👨🏽‍🏫' => 'manlike onderwyser: medium velkleur',
    '👨🏾‍🏫' => 'manlike onderwyser: medium-donker velkleur',
    '👨🏿‍🏫' => 'manlike onderwyser: donker velkleur',
    '👩🏻‍🏫' => 'vroulike onderwyser: ligte velkleur',
    '👩🏼‍🏫' => 'vroulike onderwyser: medium-ligte velkleur',
    '👩🏽‍🏫' => 'vroulike onderwyser: medium velkleur',
    '👩🏾‍🏫' => 'vroulike onderwyser: medium-donker velkleur',
    '👩🏿‍🏫' => 'vroulike onderwyser: donker velkleur',
    '🧑🏻‍⚖' => 'regter: ligte velkleur',
    '🧑🏼‍⚖' => 'regter: medium-ligte velkleur',
    '🧑🏽‍⚖' => 'regter: medium velkleur',
    '🧑🏾‍⚖' => 'regter: medium-donker velkleur',
    '🧑🏿‍⚖' => 'regter: donker velkleur',
    '👨🏻‍⚖' => 'manlike regter: ligte velkleur',
    '👨🏼‍⚖' => 'manlike regter: medium-ligte velkleur',
    '👨🏽‍⚖' => 'manlike regter: medium velkleur',
    '👨🏾‍⚖' => 'manlike regter: medium-donker velkleur',
    '👨🏿‍⚖' => 'manlike regter: donker velkleur',
    '👩🏻‍⚖' => 'vroulike regter: ligte velkleur',
    '👩🏼‍⚖' => 'vroulike regter: medium-ligte velkleur',
    '👩🏽‍⚖' => 'vroulike regter: medium velkleur',
    '👩🏾‍⚖' => 'vroulike regter: medium-donker velkleur',
    '👩🏿‍⚖' => 'vroulike regter: donker velkleur',
    '🧑🏻‍🌾' => 'boer: ligte velkleur',
    '🧑🏼‍🌾' => 'boer: medium-ligte velkleur',
    '🧑🏽‍🌾' => 'boer: medium velkleur',
    '🧑🏾‍🌾' => 'boer: medium-donker velkleur',
    '🧑🏿‍🌾' => 'boer: donker velkleur',
    '👨🏻‍🌾' => 'manlike boer: ligte velkleur',
    '👨🏼‍🌾' => 'manlike boer: medium-ligte velkleur',
    '👨🏽‍🌾' => 'manlike boer: medium velkleur',
    '👨🏾‍🌾' => 'manlike boer: medium-donker velkleur',
    '👨🏿‍🌾' => 'manlike boer: donker velkleur',
    '👩🏻‍🌾' => 'vroulike boer: ligte velkleur',
    '👩🏼‍🌾' => 'vroulike boer: medium-ligte velkleur',
    '👩🏽‍🌾' => 'vroulike boer: medium velkleur',
    '👩🏾‍🌾' => 'vroulike boer: medium-donker velkleur',
    '👩🏿‍🌾' => 'vroulike boer: donker velkleur',
    '🧑🏻‍🍳' => 'kok: ligte velkleur',
    '🧑🏼‍🍳' => 'kok: medium-ligte velkleur',
    '🧑🏽‍🍳' => 'kok: medium velkleur',
    '🧑🏾‍🍳' => 'kok: medium-donker velkleur',
    '🧑🏿‍🍳' => 'kok: donker velkleur',
    '👨🏻‍🍳' => 'manlike kok: ligte velkleur',
    '👨🏼‍🍳' => 'manlike kok: medium-ligte velkleur',
    '👨🏽‍🍳' => 'manlike kok: medium velkleur',
    '👨🏾‍🍳' => 'manlike kok: medium-donker velkleur',
    '👨🏿‍🍳' => 'manlike kok: donker velkleur',
    '👩🏻‍🍳' => 'vroulike kok: ligte velkleur',
    '👩🏼‍🍳' => 'vroulike kok: medium-ligte velkleur',
    '👩🏽‍🍳' => 'vroulike kok: medium velkleur',
    '👩🏾‍🍳' => 'vroulike kok: medium-donker velkleur',
    '👩🏿‍🍳' => 'vroulike kok: donker velkleur',
    '🧑🏻‍🔧' => 'werktuigkundige: ligte velkleur',
    '🧑🏼‍🔧' => 'werktuigkundige: medium-ligte velkleur',
    '🧑🏽‍🔧' => 'werktuigkundige: medium velkleur',
    '🧑🏾‍🔧' => 'werktuigkundige: medium-donker velkleur',
    '🧑🏿‍🔧' => 'werktuigkundige: donker velkleur',
    '👨🏻‍🔧' => 'manlike motorwerktuigkundige: ligte velkleur',
    '👨🏼‍🔧' => 'manlike motorwerktuigkundige: medium-ligte velkleur',
    '👨🏽‍🔧' => 'manlike motorwerktuigkundige: medium velkleur',
    '👨🏾‍🔧' => 'manlike motorwerktuigkundige: medium-donker velkleur',
    '👨🏿‍🔧' => 'manlike motorwerktuigkundige: donker velkleur',
    '👩🏻‍🔧' => 'vroulike motorwerktuigkundige: ligte velkleur',
    '👩🏼‍🔧' => 'vroulike motorwerktuigkundige: medium-ligte velkleur',
    '👩🏽‍🔧' => 'vroulike motorwerktuigkundige: medium velkleur',
    '👩🏾‍🔧' => 'vroulike motorwerktuigkundige: medium-donker velkleur',
    '👩🏿‍🔧' => 'vroulike motorwerktuigkundige: donker velkleur',
    '🧑🏻‍🏭' => 'fabriekswerker: ligte velkleur',
    '🧑🏼‍🏭' => 'fabriekswerker: medium-ligte velkleur',
    '🧑🏽‍🏭' => 'fabriekswerker: medium velkleur',
    '🧑🏾‍🏭' => 'fabriekswerker: medium-donker velkleur',
    '🧑🏿‍🏭' => 'fabriekswerker: donker velkleur',
    '👨🏻‍🏭' => 'manlike fabriekswerker: ligte velkleur',
    '👨🏼‍🏭' => 'manlike fabriekswerker: medium-ligte velkleur',
    '👨🏽‍🏭' => 'manlike fabriekswerker: medium velkleur',
    '👨🏾‍🏭' => 'manlike fabriekswerker: medium-donker velkleur',
    '👨🏿‍🏭' => 'manlike fabriekswerker: donker velkleur',
    '👩🏻‍🏭' => 'vroulike fabriekswerker: ligte velkleur',
    '👩🏼‍🏭' => 'vroulike fabriekswerker: medium-ligte velkleur',
    '👩🏽‍🏭' => 'vroulike fabriekswerker: medium velkleur',
    '👩🏾‍🏭' => 'vroulike fabriekswerker: medium-donker velkleur',
    '👩🏿‍🏭' => 'vroulike fabriekswerker: donker velkleur',
    '🧑🏻‍💼' => 'kantoorwerker: ligte velkleur',
    '🧑🏼‍💼' => 'kantoorwerker: medium-ligte velkleur',
    '🧑🏽‍💼' => 'kantoorwerker: medium velkleur',
    '🧑🏾‍💼' => 'kantoorwerker: medium-donker velkleur',
    '🧑🏿‍💼' => 'kantoorwerker: donker velkleur',
    '👨🏻‍💼' => 'manlike kantoorwerker: ligte velkleur',
    '👨🏼‍💼' => 'manlike kantoorwerker: medium-ligte velkleur',
    '👨🏽‍💼' => 'manlike kantoorwerker: medium velkleur',
    '👨🏾‍💼' => 'manlike kantoorwerker: medium-donker velkleur',
    '👨🏿‍💼' => 'manlike kantoorwerker: donker velkleur',
    '👩🏻‍💼' => 'vroulike kantoorwerker: ligte velkleur',
    '👩🏼‍💼' => 'vroulike kantoorwerker: medium-ligte velkleur',
    '👩🏽‍💼' => 'vroulike kantoorwerker: medium velkleur',
    '👩🏾‍💼' => 'vroulike kantoorwerker: medium-donker velkleur',
    '👩🏿‍💼' => 'vroulike kantoorwerker: donker velkleur',
    '🧑🏻‍🔬' => 'wetenskaplike: ligte velkleur',
    '🧑🏼‍🔬' => 'wetenskaplike: medium-ligte velkleur',
    '🧑🏽‍🔬' => 'wetenskaplike: medium velkleur',
    '🧑🏾‍🔬' => 'wetenskaplike: medium-donker velkleur',
    '🧑🏿‍🔬' => 'wetenskaplike: donker velkleur',
    '👨🏻‍🔬' => 'manlike wetenskaplike: ligte velkleur',
    '👨🏼‍🔬' => 'manlike wetenskaplike: medium-ligte velkleur',
    '👨🏽‍🔬' => 'manlike wetenskaplike: medium velkleur',
    '👨🏾‍🔬' => 'manlike wetenskaplike: medium-donker velkleur',
    '👨🏿‍🔬' => 'manlike wetenskaplike: donker velkleur',
    '👩🏻‍🔬' => 'vroulike wetenskaplike: ligte velkleur',
    '👩🏼‍🔬' => 'vroulike wetenskaplike: medium-ligte velkleur',
    '👩🏽‍🔬' => 'vroulike wetenskaplike: medium velkleur',
    '👩🏾‍🔬' => 'vroulike wetenskaplike: medium-donker velkleur',
    '👩🏿‍🔬' => 'vroulike wetenskaplike: donker velkleur',
    '🧑🏻‍💻' => 'tegnoloog: ligte velkleur',
    '🧑🏼‍💻' => 'tegnoloog: medium-ligte velkleur',
    '🧑🏽‍💻' => 'tegnoloog: medium velkleur',
    '🧑🏾‍💻' => 'tegnoloog: medium-donker velkleur',
    '🧑🏿‍💻' => 'tegnoloog: donker velkleur',
    '👨🏻‍💻' => 'manlike tegnoloog: ligte velkleur',
    '👨🏼‍💻' => 'manlike tegnoloog: medium-ligte velkleur',
    '👨🏽‍💻' => 'manlike tegnoloog: medium velkleur',
    '👨🏾‍💻' => 'manlike tegnoloog: medium-donker velkleur',
    '👨🏿‍💻' => 'manlike tegnoloog: donker velkleur',
    '👩🏻‍💻' => 'vroulike tegnoloog: ligte velkleur',
    '👩🏼‍💻' => 'vroulike tegnoloog: medium-ligte velkleur',
    '👩🏽‍💻' => 'vroulike tegnoloog: medium velkleur',
    '👩🏾‍💻' => 'vroulike tegnoloog: medium-donker velkleur',
    '👩🏿‍💻' => 'vroulike tegnoloog: donker velkleur',
    '🧑🏻‍🎤' => 'sanger: ligte velkleur',
    '🧑🏼‍🎤' => 'sanger: medium-ligte velkleur',
    '🧑🏽‍🎤' => 'sanger: medium velkleur',
    '🧑🏾‍🎤' => 'sanger: medium-donker velkleur',
    '🧑🏿‍🎤' => 'sanger: donker velkleur',
    '👨🏻‍🎤' => 'manlike sanger: ligte velkleur',
    '👨🏼‍🎤' => 'manlike sanger: medium-ligte velkleur',
    '👨🏽‍🎤' => 'manlike sanger: medium velkleur',
    '👨🏾‍🎤' => 'manlike sanger: medium-donker velkleur',
    '👨🏿‍🎤' => 'manlike sanger: donker velkleur',
    '👩🏻‍🎤' => 'vroulike sanger: ligte velkleur',
    '👩🏼‍🎤' => 'vroulike sanger: medium-ligte velkleur',
    '👩🏽‍🎤' => 'vroulike sanger: medium velkleur',
    '👩🏾‍🎤' => 'vroulike sanger: medium-donker velkleur',
    '👩🏿‍🎤' => 'vroulike sanger: donker velkleur',
    '🧑🏻‍🎨' => 'kunstenaar: ligte velkleur',
    '🧑🏼‍🎨' => 'kunstenaar: medium-ligte velkleur',
    '🧑🏽‍🎨' => 'kunstenaar: medium velkleur',
    '🧑🏾‍🎨' => 'kunstenaar: medium-donker velkleur',
    '🧑🏿‍🎨' => 'kunstenaar: donker velkleur',
    '👨🏻‍🎨' => 'manlike kunstenaar: ligte velkleur',
    '👨🏼‍🎨' => 'manlike kunstenaar: medium-ligte velkleur',
    '👨🏽‍🎨' => 'manlike kunstenaar: medium velkleur',
    '👨🏾‍🎨' => 'manlike kunstenaar: medium-donker velkleur',
    '👨🏿‍🎨' => 'manlike kunstenaar: donker velkleur',
    '👩🏻‍🎨' => 'vroulike kunstenaar: ligte velkleur',
    '👩🏼‍🎨' => 'vroulike kunstenaar: medium-ligte velkleur',
    '👩🏽‍🎨' => 'vroulike kunstenaar: medium velkleur',
    '👩🏾‍🎨' => 'vroulike kunstenaar: medium-donker velkleur',
    '👩🏿‍🎨' => 'vroulike kunstenaar: donker velkleur',
    '🧑🏻‍✈' => 'vlieënier: ligte velkleur',
    '🧑🏼‍✈' => 'vlieënier: medium-ligte velkleur',
    '🧑🏽‍✈' => 'vlieënier: medium velkleur',
    '🧑🏾‍✈' => 'vlieënier: medium-donker velkleur',
    '🧑🏿‍✈' => 'vlieënier: donker velkleur',
    '👨🏻‍✈' => 'manlike vlieënier: ligte velkleur',
    '👨🏼‍✈' => 'manlike vlieënier: medium-ligte velkleur',
    '👨🏽‍✈' => 'manlike vlieënier: medium velkleur',
    '👨🏾‍✈' => 'manlike vlieënier: medium-donker velkleur',
    '👨🏿‍✈' => 'manlike vlieënier: donker velkleur',
    '👩🏻‍✈' => 'vroulike vlieënier: ligte velkleur',
    '👩🏼‍✈' => 'vroulike vlieënier: medium-ligte velkleur',
    '👩🏽‍✈' => 'vroulike vlieënier: medium velkleur',
    '👩🏾‍✈' => 'vroulike vlieënier: medium-donker velkleur',
    '👩🏿‍✈' => 'vroulike vlieënier: donker velkleur',
    '🧑🏻‍🚀' => 'ruimtevaarder: ligte velkleur',
    '🧑🏼‍🚀' => 'ruimtevaarder: medium-ligte velkleur',
    '🧑🏽‍🚀' => 'ruimtevaarder: medium velkleur',
    '🧑🏾‍🚀' => 'ruimtevaarder: medium-donker velkleur',
    '🧑🏿‍🚀' => 'ruimtevaarder: donker velkleur',
    '👨🏻‍🚀' => 'manlike ruimtevaarder: ligte velkleur',
    '👨🏼‍🚀' => 'manlike ruimtevaarder: medium-ligte velkleur',
    '👨🏽‍🚀' => 'manlike ruimtevaarder: medium velkleur',
    '👨🏾‍🚀' => 'manlike ruimtevaarder: medium-donker velkleur',
    '👨🏿‍🚀' => 'manlike ruimtevaarder: donker velkleur',
    '👩🏻‍🚀' => 'vroulike ruimtevaarder: ligte velkleur',
    '👩🏼‍🚀' => 'vroulike ruimtevaarder: medium-ligte velkleur',
    '👩🏽‍🚀' => 'vroulike ruimtevaarder: medium velkleur',
    '👩🏾‍🚀' => 'vroulike ruimtevaarder: medium-donker velkleur',
    '👩🏿‍🚀' => 'vroulike ruimtevaarder: donker velkleur',
    '🧑🏻‍🚒' => 'brandbestryder: ligte velkleur',
    '🧑🏼‍🚒' => 'brandbestryder: medium-ligte velkleur',
    '🧑🏽‍🚒' => 'brandbestryder: medium velkleur',
    '🧑🏾‍🚒' => 'brandbestryder: medium-donker velkleur',
    '🧑🏿‍🚒' => 'brandbestryder: donker velkleur',
    '👨🏻‍🚒' => 'brandweerman: ligte velkleur',
    '👨🏼‍🚒' => 'brandweerman: medium-ligte velkleur',
    '👨🏽‍🚒' => 'brandweerman: medium velkleur',
    '👨🏾‍🚒' => 'brandweerman: medium-donker velkleur',
    '👨🏿‍🚒' => 'brandweerman: donker velkleur',
    '👩🏻‍🚒' => 'brandweervrou: ligte velkleur',
    '👩🏼‍🚒' => 'brandweervrou: medium-ligte velkleur',
    '👩🏽‍🚒' => 'brandweervrou: medium velkleur',
    '👩🏾‍🚒' => 'brandweervrou: medium-donker velkleur',
    '👩🏿‍🚒' => 'brandweervrou: donker velkleur',
    '👮🏻‍♂' => 'polisieman: ligte velkleur',
    '👮🏼‍♂' => 'polisieman: medium-ligte velkleur',
    '👮🏽‍♂' => 'polisieman: medium velkleur',
    '👮🏾‍♂' => 'polisieman: medium-donker velkleur',
    '👮🏿‍♂' => 'polisieman: donker velkleur',
    '👮🏻‍♀' => 'polisievrou: ligte velkleur',
    '👮🏼‍♀' => 'polisievrou: medium-ligte velkleur',
    '👮🏽‍♀' => 'polisievrou: medium velkleur',
    '👮🏾‍♀' => 'polisievrou: medium-donker velkleur',
    '👮🏿‍♀' => 'polisievrou: donker velkleur',
    '🕵🏻‍♂' => 'manlike speurder: ligte velkleur',
    '🕵🏼‍♂' => 'manlike speurder: medium-ligte velkleur',
    '🕵🏽‍♂' => 'manlike speurder: medium velkleur',
    '🕵🏾‍♂' => 'manlike speurder: medium-donker velkleur',
    '🕵🏿‍♂' => 'manlike speurder: donker velkleur',
    '🕵🏻‍♀' => 'vroulike speurder: ligte velkleur',
    '🕵🏼‍♀' => 'vroulike speurder: medium-ligte velkleur',
    '🕵🏽‍♀' => 'vroulike speurder: medium velkleur',
    '🕵🏾‍♀' => 'vroulike speurder: medium-donker velkleur',
    '🕵🏿‍♀' => 'vroulike speurder: donker velkleur',
    '💂🏻‍♂' => 'manlike wag: ligte velkleur',
    '💂🏼‍♂' => 'manlike wag: medium-ligte velkleur',
    '💂🏽‍♂' => 'manlike wag: medium velkleur',
    '💂🏾‍♂' => 'manlike wag: medium-donker velkleur',
    '💂🏿‍♂' => 'manlike wag: donker velkleur',
    '💂🏻‍♀' => 'vroulike wag: ligte velkleur',
    '💂🏼‍♀' => 'vroulike wag: medium-ligte velkleur',
    '💂🏽‍♀' => 'vroulike wag: medium velkleur',
    '💂🏾‍♀' => 'vroulike wag: medium-donker velkleur',
    '💂🏿‍♀' => 'vroulike wag: donker velkleur',
    '👷🏻‍♂' => 'manlike bouer: ligte velkleur',
    '👷🏼‍♂' => 'manlike bouer: medium-ligte velkleur',
    '👷🏽‍♂' => 'manlike bouer: medium velkleur',
    '👷🏾‍♂' => 'manlike bouer: medium-donker velkleur',
    '👷🏿‍♂' => 'manlike bouer: donker velkleur',
    '👷🏻‍♀' => 'vroulike bouer: ligte velkleur',
    '👷🏼‍♀' => 'vroulike bouer: medium-ligte velkleur',
    '👷🏽‍♀' => 'vroulike bouer: medium velkleur',
    '👷🏾‍♀' => 'vroulike bouer: medium-donker velkleur',
    '👷🏿‍♀' => 'vroulike bouer: donker velkleur',
    '👳🏻‍♂' => 'man met tulband: ligte velkleur',
    '👳🏼‍♂' => 'man met tulband: medium-ligte velkleur',
    '👳🏽‍♂' => 'man met tulband: medium velkleur',
    '👳🏾‍♂' => 'man met tulband: medium-donker velkleur',
    '👳🏿‍♂' => 'man met tulband: donker velkleur',
    '👳🏻‍♀' => 'vrou met tulband: ligte velkleur',
    '👳🏼‍♀' => 'vrou met tulband: medium-ligte velkleur',
    '👳🏽‍♀' => 'vrou met tulband: medium velkleur',
    '👳🏾‍♀' => 'vrou met tulband: medium-donker velkleur',
    '👳🏿‍♀' => 'vrou met tulband: donker velkleur',
    '🤵🏻‍♂' => 'man in pak: ligte velkleur',
    '🤵🏼‍♂' => 'man in pak: medium-ligte velkleur',
    '🤵🏽‍♂' => 'man in pak: medium velkleur',
    '🤵🏾‍♂' => 'man in pak: medium-donker velkleur',
    '🤵🏿‍♂' => 'man in pak: donker velkleur',
    '🤵🏻‍♀' => 'vrou in pak: ligte velkleur',
    '🤵🏼‍♀' => 'vrou in pak: medium-ligte velkleur',
    '🤵🏽‍♀' => 'vrou in pak: medium velkleur',
    '🤵🏾‍♀' => 'vrou in pak: medium-donker velkleur',
    '🤵🏿‍♀' => 'vrou in pak: donker velkleur',
    '👰🏻‍♂' => 'man met sluier: ligte velkleur',
    '👰🏼‍♂' => 'man met sluier: medium-ligte velkleur',
    '👰🏽‍♂' => 'man met sluier: medium velkleur',
    '👰🏾‍♂' => 'man met sluier: medium-donker velkleur',
    '👰🏿‍♂' => 'man met sluier: donker velkleur',
    '👰🏻‍♀' => 'vrou met sluier: ligte velkleur',
    '👰🏼‍♀' => 'vrou met sluier: medium-ligte velkleur',
    '👰🏽‍♀' => 'vrou met sluier: medium velkleur',
    '👰🏾‍♀' => 'vrou met sluier: medium-donker velkleur',
    '👰🏿‍♀' => 'vrou met sluier: donker velkleur',
    '👩🏻‍🍼' => 'vrou wat baba voed: ligte velkleur',
    '👩🏼‍🍼' => 'vrou wat baba voed: medium-ligte velkleur',
    '👩🏽‍🍼' => 'vrou wat baba voed: medium velkleur',
    '👩🏾‍🍼' => 'vrou wat baba voed: medium-donker velkleur',
    '👩🏿‍🍼' => 'vrou wat baba voed: donker velkleur',
    '👨🏻‍🍼' => 'man wat baba voed: ligte velkleur',
    '👨🏼‍🍼' => 'man wat baba voed: medium-ligte velkleur',
    '👨🏽‍🍼' => 'man wat baba voed: medium velkleur',
    '👨🏾‍🍼' => 'man wat baba voed: medium-donker velkleur',
    '👨🏿‍🍼' => 'man wat baba voed: donker velkleur',
    '🧑🏻‍🍼' => 'persoon wat baba voed: ligte velkleur',
    '🧑🏼‍🍼' => 'persoon wat baba voed: medium-ligte velkleur',
    '🧑🏽‍🍼' => 'persoon wat baba voed: medium velkleur',
    '🧑🏾‍🍼' => 'persoon wat baba voed: medium-donker velkleur',
    '🧑🏿‍🍼' => 'persoon wat baba voed: donker velkleur',
    '🧑🏻‍🎄' => 'mx claus: ligte velkleur',
    '🧑🏼‍🎄' => 'mx claus: medium-ligte velkleur',
    '🧑🏽‍🎄' => 'mx claus: medium velkleur',
    '🧑🏾‍🎄' => 'mx claus: medium-donker velkleur',
    '🧑🏿‍🎄' => 'mx claus: donker velkleur',
    '🦸🏻‍♂' => 'manlike superheld: ligte velkleur',
    '🦸🏼‍♂' => 'manlike superheld: medium-ligte velkleur',
    '🦸🏽‍♂' => 'manlike superheld: medium velkleur',
    '🦸🏾‍♂' => 'manlike superheld: medium-donker velkleur',
    '🦸🏿‍♂' => 'manlike superheld: donker velkleur',
    '🦸🏻‍♀' => 'vroulike superheld: ligte velkleur',
    '🦸🏼‍♀' => 'vroulike superheld: medium-ligte velkleur',
    '🦸🏽‍♀' => 'vroulike superheld: medium velkleur',
    '🦸🏾‍♀' => 'vroulike superheld: medium-donker velkleur',
    '🦸🏿‍♀' => 'vroulike superheld: donker velkleur',
    '🦹🏻‍♂' => 'manlike superskurk: ligte velkleur',
    '🦹🏼‍♂' => 'manlike superskurk: medium-ligte velkleur',
    '🦹🏽‍♂' => 'manlike superskurk: medium velkleur',
    '🦹🏾‍♂' => 'manlike superskurk: medium-donker velkleur',
    '🦹🏿‍♂' => 'manlike superskurk: donker velkleur',
    '🦹🏻‍♀' => 'vroulike superskurk: ligte velkleur',
    '🦹🏼‍♀' => 'vroulike superskurk: medium-ligte velkleur',
    '🦹🏽‍♀' => 'vroulike superskurk: medium velkleur',
    '🦹🏾‍♀' => 'vroulike superskurk: medium-donker velkleur',
    '🦹🏿‍♀' => 'vroulike superskurk: donker velkleur',
    '🧙🏻‍♂' => 'manlike magus: ligte velkleur',
    '🧙🏼‍♂' => 'manlike magus: medium-ligte velkleur',
    '🧙🏽‍♂' => 'manlike magus: medium velkleur',
    '🧙🏾‍♂' => 'manlike magus: medium-donker velkleur',
    '🧙🏿‍♂' => 'manlike magus: donker velkleur',
    '🧙🏻‍♀' => 'vroulike magus: ligte velkleur',
    '🧙🏼‍♀' => 'vroulike magus: medium-ligte velkleur',
    '🧙🏽‍♀' => 'vroulike magus: medium velkleur',
    '🧙🏾‍♀' => 'vroulike magus: medium-donker velkleur',
    '🧙🏿‍♀' => 'vroulike magus: donker velkleur',
    '🧚🏻‍♂' => 'manlike fee: ligte velkleur',
    '🧚🏼‍♂' => 'manlike fee: medium-ligte velkleur',
    '🧚🏽‍♂' => 'manlike fee: medium velkleur',
    '🧚🏾‍♂' => 'manlike fee: medium-donker velkleur',
    '🧚🏿‍♂' => 'manlike fee: donker velkleur',
    '🧚🏻‍♀' => 'vroulike feetjie: ligte velkleur',
    '🧚🏼‍♀' => 'vroulike feetjie: medium-ligte velkleur',
    '🧚🏽‍♀' => 'vroulike feetjie: medium velkleur',
    '🧚🏾‍♀' => 'vroulike feetjie: medium-donker velkleur',
    '🧚🏿‍♀' => 'vroulike feetjie: donker velkleur',
    '🧛🏻‍♂' => 'manlike vampier: ligte velkleur',
    '🧛🏼‍♂' => 'manlike vampier: medium-ligte velkleur',
    '🧛🏽‍♂' => 'manlike vampier: medium velkleur',
    '🧛🏾‍♂' => 'manlike vampier: medium-donker velkleur',
    '🧛🏿‍♂' => 'manlike vampier: donker velkleur',
    '🧛🏻‍♀' => 'vroulike vampier: ligte velkleur',
    '🧛🏼‍♀' => 'vroulike vampier: medium-ligte velkleur',
    '🧛🏽‍♀' => 'vroulike vampier: medium velkleur',
    '🧛🏾‍♀' => 'vroulike vampier: medium-donker velkleur',
    '🧛🏿‍♀' => 'vroulike vampier: donker velkleur',
    '🧜🏻‍♂' => 'meerman: ligte velkleur',
    '🧜🏼‍♂' => 'meerman: medium-ligte velkleur',
    '🧜🏽‍♂' => 'meerman: medium velkleur',
    '🧜🏾‍♂' => 'meerman: medium-donker velkleur',
    '🧜🏿‍♂' => 'meerman: donker velkleur',
    '🧜🏻‍♀' => 'meermin: ligte velkleur',
    '🧜🏼‍♀' => 'meermin: medium-ligte velkleur',
    '🧜🏽‍♀' => 'meermin: medium velkleur',
    '🧜🏾‍♀' => 'meermin: medium-donker velkleur',
    '🧜🏿‍♀' => 'meermin: donker velkleur',
    '🧝🏻‍♂' => 'manlike elf: ligte velkleur',
    '🧝🏼‍♂' => 'manlike elf: medium-ligte velkleur',
    '🧝🏽‍♂' => 'manlike elf: medium velkleur',
    '🧝🏾‍♂' => 'manlike elf: medium-donker velkleur',
    '🧝🏿‍♂' => 'manlike elf: donker velkleur',
    '🧝🏻‍♀' => 'vroulike elf: ligte velkleur',
    '🧝🏼‍♀' => 'vroulike elf: medium-ligte velkleur',
    '🧝🏽‍♀' => 'vroulike elf: medium velkleur',
    '🧝🏾‍♀' => 'vroulike elf: medium-donker velkleur',
    '🧝🏿‍♀' => 'vroulike elf: donker velkleur',
    '💆🏻‍♂' => 'man kry massering: ligte velkleur',
    '💆🏼‍♂' => 'man kry massering: medium-ligte velkleur',
    '💆🏽‍♂' => 'man kry massering: medium velkleur',
    '💆🏾‍♂' => 'man kry massering: medium-donker velkleur',
    '💆🏿‍♂' => 'man kry massering: donker velkleur',
    '💆🏻‍♀' => 'vrou kry massering: ligte velkleur',
    '💆🏼‍♀' => 'vrou kry massering: medium-ligte velkleur',
    '💆🏽‍♀' => 'vrou kry massering: medium velkleur',
    '💆🏾‍♀' => 'vrou kry massering: medium-donker velkleur',
    '💆🏿‍♀' => 'vrou kry massering: donker velkleur',
    '💇🏻‍♂' => 'man kry haarsny: ligte velkleur',
    '💇🏼‍♂' => 'man kry haarsny: medium-ligte velkleur',
    '💇🏽‍♂' => 'man kry haarsny: medium velkleur',
    '💇🏾‍♂' => 'man kry haarsny: medium-donker velkleur',
    '💇🏿‍♂' => 'man kry haarsny: donker velkleur',
    '💇🏻‍♀' => 'vrou kry haarsny: ligte velkleur',
    '💇🏼‍♀' => 'vrou kry haarsny: medium-ligte velkleur',
    '💇🏽‍♀' => 'vrou kry haarsny: medium velkleur',
    '💇🏾‍♀' => 'vrou kry haarsny: medium-donker velkleur',
    '💇🏿‍♀' => 'vrou kry haarsny: donker velkleur',
    '🚶🏻‍♂' => 'man stap: ligte velkleur',
    '🚶🏼‍♂' => 'man stap: medium-ligte velkleur',
    '🚶🏽‍♂' => 'man stap: medium velkleur',
    '🚶🏾‍♂' => 'man stap: medium-donker velkleur',
    '🚶🏿‍♂' => 'man stap: donker velkleur',
    '🚶🏻‍♀' => 'vrou stap: ligte velkleur',
    '🚶🏼‍♀' => 'vrou stap: medium-ligte velkleur',
    '🚶🏽‍♀' => 'vrou stap: medium velkleur',
    '🚶🏾‍♀' => 'vrou stap: medium-donker velkleur',
    '🚶🏿‍♀' => 'vrou stap: donker velkleur',
    '🚶🏻‍➡' => 'voetganger: ligte velkleur, kyk na regs',
    '🚶🏼‍➡' => 'voetganger: medium-ligte velkleur, kyk na regs',
    '🚶🏽‍➡' => 'voetganger: medium velkleur, kyk na regs',
    '🚶🏾‍➡' => 'voetganger: medium-donker velkleur, kyk na regs',
    '🚶🏿‍➡' => 'voetganger: donker velkleur, kyk na regs',
    '🧍🏻‍♂' => 'man wat staan: ligte velkleur',
    '🧍🏼‍♂' => 'man wat staan: medium-ligte velkleur',
    '🧍🏽‍♂' => 'man wat staan: medium velkleur',
    '🧍🏾‍♂' => 'man wat staan: medium-donker velkleur',
    '🧍🏿‍♂' => 'man wat staan: donker velkleur',
    '🧍🏻‍♀' => 'vrou wat staan: ligte velkleur',
    '🧍🏼‍♀' => 'vrou wat staan: medium-ligte velkleur',
    '🧍🏽‍♀' => 'vrou wat staan: medium velkleur',
    '🧍🏾‍♀' => 'vrou wat staan: medium-donker velkleur',
    '🧍🏿‍♀' => 'vrou wat staan: donker velkleur',
    '🧎🏻‍♂' => 'man wat kniel: ligte velkleur',
    '🧎🏼‍♂' => 'man wat kniel: medium-ligte velkleur',
    '🧎🏽‍♂' => 'man wat kniel: medium velkleur',
    '🧎🏾‍♂' => 'man wat kniel: medium-donker velkleur',
    '🧎🏿‍♂' => 'man wat kniel: donker velkleur',
    '🧎🏻‍♀' => 'vrou wat kniel: ligte velkleur',
    '🧎🏼‍♀' => 'vrou wat kniel: medium-ligte velkleur',
    '🧎🏽‍♀' => 'vrou wat kniel: medium velkleur',
    '🧎🏾‍♀' => 'vrou wat kniel: medium-donker velkleur',
    '🧎🏿‍♀' => 'vrou wat kniel: donker velkleur',
    '🧎🏻‍➡' => 'persoon wat kniel: ligte velkleur, kyk na regs',
    '🧎🏼‍➡' => 'persoon wat kniel: medium-ligte velkleur, kyk na regs',
    '🧎🏽‍➡' => 'persoon wat kniel: medium velkleur, kyk na regs',
    '🧎🏾‍➡' => 'persoon wat kniel: medium-donker velkleur, kyk na regs',
    '🧎🏿‍➡' => 'persoon wat kniel: donker velkleur, kyk na regs',
    '🧑🏻‍🦯' => 'persoon met gidsstok: ligte velkleur',
    '🧑🏼‍🦯' => 'persoon met gidsstok: medium-ligte velkleur',
    '🧑🏽‍🦯' => 'persoon met gidsstok: medium velkleur',
    '🧑🏾‍🦯' => 'persoon met gidsstok: medium-donker velkleur',
    '🧑🏿‍🦯' => 'persoon met gidsstok: donker velkleur',
    '👨🏻‍🦯' => 'man met gidsstok: ligte velkleur',
    '👨🏼‍🦯' => 'man met gidsstok: medium-ligte velkleur',
    '👨🏽‍🦯' => 'man met gidsstok: medium velkleur',
    '👨🏾‍🦯' => 'man met gidsstok: medium-donker velkleur',
    '👨🏿‍🦯' => 'man met gidsstok: donker velkleur',
    '👩🏻‍🦯' => 'vrou met gidsstok: ligte velkleur',
    '👩🏼‍🦯' => 'vrou met gidsstok: medium-ligte velkleur',
    '👩🏽‍🦯' => 'vrou met gidsstok: medium velkleur',
    '👩🏾‍🦯' => 'vrou met gidsstok: medium-donker velkleur',
    '👩🏿‍🦯' => 'vrou met gidsstok: donker velkleur',
    '🧑🏻‍🦼' => 'persoon in motoraangedrewe rolstoel: ligte velkleur',
    '🧑🏼‍🦼' => 'persoon in motoraangedrewe rolstoel: medium-ligte velkleur',
    '🧑🏽‍🦼' => 'persoon in motoraangedrewe rolstoel: medium velkleur',
    '🧑🏾‍🦼' => 'persoon in motoraangedrewe rolstoel: medium-donker velkleur',
    '🧑🏿‍🦼' => 'persoon in motoraangedrewe rolstoel: donker velkleur',
    '👨🏻‍🦼' => 'man in motoraangedrewe rolstoel: ligte velkleur',
    '👨🏼‍🦼' => 'man in motoraangedrewe rolstoel: medium-ligte velkleur',
    '👨🏽‍🦼' => 'man in motoraangedrewe rolstoel: medium velkleur',
    '👨🏾‍🦼' => 'man in motoraangedrewe rolstoel: medium-donker velkleur',
    '👨🏿‍🦼' => 'man in motoraangedrewe rolstoel: donker velkleur',
    '👩🏻‍🦼' => 'vrou in motoraangedrewe rolstoel: ligte velkleur',
    '👩🏼‍🦼' => 'vrou in motoraangedrewe rolstoel: medium-ligte velkleur',
    '👩🏽‍🦼' => 'vrou in motoraangedrewe rolstoel: medium velkleur',
    '👩🏾‍🦼' => 'vrou in motoraangedrewe rolstoel: medium-donker velkleur',
    '👩🏿‍🦼' => 'vrou in motoraangedrewe rolstoel: donker velkleur',
    '🧑🏻‍🦽' => 'persoon in handgedrewe rolstoel: ligte velkleur',
    '🧑🏼‍🦽' => 'persoon in handgedrewe rolstoel: medium-ligte velkleur',
    '🧑🏽‍🦽' => 'persoon in handgedrewe rolstoel: medium velkleur',
    '🧑🏾‍🦽' => 'persoon in handgedrewe rolstoel: medium-donker velkleur',
    '🧑🏿‍🦽' => 'persoon in handgedrewe rolstoel: donker velkleur',
    '👨🏻‍🦽' => 'man in handgedrewe rolstoel: ligte velkleur',
    '👨🏼‍🦽' => 'man in handgedrewe rolstoel: medium-ligte velkleur',
    '👨🏽‍🦽' => 'man in handgedrewe rolstoel: medium velkleur',
    '👨🏾‍🦽' => 'man in handgedrewe rolstoel: medium-donker velkleur',
    '👨🏿‍🦽' => 'man in handgedrewe rolstoel: donker velkleur',
    '👩🏻‍🦽' => 'vrou in handgedrewe rolstoel: ligte velkleur',
    '👩🏼‍🦽' => 'vrou in handgedrewe rolstoel: medium-ligte velkleur',
    '👩🏽‍🦽' => 'vrou in handgedrewe rolstoel: medium velkleur',
    '👩🏾‍🦽' => 'vrou in handgedrewe rolstoel: medium-donker velkleur',
    '👩🏿‍🦽' => 'vrou in handgedrewe rolstoel: donker velkleur',
    '🏃🏻‍♂' => 'man hardloop: ligte velkleur',
    '🏃🏼‍♂' => 'man hardloop: medium-ligte velkleur',
    '🏃🏽‍♂' => 'man hardloop: medium velkleur',
    '🏃🏾‍♂' => 'man hardloop: medium-donker velkleur',
    '🏃🏿‍♂' => 'man hardloop: donker velkleur',
    '🏃🏻‍♀' => 'vrou hardloop: ligte velkleur',
    '🏃🏼‍♀' => 'vrou hardloop: medium-ligte velkleur',
    '🏃🏽‍♀' => 'vrou hardloop: medium velkleur',
    '🏃🏾‍♀' => 'vrou hardloop: medium-donker velkleur',
    '🏃🏿‍♀' => 'vrou hardloop: donker velkleur',
    '🏃🏻‍➡' => 'persoon wat hardloop: ligte velkleur, kyk na regs',
    '🏃🏼‍➡' => 'persoon wat hardloop: medium-ligte velkleur, kyk na regs',
    '🏃🏽‍➡' => 'persoon wat hardloop: medium velkleur, kyk na regs',
    '🏃🏾‍➡' => 'persoon wat hardloop: medium-donker velkleur, kyk na regs',
    '🏃🏿‍➡' => 'persoon wat hardloop: donker velkleur, kyk na regs',
    '👯🏻‍♀' => 'vroue met haasore: ligte velkleur',
    '👯🏼‍♀' => 'vroue met haasore: medium-ligte velkleur',
    '👯🏽‍♀' => 'vroue met haasore: medium velkleur',
    '👯🏾‍♀' => 'vroue met haasore: medium-donker velkleur',
    '👯🏿‍♀' => 'vroue met haasore: donker velkleur',
    '👯🏻‍♂' => 'mans met haasore: ligte velkleur',
    '👯🏼‍♂' => 'mans met haasore: medium-ligte velkleur',
    '👯🏽‍♂' => 'mans met haasore: medium velkleur',
    '👯🏾‍♂' => 'mans met haasore: medium-donker velkleur',
    '👯🏿‍♂' => 'mans met haasore: donker velkleur',
    '🧖🏻‍♂' => 'man in stoomkamer: ligte velkleur',
    '🧖🏼‍♂' => 'man in stoomkamer: medium-ligte velkleur',
    '🧖🏽‍♂' => 'man in stoomkamer: medium velkleur',
    '🧖🏾‍♂' => 'man in stoomkamer: medium-donker velkleur',
    '🧖🏿‍♂' => 'man in stoomkamer: donker velkleur',
    '🧖🏻‍♀' => 'vrou in stoomkamer: ligte velkleur',
    '🧖🏼‍♀' => 'vrou in stoomkamer: medium-ligte velkleur',
    '🧖🏽‍♀' => 'vrou in stoomkamer: medium velkleur',
    '🧖🏾‍♀' => 'vrou in stoomkamer: medium-donker velkleur',
    '🧖🏿‍♀' => 'vrou in stoomkamer: donker velkleur',
    '🧗🏻‍♂' => 'manlike rotsklimmer: ligte velkleur',
    '🧗🏼‍♂' => 'manlike rotsklimmer: medium-ligte velkleur',
    '🧗🏽‍♂' => 'manlike rotsklimmer: medium velkleur',
    '🧗🏾‍♂' => 'manlike rotsklimmer: medium-donker velkleur',
    '🧗🏿‍♂' => 'manlike rotsklimmer: donker velkleur',
    '🧗🏻‍♀' => 'vroulike rotsklimmer: ligte velkleur',
    '🧗🏼‍♀' => 'vroulike rotsklimmer: medium-ligte velkleur',
    '🧗🏽‍♀' => 'vroulike rotsklimmer: medium velkleur',
    '🧗🏾‍♀' => 'vroulike rotsklimmer: medium-donker velkleur',
    '🧗🏿‍♀' => 'vroulike rotsklimmer: donker velkleur',
    '🏌🏻‍♂' => 'manlike gholfspeler: ligte velkleur',
    '🏌🏼‍♂' => 'manlike gholfspeler: medium-ligte velkleur',
    '🏌🏽‍♂' => 'manlike gholfspeler: medium velkleur',
    '🏌🏾‍♂' => 'manlike gholfspeler: medium-donker velkleur',
    '🏌🏿‍♂' => 'manlike gholfspeler: donker velkleur',
    '🏌🏻‍♀' => 'vroulike gholfspeler: ligte velkleur',
    '🏌🏼‍♀' => 'vroulike gholfspeler: medium-ligte velkleur',
    '🏌🏽‍♀' => 'vroulike gholfspeler: medium velkleur',
    '🏌🏾‍♀' => 'vroulike gholfspeler: medium-donker velkleur',
    '🏌🏿‍♀' => 'vroulike gholfspeler: donker velkleur',
    '🏄🏻‍♂' => 'manlike branderplankryer: ligte velkleur',
    '🏄🏼‍♂' => 'manlike branderplankryer: medium-ligte velkleur',
    '🏄🏽‍♂' => 'manlike branderplankryer: medium velkleur',
    '🏄🏾‍♂' => 'manlike branderplankryer: medium-donker velkleur',
    '🏄🏿‍♂' => 'manlike branderplankryer: donker velkleur',
    '🏄🏻‍♀' => 'vroulike branderplankryer: ligte velkleur',
    '🏄🏼‍♀' => 'vroulike branderplankryer: medium-ligte velkleur',
    '🏄🏽‍♀' => 'vroulike branderplankryer: medium velkleur',
    '🏄🏾‍♀' => 'vroulike branderplankryer: medium-donker velkleur',
    '🏄🏿‍♀' => 'vroulike branderplankryer: donker velkleur',
    '🚣🏻‍♂' => 'man wat roei: ligte velkleur',
    '🚣🏼‍♂' => 'man wat roei: medium-ligte velkleur',
    '🚣🏽‍♂' => 'man wat roei: medium velkleur',
    '🚣🏾‍♂' => 'man wat roei: medium-donker velkleur',
    '🚣🏿‍♂' => 'man wat roei: donker velkleur',
    '🚣🏻‍♀' => 'vrou wat roei: ligte velkleur',
    '🚣🏼‍♀' => 'vrou wat roei: medium-ligte velkleur',
    '🚣🏽‍♀' => 'vrou wat roei: medium velkleur',
    '🚣🏾‍♀' => 'vrou wat roei: medium-donker velkleur',
    '🚣🏿‍♀' => 'vrou wat roei: donker velkleur',
    '🏊🏻‍♂' => 'manlike swemmer: ligte velkleur',
    '🏊🏼‍♂' => 'manlike swemmer: medium-ligte velkleur',
    '🏊🏽‍♂' => 'manlike swemmer: medium velkleur',
    '🏊🏾‍♂' => 'manlike swemmer: medium-donker velkleur',
    '🏊🏿‍♂' => 'manlike swemmer: donker velkleur',
    '🏊🏻‍♀' => 'vroulike swemmer: ligte velkleur',
    '🏊🏼‍♀' => 'vroulike swemmer: medium-ligte velkleur',
    '🏊🏽‍♀' => 'vroulike swemmer: medium velkleur',
    '🏊🏾‍♀' => 'vroulike swemmer: medium-donker velkleur',
    '🏊🏿‍♀' => 'vroulike swemmer: donker velkleur',
    '⛹🏻‍♂' => 'man hop bal: ligte velkleur',
    '⛹🏼‍♂' => 'man hop bal: medium-ligte velkleur',
    '⛹🏽‍♂' => 'man hop bal: medium velkleur',
    '⛹🏾‍♂' => 'man hop bal: medium-donker velkleur',
    '⛹🏿‍♂' => 'man hop bal: donker velkleur',
    '⛹🏻‍♀' => 'vrou hop bal: ligte velkleur',
    '⛹🏼‍♀' => 'vrou hop bal: medium-ligte velkleur',
    '⛹🏽‍♀' => 'vrou hop bal: medium velkleur',
    '⛹🏾‍♀' => 'vrou hop bal: medium-donker velkleur',
    '⛹🏿‍♀' => 'vrou hop bal: donker velkleur',
    '🏋🏻‍♂' => 'manlike gewigopteller: ligte velkleur',
    '🏋🏼‍♂' => 'manlike gewigopteller: medium-ligte velkleur',
    '🏋🏽‍♂' => 'manlike gewigopteller: medium velkleur',
    '🏋🏾‍♂' => 'manlike gewigopteller: medium-donker velkleur',
    '🏋🏿‍♂' => 'manlike gewigopteller: donker velkleur',
    '🏋🏻‍♀' => 'vroulike gewigopteller: ligte velkleur',
    '🏋🏼‍♀' => 'vroulike gewigopteller: medium-ligte velkleur',
    '🏋🏽‍♀' => 'vroulike gewigopteller: medium velkleur',
    '🏋🏾‍♀' => 'vroulike gewigopteller: medium-donker velkleur',
    '🏋🏿‍♀' => 'vroulike gewigopteller: donker velkleur',
    '🚴🏻‍♂' => 'manlike fietsryer: ligte velkleur',
    '🚴🏼‍♂' => 'manlike fietsryer: medium-ligte velkleur',
    '🚴🏽‍♂' => 'manlike fietsryer: medium velkleur',
    '🚴🏾‍♂' => 'manlike fietsryer: medium-donker velkleur',
    '🚴🏿‍♂' => 'manlike fietsryer: donker velkleur',
    '🚴🏻‍♀' => 'vroulike fietsryer: ligte velkleur',
    '🚴🏼‍♀' => 'vroulike fietsryer: medium-ligte velkleur',
    '🚴🏽‍♀' => 'vroulike fietsryer: medium velkleur',
    '🚴🏾‍♀' => 'vroulike fietsryer: medium-donker velkleur',
    '🚴🏿‍♀' => 'vroulike fietsryer: donker velkleur',
    '🚵🏻‍♂' => 'manlike bergfietsryer: ligte velkleur',
    '🚵🏼‍♂' => 'manlike bergfietsryer: medium-ligte velkleur',
    '🚵🏽‍♂' => 'manlike bergfietsryer: medium velkleur',
    '🚵🏾‍♂' => 'manlike bergfietsryer: medium-donker velkleur',
    '🚵🏿‍♂' => 'manlike bergfietsryer: donker velkleur',
    '🚵🏻‍♀' => 'vroulike bergfietsryer: ligte velkleur',
    '🚵🏼‍♀' => 'vroulike bergfietsryer: medium-ligte velkleur',
    '🚵🏽‍♀' => 'vroulike bergfietsryer: medium velkleur',
    '🚵🏾‍♀' => 'vroulike bergfietsryer: medium-donker velkleur',
    '🚵🏿‍♀' => 'vroulike bergfietsryer: donker velkleur',
    '🤸🏻‍♂' => 'man doen wawiel: ligte velkleur',
    '🤸🏼‍♂' => 'man doen wawiel: medium-ligte velkleur',
    '🤸🏽‍♂' => 'man doen wawiel: medium velkleur',
    '🤸🏾‍♂' => 'man doen wawiel: medium-donker velkleur',
    '🤸🏿‍♂' => 'man doen wawiel: donker velkleur',
    '🤸🏻‍♀' => 'vrou doen wawiel: ligte velkleur',
    '🤸🏼‍♀' => 'vrou doen wawiel: medium-ligte velkleur',
    '🤸🏽‍♀' => 'vrou doen wawiel: medium velkleur',
    '🤸🏾‍♀' => 'vrou doen wawiel: medium-donker velkleur',
    '🤸🏿‍♀' => 'vrou doen wawiel: donker velkleur',
    '🤼🏻‍♀' => 'vroulike stoeiers: ligte velkleur',
    '🤼🏼‍♀' => 'vroulike stoeiers: medium-ligte velkleur',
    '🤼🏽‍♀' => 'vroulike stoeiers: medium velkleur',
    '🤼🏾‍♀' => 'vroulike stoeiers: medium-donker velkleur',
    '🤼🏿‍♀' => 'vroulike stoeiers: donker velkleur',
    '🤼🏻‍♂' => 'manlike stoeiers: ligte velkleur',
    '🤼🏼‍♂' => 'manlike stoeiers: medium-ligte velkleur',
    '🤼🏽‍♂' => 'manlike stoeiers: medium velkleur',
    '🤼🏾‍♂' => 'manlike stoeiers: medium-donker velkleur',
    '🤼🏿‍♂' => 'manlike stoeiers: donker velkleur',
    '🤽🏻‍♂' => 'manlike waterpolospeler: ligte velkleur',
    '🤽🏼‍♂' => 'manlike waterpolospeler: medium-ligte velkleur',
    '🤽🏽‍♂' => 'manlike waterpolospeler: medium velkleur',
    '🤽🏾‍♂' => 'manlike waterpolospeler: medium-donker velkleur',
    '🤽🏿‍♂' => 'manlike waterpolospeler: donker velkleur',
    '🤽🏻‍♀' => 'vroulike waterpolospeler: ligte velkleur',
    '🤽🏼‍♀' => 'vroulike waterpolospeler: medium-ligte velkleur',
    '🤽🏽‍♀' => 'vroulike waterpolospeler: medium velkleur',
    '🤽🏾‍♀' => 'vroulike waterpolospeler: medium-donker velkleur',
    '🤽🏿‍♀' => 'vroulike waterpolospeler: donker velkleur',
    '🤾🏻‍♂' => 'manlike handbalspeler: ligte velkleur',
    '🤾🏼‍♂' => 'manlike handbalspeler: medium-ligte velkleur',
    '🤾🏽‍♂' => 'manlike handbalspeler: medium velkleur',
    '🤾🏾‍♂' => 'manlike handbalspeler: medium-donker velkleur',
    '🤾🏿‍♂' => 'manlike handbalspeler: donker velkleur',
    '🤾🏻‍♀' => 'vroulike handbalspeler: ligte velkleur',
    '🤾🏼‍♀' => 'vroulike handbalspeler: medium-ligte velkleur',
    '🤾🏽‍♀' => 'vroulike handbalspeler: medium velkleur',
    '🤾🏾‍♀' => 'vroulike handbalspeler: medium-donker velkleur',
    '🤾🏿‍♀' => 'vroulike handbalspeler: donker velkleur',
    '🤹🏻‍♂' => 'manlike jongleur: ligte velkleur',
    '🤹🏼‍♂' => 'manlike jongleur: medium-ligte velkleur',
    '🤹🏽‍♂' => 'manlike jongleur: medium velkleur',
    '🤹🏾‍♂' => 'manlike jongleur: medium-donker velkleur',
    '🤹🏿‍♂' => 'manlike jongleur: donker velkleur',
    '🤹🏻‍♀' => 'vroulike jongleur: ligte velkleur',
    '🤹🏼‍♀' => 'vroulike jongleur: medium-ligte velkleur',
    '🤹🏽‍♀' => 'vroulike jongleur: medium velkleur',
    '🤹🏾‍♀' => 'vroulike jongleur: medium-donker velkleur',
    '🤹🏿‍♀' => 'vroulike jongleur: donker velkleur',
    '🧘🏻‍♂' => 'man in lotusposisie: ligte velkleur',
    '🧘🏼‍♂' => 'man in lotusposisie: medium-ligte velkleur',
    '🧘🏽‍♂' => 'man in lotusposisie: medium velkleur',
    '🧘🏾‍♂' => 'man in lotusposisie: medium-donker velkleur',
    '🧘🏿‍♂' => 'man in lotusposisie: donker velkleur',
    '🧘🏻‍♀' => 'vrou in lotusposisie: ligte velkleur',
    '🧘🏼‍♀' => 'vrou in lotusposisie: medium-ligte velkleur',
    '🧘🏽‍♀' => 'vrou in lotusposisie: medium velkleur',
    '🧘🏾‍♀' => 'vrou in lotusposisie: medium-donker velkleur',
    '🧘🏿‍♀' => 'vrou in lotusposisie: donker velkleur',
    '🧑‍🦰' => 'volwassene: rooi hare',
    '🧑‍🦱' => 'volwassene: krulhare',
    '🧑‍🦳' => 'volwassene: wit hare',
    '🧑‍🦲' => 'volwassene: bles',
    '👨‍🦰' => 'man: rooi hare',
    '👨‍🦱' => 'man: krulhare',
    '👨‍🦳' => 'man: wit hare',
    '👨‍🦲' => 'man: bles',
    '👩‍🦰' => 'vrou: rooi hare',
    '👩‍🦱' => 'vrou: krulhare',
    '👩‍🦳' => 'vrou: wit hare',
    '👩‍🦲' => 'vrou: bles',
    '🚶‍➡' => 'voetganger: kyk na regs',
    '🧎‍➡' => 'persoon wat kniel: kyk na regs',
    '🏃‍➡' => 'persoon wat hardloop: kyk na regs',
    '👨‍👦' => 'gesin: man, seun',
    '👨‍👧' => 'gesin: man, meisie',
    '👩‍👦' => 'gesin: vrou, seun',
    '👩‍👧' => 'gesin: vrou, meisie',
    '😶‍🌫' => 'gesig in wolke',
    '😮‍💨' => 'gesig asem uit',
    '🙂‍↕' => 'kop wat vertikaal skud',
    '😵‍💫' => 'gesig met spiraaloë',
    '❤‍🔥' => 'hart wat brand',
    '❤‍🩹' => 'helende hart',
    '👁‍🗨' => 'oog in spraakborrel',
    '🧔‍♂' => 'man: baard',
    '👱‍♂' => 'blonde man',
    '🧔‍♀' => 'vrou: baard',
    '👱‍♀' => 'blondine',
    '🙍‍♂' => 'man wat frons',
    '🙍‍♀' => 'vrou wat frons',
    '🙎‍♂' => 'dikbek man',
    '🙎‍♀' => 'dikbek vrou',
    '🙅‍♂' => 'man wys NEE',
    '🙅‍♀' => 'vrou wys NEE',
    '🙆‍♂' => 'man wys als is goed',
    '🙆‍♀' => 'vrou wys als is goed',
    '💁‍♂' => 'man hou hand geknak',
    '💁‍♀' => 'vrou hou hand geknak',
    '🙋‍♂' => 'man wat hand opsteek',
    '🙋‍♀' => 'vrou wat hand opsteek',
    '🧏‍♂' => 'dowe man',
    '🧏‍♀' => 'dowe vrou',
    '🙇‍♂' => 'man buig',
    '🙇‍♀' => 'vrou buig',
    '🤦‍♂' => 'man slaan hand teen voorkop',
    '🤦‍♀' => 'vrou slaan hand teen voorkop',
    '🤷‍♂' => 'man skouerophaal',
    '🤷‍♀' => 'vrou skouerophaal',
    '🧑‍⚕' => 'gesondheidswerker',
    '👨‍⚕' => 'manlike gesondheidswerker',
    '👩‍⚕' => 'vroulike gesondheidswerker',
    '🧑‍🎓' => 'student',
    '👨‍🎓' => 'manlike student',
    '👩‍🎓' => 'vroulike student',
    '🧑‍🏫' => 'onderwyser',
    '👨‍🏫' => 'manlike onderwyser',
    '👩‍🏫' => 'vroulike onderwyser',
    '🧑‍⚖' => 'regter',
    '👨‍⚖' => 'manlike regter',
    '👩‍⚖' => 'vroulike regter',
    '🧑‍🌾' => 'boer',
    '👨‍🌾' => 'manlike boer',
    '👩‍🌾' => 'vroulike boer',
    '🧑‍🍳' => 'kok',
    '👨‍🍳' => 'manlike kok',
    '👩‍🍳' => 'vroulike kok',
    '🧑‍🔧' => 'werktuigkundige',
    '👨‍🔧' => 'manlike motorwerktuigkundige',
    '👩‍🔧' => 'vroulike motorwerktuigkundige',
    '🧑‍🏭' => 'fabriekswerker',
    '👨‍🏭' => 'manlike fabriekswerker',
    '👩‍🏭' => 'vroulike fabriekswerker',
    '🧑‍💼' => 'kantoorwerker',
    '👨‍💼' => 'manlike kantoorwerker',
    '👩‍💼' => 'vroulike kantoorwerker',
    '🧑‍🔬' => 'wetenskaplike',
    '👨‍🔬' => 'manlike wetenskaplike',
    '👩‍🔬' => 'vroulike wetenskaplike',
    '🧑‍💻' => 'tegnoloog',
    '👨‍💻' => 'manlike tegnoloog',
    '👩‍💻' => 'vroulike tegnoloog',
    '🧑‍🎤' => 'sanger',
    '👨‍🎤' => 'manlike sanger',
    '👩‍🎤' => 'vroulike sanger',
    '🧑‍🎨' => 'kunstenaar',
    '👨‍🎨' => 'manlike kunstenaar',
    '👩‍🎨' => 'vroulike kunstenaar',
    '🧑‍✈' => 'vlieënier',
    '👨‍✈' => 'manlike vlieënier',
    '👩‍✈' => 'vroulike vlieënier',
    '🧑‍🚀' => 'ruimtevaarder',
    '👨‍🚀' => 'manlike ruimtevaarder',
    '👩‍🚀' => 'vroulike ruimtevaarder',
    '🧑‍🚒' => 'brandbestryder',
    '👨‍🚒' => 'brandweerman',
    '👩‍🚒' => 'brandweervrou',
    '👮‍♂' => 'polisieman',
    '👮‍♀' => 'polisievrou',
    '🕵‍♂' => 'manlike speurder',
    '🕵‍♀' => 'vroulike speurder',
    '💂‍♂' => 'manlike wag',
    '💂‍♀' => 'vroulike wag',
    '👷‍♂' => 'manlike bouer',
    '👷‍♀' => 'vroulike bouer',
    '👳‍♂' => 'man met tulband',
    '👳‍♀' => 'vrou met tulband',
    '🤵‍♂' => 'man in pak',
    '🤵‍♀' => 'vrou in pak',
    '👰‍♂' => 'man met sluier',
    '👰‍♀' => 'vrou met sluier',
    '👩‍🍼' => 'vrou wat baba voed',
    '👨‍🍼' => 'man wat baba voed',
    '🧑‍🍼' => 'persoon wat baba voed',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'manlike superheld',
    '🦸‍♀' => 'vroulike superheld',
    '🦹‍♂' => 'manlike superskurk',
    '🦹‍♀' => 'vroulike superskurk',
    '🧙‍♂' => 'manlike magus',
    '🧙‍♀' => 'vroulike magus',
    '🧚‍♂' => 'manlike fee',
    '🧚‍♀' => 'vroulike feetjie',
    '🧛‍♂' => 'manlike vampier',
    '🧛‍♀' => 'vroulike vampier',
    '🧜‍♂' => 'meerman',
    '🧜‍♀' => 'meermin',
    '🧝‍♂' => 'manlike elf',
    '🧝‍♀' => 'vroulike elf',
    '🧞‍♂' => 'manlike towergees',
    '🧞‍♀' => 'vroulike towergees',
    '🧟‍♂' => 'manlike zombie',
    '🧟‍♀' => 'vroulike zombie',
    '💆‍♂' => 'man kry massering',
    '💆‍♀' => 'vrou kry massering',
    '💇‍♂' => 'man kry haarsny',
    '💇‍♀' => 'vrou kry haarsny',
    '🚶‍♂' => 'man stap',
    '🚶‍♀' => 'vrou stap',
    '🧍‍♂' => 'man wat staan',
    '🧍‍♀' => 'vrou wat staan',
    '🧎‍♂' => 'man wat kniel',
    '🧎‍♀' => 'vrou wat kniel',
    '🧑‍🦯' => 'persoon met gidsstok',
    '👨‍🦯' => 'man met gidsstok',
    '👩‍🦯' => 'vrou met gidsstok',
    '🧑‍🦼' => 'persoon in motoraangedrewe rolstoel',
    '👨‍🦼' => 'man in motoraangedrewe rolstoel',
    '👩‍🦼' => 'vrou in motoraangedrewe rolstoel',
    '🧑‍🦽' => 'persoon in handgedrewe rolstoel',
    '👨‍🦽' => 'man in handgedrewe rolstoel',
    '👩‍🦽' => 'vrou in handgedrewe rolstoel',
    '🏃‍♂' => 'man hardloop',
    '🏃‍♀' => 'vrou hardloop',
    '🧑‍🩰' => 'balletdanser',
    '👯‍♂' => 'mans met haasore',
    '👯‍♀' => 'vroue met haasore',
    '🧖‍♂' => 'man in stoomkamer',
    '🧖‍♀' => 'vrou in stoomkamer',
    '🧗‍♂' => 'manlike rotsklimmer',
    '🧗‍♀' => 'vroulike rotsklimmer',
    '🏌‍♂' => 'manlike gholfspeler',
    '🏌‍♀' => 'vroulike gholfspeler',
    '🏄‍♂' => 'manlike branderplankryer',
    '🏄‍♀' => 'vroulike branderplankryer',
    '🚣‍♂' => 'man wat roei',
    '🚣‍♀' => 'vrou wat roei',
    '🏊‍♂' => 'manlike swemmer',
    '🏊‍♀' => 'vroulike swemmer',
    '⛹‍♂' => 'man hop bal',
    '⛹‍♀' => 'vrou hop bal',
    '🏋‍♂' => 'manlike gewigopteller',
    '🏋‍♀' => 'vroulike gewigopteller',
    '🚴‍♂' => 'manlike fietsryer',
    '🚴‍♀' => 'vroulike fietsryer',
    '🚵‍♂' => 'manlike bergfietsryer',
    '🚵‍♀' => 'vroulike bergfietsryer',
    '🤸‍♂' => 'man doen wawiel',
    '🤸‍♀' => 'vrou doen wawiel',
    '🤼‍♂' => 'manlike stoeiers',
    '🤼‍♀' => 'vroulike stoeiers',
    '🤽‍♂' => 'manlike waterpolospeler',
    '🤽‍♀' => 'vroulike waterpolospeler',
    '🤾‍♂' => 'manlike handbalspeler',
    '🤾‍♀' => 'vroulike handbalspeler',
    '🤹‍♂' => 'manlike jongleur',
    '🤹‍♀' => 'vroulike jongleur',
    '🧘‍♂' => 'man in lotusposisie',
    '🧘‍♀' => 'vrou in lotusposisie',
    '🧑‍🧒' => 'gesin: grootmens, kind',
    '🐕‍🦺' => 'dienshond',
    '🐈‍⬛' => 'swart kat',
    '🐻‍❄' => 'ysbeer',
    '🐦‍⬛' => 'swart voël',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'lemmetjie',
    '🍄‍🟫' => 'bruin sampioen',
    '⛓‍💥' => 'gebreekte ketting',
    '🏳‍🌈' => 'reënboogvlag',
    '🏳‍⚧' => 'transgendervlag',
    '🏴‍☠' => 'seerowervlag',
    '👋🏻' => 'wuiwende hand: ligte velkleur',
    '👋🏼' => 'wuiwende hand: medium-ligte velkleur',
    '👋🏽' => 'wuiwende hand: medium velkleur',
    '👋🏾' => 'wuiwende hand: medium-donker velkleur',
    '👋🏿' => 'wuiwende hand: donker velkleur',
    '🤚🏻' => 'handrug: ligte velkleur',
    '🤚🏼' => 'handrug: medium-ligte velkleur',
    '🤚🏽' => 'handrug: medium velkleur',
    '🤚🏾' => 'handrug: medium-donker velkleur',
    '🤚🏿' => 'handrug: donker velkleur',
    '🖐🏻' => 'hand in die lug met vingers oopgesprei: ligte velkleur',
    '🖐🏼' => 'hand in die lug met vingers oopgesprei: medium-ligte velkleur',
    '🖐🏽' => 'hand in die lug met vingers oopgesprei: medium velkleur',
    '🖐🏾' => 'hand in die lug met vingers oopgesprei: medium-donker velkleur',
    '🖐🏿' => 'hand in die lug met vingers oopgesprei: donker velkleur',
    '✋🏻' => 'hand in die lug: ligte velkleur',
    '✋🏼' => 'hand in die lug: medium-ligte velkleur',
    '✋🏽' => 'hand in die lug: medium velkleur',
    '✋🏾' => 'hand in die lug: medium-donker velkleur',
    '✋🏿' => 'hand in die lug: donker velkleur',
    '🖖🏻' => 'vulkansaluut: ligte velkleur',
    '🖖🏼' => 'vulkansaluut: medium-ligte velkleur',
    '🖖🏽' => 'vulkansaluut: medium velkleur',
    '🖖🏾' => 'vulkansaluut: medium-donker velkleur',
    '🖖🏿' => 'vulkansaluut: donker velkleur',
    '🫱🏻' => 'hand na regs: ligte velkleur',
    '🫱🏼' => 'hand na regs: medium-ligte velkleur',
    '🫱🏽' => 'hand na regs: medium velkleur',
    '🫱🏾' => 'hand na regs: medium-donker velkleur',
    '🫱🏿' => 'hand na regs: donker velkleur',
    '🫲🏻' => 'hand na links: ligte velkleur',
    '🫲🏼' => 'hand na links: medium-ligte velkleur',
    '🫲🏽' => 'hand na links: medium velkleur',
    '🫲🏾' => 'hand na links: medium-donker velkleur',
    '🫲🏿' => 'hand na links: donker velkleur',
    '🫳🏻' => 'hand met palm ondertoe: ligte velkleur',
    '🫳🏼' => 'hand met palm ondertoe: medium-ligte velkleur',
    '🫳🏽' => 'hand met palm ondertoe: medium velkleur',
    '🫳🏾' => 'hand met palm ondertoe: medium-donker velkleur',
    '🫳🏿' => 'hand met palm ondertoe: donker velkleur',
    '🫴🏻' => 'hand met palm boontoe: ligte velkleur',
    '🫴🏼' => 'hand met palm boontoe: medium-ligte velkleur',
    '🫴🏽' => 'hand met palm boontoe: medium velkleur',
    '🫴🏾' => 'hand met palm boontoe: medium-donker velkleur',
    '🫴🏿' => 'hand met palm boontoe: donker velkleur',
    '🫷🏻' => 'hand wat linkswaarts druk: ligte velkleur',
    '🫷🏼' => 'hand wat linkswaarts druk: medium-ligte velkleur',
    '🫷🏽' => 'hand wat linkswaarts druk: medium velkleur',
    '🫷🏾' => 'hand wat linkswaarts druk: medium-donker velkleur',
    '🫷🏿' => 'hand wat linkswaarts druk: donker velkleur',
    '🫸🏻' => 'regswaarts drukkende hand: ligte velkleur',
    '🫸🏼' => 'regswaarts drukkende hand: medium-ligte velkleur',
    '🫸🏽' => 'regswaarts drukkende hand: medium velkleur',
    '🫸🏾' => 'regswaarts drukkende hand: medium-donker velkleur',
    '🫸🏿' => 'regswaarts drukkende hand: donker velkleur',
    '👌🏻' => 'ok-handteken: ligte velkleur',
    '👌🏼' => 'ok-handteken: medium-ligte velkleur',
    '👌🏽' => 'ok-handteken: medium velkleur',
    '👌🏾' => 'ok-handteken: medium-donker velkleur',
    '👌🏿' => 'ok-handteken: donker velkleur',
    '🤌🏻' => 'vingerpunte saamgedruk: ligte velkleur',
    '🤌🏼' => 'vingerpunte saamgedruk: medium-ligte velkleur',
    '🤌🏽' => 'vingerpunte saamgedruk: medium velkleur',
    '🤌🏾' => 'vingerpunte saamgedruk: medium-donker velkleur',
    '🤌🏿' => 'vingerpunte saamgedruk: donker velkleur',
    '🤏🏻' => 'knypende hand: ligte velkleur',
    '🤏🏼' => 'knypende hand: medium-ligte velkleur',
    '🤏🏽' => 'knypende hand: medium velkleur',
    '🤏🏾' => 'knypende hand: medium-donker velkleur',
    '🤏🏿' => 'knypende hand: donker velkleur',
    '✌🏻' => 'oorwinninghandteken: ligte velkleur',
    '✌🏼' => 'oorwinninghandteken: medium-ligte velkleur',
    '✌🏽' => 'oorwinninghandteken: medium velkleur',
    '✌🏾' => 'oorwinninghandteken: medium-donker velkleur',
    '✌🏿' => 'oorwinninghandteken: donker velkleur',
    '🤞🏻' => 'duim vashou: ligte velkleur',
    '🤞🏼' => 'duim vashou: medium-ligte velkleur',
    '🤞🏽' => 'duim vashou: medium velkleur',
    '🤞🏾' => 'duim vashou: medium-donker velkleur',
    '🤞🏿' => 'duim vashou: donker velkleur',
    '🫰🏻' => 'hand met duim en wysvinger gekruis: ligte velkleur',
    '🫰🏼' => 'hand met duim en wysvinger gekruis: medium-ligte velkleur',
    '🫰🏽' => 'hand met duim en wysvinger gekruis: medium velkleur',
    '🫰🏾' => 'hand met duim en wysvinger gekruis: medium-donker velkleur',
    '🫰🏿' => 'hand met duim en wysvinger gekruis: donker velkleur',
    '🤟🏻' => 'lief-vir-jou-gebaar: ligte velkleur',
    '🤟🏼' => 'lief-vir-jou-gebaar: medium-ligte velkleur',
    '🤟🏽' => 'lief-vir-jou-gebaar: medium velkleur',
    '🤟🏾' => 'lief-vir-jou-gebaar: medium-donker velkleur',
    '🤟🏿' => 'lief-vir-jou-gebaar: donker velkleur',
    '🤘🏻' => 'horingteken: ligte velkleur',
    '🤘🏼' => 'horingteken: medium-ligte velkleur',
    '🤘🏽' => 'horingteken: medium velkleur',
    '🤘🏾' => 'horingteken: medium-donker velkleur',
    '🤘🏿' => 'horingteken: donker velkleur',
    '🤙🏻' => 'bel my hand: ligte velkleur',
    '🤙🏼' => 'bel my hand: medium-ligte velkleur',
    '🤙🏽' => 'bel my hand: medium velkleur',
    '🤙🏾' => 'bel my hand: medium-donker velkleur',
    '🤙🏿' => 'bel my hand: donker velkleur',
    '👈🏻' => 'wysvingerrughand wat links wys: ligte velkleur',
    '👈🏼' => 'wysvingerrughand wat links wys: medium-ligte velkleur',
    '👈🏽' => 'wysvingerrughand wat links wys: medium velkleur',
    '👈🏾' => 'wysvingerrughand wat links wys: medium-donker velkleur',
    '👈🏿' => 'wysvingerrughand wat links wys: donker velkleur',
    '👉🏻' => 'wysvingerrughand wat regs wys: ligte velkleur',
    '👉🏼' => 'wysvingerrughand wat regs wys: medium-ligte velkleur',
    '👉🏽' => 'wysvingerrughand wat regs wys: medium velkleur',
    '👉🏾' => 'wysvingerrughand wat regs wys: medium-donker velkleur',
    '👉🏿' => 'wysvingerrughand wat regs wys: donker velkleur',
    '👆🏻' => 'wysvingerrughand wat op wys: ligte velkleur',
    '👆🏼' => 'wysvingerrughand wat op wys: medium-ligte velkleur',
    '👆🏽' => 'wysvingerrughand wat op wys: medium velkleur',
    '👆🏾' => 'wysvingerrughand wat op wys: medium-donker velkleur',
    '👆🏿' => 'wysvingerrughand wat op wys: donker velkleur',
    '🖕🏻' => 'middelvinger: ligte velkleur',
    '🖕🏼' => 'middelvinger: medium-ligte velkleur',
    '🖕🏽' => 'middelvinger: medium velkleur',
    '🖕🏾' => 'middelvinger: medium-donker velkleur',
    '🖕🏿' => 'middelvinger: donker velkleur',
    '👇🏻' => 'wysvingerrughand wat af wys: ligte velkleur',
    '👇🏼' => 'wysvingerrughand wat af wys: medium-ligte velkleur',
    '👇🏽' => 'wysvingerrughand wat af wys: medium velkleur',
    '👇🏾' => 'wysvingerrughand wat af wys: medium-donker velkleur',
    '👇🏿' => 'wysvingerrughand wat af wys: donker velkleur',
    '☝🏻' => 'wysvinger wat op wys: ligte velkleur',
    '☝🏼' => 'wysvinger wat op wys: medium-ligte velkleur',
    '☝🏽' => 'wysvinger wat op wys: medium velkleur',
    '☝🏾' => 'wysvinger wat op wys: medium-donker velkleur',
    '☝🏿' => 'wysvinger wat op wys: donker velkleur',
    '🫵🏻' => 'wysvinger na kyker: ligte velkleur',
    '🫵🏼' => 'wysvinger na kyker: medium-ligte velkleur',
    '🫵🏽' => 'wysvinger na kyker: medium velkleur',
    '🫵🏾' => 'wysvinger na kyker: medium-donker velkleur',
    '🫵🏿' => 'wysvinger na kyker: donker velkleur',
    '👍🏻' => 'laaik baie: ligte velkleur',
    '👍🏼' => 'laaik baie: medium-ligte velkleur',
    '👍🏽' => 'laaik baie: medium velkleur',
    '👍🏾' => 'laaik baie: medium-donker velkleur',
    '👍🏿' => 'laaik baie: donker velkleur',
    '👎🏻' => 'laaik niks: ligte velkleur',
    '👎🏼' => 'laaik niks: medium-ligte velkleur',
    '👎🏽' => 'laaik niks: medium velkleur',
    '👎🏾' => 'laaik niks: medium-donker velkleur',
    '👎🏿' => 'laaik niks: donker velkleur',
    '✊🏻' => 'vuis in die lug: ligte velkleur',
    '✊🏼' => 'vuis in die lug: medium-ligte velkleur',
    '✊🏽' => 'vuis in die lug: medium velkleur',
    '✊🏾' => 'vuis in die lug: medium-donker velkleur',
    '✊🏿' => 'vuis in die lug: donker velkleur',
    '👊🏻' => 'vuishou: ligte velkleur',
    '👊🏼' => 'vuishou: medium-ligte velkleur',
    '👊🏽' => 'vuishou: medium velkleur',
    '👊🏾' => 'vuishou: medium-donker velkleur',
    '👊🏿' => 'vuishou: donker velkleur',
    '🤛🏻' => 'vuis links: ligte velkleur',
    '🤛🏼' => 'vuis links: medium-ligte velkleur',
    '🤛🏽' => 'vuis links: medium velkleur',
    '🤛🏾' => 'vuis links: medium-donker velkleur',
    '🤛🏿' => 'vuis links: donker velkleur',
    '🤜🏻' => 'vuis regs: ligte velkleur',
    '🤜🏼' => 'vuis regs: medium-ligte velkleur',
    '🤜🏽' => 'vuis regs: medium velkleur',
    '🤜🏾' => 'vuis regs: medium-donker velkleur',
    '🤜🏿' => 'vuis regs: donker velkleur',
    '👏🏻' => 'handeklap: ligte velkleur',
    '👏🏼' => 'handeklap: medium-ligte velkleur',
    '👏🏽' => 'handeklap: medium velkleur',
    '👏🏾' => 'handeklap: medium-donker velkleur',
    '👏🏿' => 'handeklap: donker velkleur',
    '🙌🏻' => 'persoon met hande in die lug: ligte velkleur',
    '🙌🏼' => 'persoon met hande in die lug: medium-ligte velkleur',
    '🙌🏽' => 'persoon met hande in die lug: medium velkleur',
    '🙌🏾' => 'persoon met hande in die lug: medium-donker velkleur',
    '🙌🏿' => 'persoon met hande in die lug: donker velkleur',
    '🫶🏻' => 'handhartjie: ligte velkleur',
    '🫶🏼' => 'handhartjie: medium-ligte velkleur',
    '🫶🏽' => 'handhartjie: medium velkleur',
    '🫶🏾' => 'handhartjie: medium-donker velkleur',
    '🫶🏿' => 'handhartjie: donker velkleur',
    '👐🏻' => 'oop hande: ligte velkleur',
    '👐🏼' => 'oop hande: medium-ligte velkleur',
    '👐🏽' => 'oop hande: medium velkleur',
    '👐🏾' => 'oop hande: medium-donker velkleur',
    '👐🏿' => 'oop hande: donker velkleur',
    '🤲🏻' => 'palms op teen mekaar: ligte velkleur',
    '🤲🏼' => 'palms op teen mekaar: medium-ligte velkleur',
    '🤲🏽' => 'palms op teen mekaar: medium velkleur',
    '🤲🏾' => 'palms op teen mekaar: medium-donker velkleur',
    '🤲🏿' => 'palms op teen mekaar: donker velkleur',
    '🤝🏻' => 'handskud: ligte velkleur',
    '🤝🏼' => 'handskud: medium-ligte velkleur',
    '🤝🏽' => 'handskud: medium velkleur',
    '🤝🏾' => 'handskud: medium-donker velkleur',
    '🤝🏿' => 'handskud: donker velkleur',
    '🙏🏻' => 'gevoude hande: ligte velkleur',
    '🙏🏼' => 'gevoude hande: medium-ligte velkleur',
    '🙏🏽' => 'gevoude hande: medium velkleur',
    '🙏🏾' => 'gevoude hande: medium-donker velkleur',
    '🙏🏿' => 'gevoude hande: donker velkleur',
    '✍🏻' => 'hand wat skryf: ligte velkleur',
    '✍🏼' => 'hand wat skryf: medium-ligte velkleur',
    '✍🏽' => 'hand wat skryf: medium velkleur',
    '✍🏾' => 'hand wat skryf: medium-donker velkleur',
    '✍🏿' => 'hand wat skryf: donker velkleur',
    '💅🏻' => 'naellak: ligte velkleur',
    '💅🏼' => 'naellak: medium-ligte velkleur',
    '💅🏽' => 'naellak: medium velkleur',
    '💅🏾' => 'naellak: medium-donker velkleur',
    '💅🏿' => 'naellak: donker velkleur',
    '🤳🏻' => 'selfie: ligte velkleur',
    '🤳🏼' => 'selfie: medium-ligte velkleur',
    '🤳🏽' => 'selfie: medium velkleur',
    '🤳🏾' => 'selfie: medium-donker velkleur',
    '🤳🏿' => 'selfie: donker velkleur',
    '💪🏻' => 'gebulte biseps: ligte velkleur',
    '💪🏼' => 'gebulte biseps: medium-ligte velkleur',
    '💪🏽' => 'gebulte biseps: medium velkleur',
    '💪🏾' => 'gebulte biseps: medium-donker velkleur',
    '💪🏿' => 'gebulte biseps: donker velkleur',
    '🦵🏻' => 'been: ligte velkleur',
    '🦵🏼' => 'been: medium-ligte velkleur',
    '🦵🏽' => 'been: medium velkleur',
    '🦵🏾' => 'been: medium-donker velkleur',
    '🦵🏿' => 'been: donker velkleur',
    '🦶🏻' => 'voet: ligte velkleur',
    '🦶🏼' => 'voet: medium-ligte velkleur',
    '🦶🏽' => 'voet: medium velkleur',
    '🦶🏾' => 'voet: medium-donker velkleur',
    '🦶🏿' => 'voet: donker velkleur',
    '👂🏻' => 'oor: ligte velkleur',
    '👂🏼' => 'oor: medium-ligte velkleur',
    '👂🏽' => 'oor: medium velkleur',
    '👂🏾' => 'oor: medium-donker velkleur',
    '👂🏿' => 'oor: donker velkleur',
    '🦻🏻' => 'oor met gehoorapparaat: ligte velkleur',
    '🦻🏼' => 'oor met gehoorapparaat: medium-ligte velkleur',
    '🦻🏽' => 'oor met gehoorapparaat: medium velkleur',
    '🦻🏾' => 'oor met gehoorapparaat: medium-donker velkleur',
    '🦻🏿' => 'oor met gehoorapparaat: donker velkleur',
    '👃🏻' => 'neus: ligte velkleur',
    '👃🏼' => 'neus: medium-ligte velkleur',
    '👃🏽' => 'neus: medium velkleur',
    '👃🏾' => 'neus: medium-donker velkleur',
    '👃🏿' => 'neus: donker velkleur',
    '👶🏻' => 'baba: ligte velkleur',
    '👶🏼' => 'baba: medium-ligte velkleur',
    '👶🏽' => 'baba: medium velkleur',
    '👶🏾' => 'baba: medium-donker velkleur',
    '👶🏿' => 'baba: donker velkleur',
    '🧒🏻' => 'kind: ligte velkleur',
    '🧒🏼' => 'kind: medium-ligte velkleur',
    '🧒🏽' => 'kind: medium velkleur',
    '🧒🏾' => 'kind: medium-donker velkleur',
    '🧒🏿' => 'kind: donker velkleur',
    '👦🏻' => 'seun: ligte velkleur',
    '👦🏼' => 'seun: medium-ligte velkleur',
    '👦🏽' => 'seun: medium velkleur',
    '👦🏾' => 'seun: medium-donker velkleur',
    '👦🏿' => 'seun: donker velkleur',
    '👧🏻' => 'meisie: ligte velkleur',
    '👧🏼' => 'meisie: medium-ligte velkleur',
    '👧🏽' => 'meisie: medium velkleur',
    '👧🏾' => 'meisie: medium-donker velkleur',
    '👧🏿' => 'meisie: donker velkleur',
    '🧑🏻' => 'volwassene: ligte velkleur',
    '🧑🏼' => 'volwassene: medium-ligte velkleur',
    '🧑🏽' => 'volwassene: medium velkleur',
    '🧑🏾' => 'volwassene: medium-donker velkleur',
    '🧑🏿' => 'volwassene: donker velkleur',
    '👱🏻' => 'persoon met blonde hare: ligte velkleur',
    '👱🏼' => 'persoon met blonde hare: medium-ligte velkleur',
    '👱🏽' => 'persoon met blonde hare: medium velkleur',
    '👱🏾' => 'persoon met blonde hare: medium-donker velkleur',
    '👱🏿' => 'persoon met blonde hare: donker velkleur',
    '👨🏻' => 'man: ligte velkleur',
    '👨🏼' => 'man: medium-ligte velkleur',
    '👨🏽' => 'man: medium velkleur',
    '👨🏾' => 'man: medium-donker velkleur',
    '👨🏿' => 'man: donker velkleur',
    '🧔🏻' => 'bebaarde persoon: ligte velkleur',
    '🧔🏼' => 'bebaarde persoon: medium-ligte velkleur',
    '🧔🏽' => 'bebaarde persoon: medium velkleur',
    '🧔🏾' => 'bebaarde persoon: medium-donker velkleur',
    '🧔🏿' => 'bebaarde persoon: donker velkleur',
    '👩🏻' => 'vrou: ligte velkleur',
    '👩🏼' => 'vrou: medium-ligte velkleur',
    '👩🏽' => 'vrou: medium velkleur',
    '👩🏾' => 'vrou: medium-donker velkleur',
    '👩🏿' => 'vrou: donker velkleur',
    '🧓🏻' => 'ouer volwassene: ligte velkleur',
    '🧓🏼' => 'ouer volwassene: medium-ligte velkleur',
    '🧓🏽' => 'ouer volwassene: medium velkleur',
    '🧓🏾' => 'ouer volwassene: medium-donker velkleur',
    '🧓🏿' => 'ouer volwassene: donker velkleur',
    '👴🏻' => 'ou man: ligte velkleur',
    '👴🏼' => 'ou man: medium-ligte velkleur',
    '👴🏽' => 'ou man: medium velkleur',
    '👴🏾' => 'ou man: medium-donker velkleur',
    '👴🏿' => 'ou man: donker velkleur',
    '👵🏻' => 'ou vrou: ligte velkleur',
    '👵🏼' => 'ou vrou: medium-ligte velkleur',
    '👵🏽' => 'ou vrou: medium velkleur',
    '👵🏾' => 'ou vrou: medium-donker velkleur',
    '👵🏿' => 'ou vrou: donker velkleur',
    '🙍🏻' => 'persoon wat frons: ligte velkleur',
    '🙍🏼' => 'persoon wat frons: medium-ligte velkleur',
    '🙍🏽' => 'persoon wat frons: medium velkleur',
    '🙍🏾' => 'persoon wat frons: medium-donker velkleur',
    '🙍🏿' => 'persoon wat frons: donker velkleur',
    '🙎🏻' => 'dikbek persoon: ligte velkleur',
    '🙎🏼' => 'dikbek persoon: medium-ligte velkleur',
    '🙎🏽' => 'dikbek persoon: medium velkleur',
    '🙎🏾' => 'dikbek persoon: medium-donker velkleur',
    '🙎🏿' => 'dikbek persoon: donker velkleur',
    '🙅🏻' => 'persoon wat NEE wys: ligte velkleur',
    '🙅🏼' => 'persoon wat NEE wys: medium-ligte velkleur',
    '🙅🏽' => 'persoon wat NEE wys: medium velkleur',
    '🙅🏾' => 'persoon wat NEE wys: medium-donker velkleur',
    '🙅🏿' => 'persoon wat NEE wys: donker velkleur',
    '🙆🏻' => 'persoon wys als is goed: ligte velkleur',
    '🙆🏼' => 'persoon wys als is goed: medium-ligte velkleur',
    '🙆🏽' => 'persoon wys als is goed: medium velkleur',
    '🙆🏾' => 'persoon wys als is goed: medium-donker velkleur',
    '🙆🏿' => 'persoon wys als is goed: donker velkleur',
    '💁🏻' => 'persoon hou hand geknak: ligte velkleur',
    '💁🏼' => 'persoon hou hand geknak: medium-ligte velkleur',
    '💁🏽' => 'persoon hou hand geknak: medium velkleur',
    '💁🏾' => 'persoon hou hand geknak: medium-donker velkleur',
    '💁🏿' => 'persoon hou hand geknak: donker velkleur',
    '🙋🏻' => 'persoon wat hand opsteek: ligte velkleur',
    '🙋🏼' => 'persoon wat hand opsteek: medium-ligte velkleur',
    '🙋🏽' => 'persoon wat hand opsteek: medium velkleur',
    '🙋🏾' => 'persoon wat hand opsteek: medium-donker velkleur',
    '🙋🏿' => 'persoon wat hand opsteek: donker velkleur',
    '🧏🏻' => 'dowe persoon: ligte velkleur',
    '🧏🏼' => 'dowe persoon: medium-ligte velkleur',
    '🧏🏽' => 'dowe persoon: medium velkleur',
    '🧏🏾' => 'dowe persoon: medium-donker velkleur',
    '🧏🏿' => 'dowe persoon: donker velkleur',
    '🙇🏻' => 'persoon wat buig: ligte velkleur',
    '🙇🏼' => 'persoon wat buig: medium-ligte velkleur',
    '🙇🏽' => 'persoon wat buig: medium velkleur',
    '🙇🏾' => 'persoon wat buig: medium-donker velkleur',
    '🙇🏿' => 'persoon wat buig: donker velkleur',
    '🤦🏻' => 'hand teen voorkop slaan: ligte velkleur',
    '🤦🏼' => 'hand teen voorkop slaan: medium-ligte velkleur',
    '🤦🏽' => 'hand teen voorkop slaan: medium velkleur',
    '🤦🏾' => 'hand teen voorkop slaan: medium-donker velkleur',
    '🤦🏿' => 'hand teen voorkop slaan: donker velkleur',
    '🤷🏻' => 'persoon skouerophaal: ligte velkleur',
    '🤷🏼' => 'persoon skouerophaal: medium-ligte velkleur',
    '🤷🏽' => 'persoon skouerophaal: medium velkleur',
    '🤷🏾' => 'persoon skouerophaal: medium-donker velkleur',
    '🤷🏿' => 'persoon skouerophaal: donker velkleur',
    '👮🏻' => 'polisiebeampte: ligte velkleur',
    '👮🏼' => 'polisiebeampte: medium-ligte velkleur',
    '👮🏽' => 'polisiebeampte: medium velkleur',
    '👮🏾' => 'polisiebeampte: medium-donker velkleur',
    '👮🏿' => 'polisiebeampte: donker velkleur',
    '🕵🏻' => 'speurder: ligte velkleur',
    '🕵🏼' => 'speurder: medium-ligte velkleur',
    '🕵🏽' => 'speurder: medium velkleur',
    '🕵🏾' => 'speurder: medium-donker velkleur',
    '🕵🏿' => 'speurder: donker velkleur',
    '💂🏻' => 'gardeoffisier: ligte velkleur',
    '💂🏼' => 'gardeoffisier: medium-ligte velkleur',
    '💂🏽' => 'gardeoffisier: medium velkleur',
    '💂🏾' => 'gardeoffisier: medium-donker velkleur',
    '💂🏿' => 'gardeoffisier: donker velkleur',
    '🥷🏻' => 'ninja: ligte velkleur',
    '🥷🏼' => 'ninja: medium-ligte velkleur',
    '🥷🏽' => 'ninja: medium velkleur',
    '🥷🏾' => 'ninja: medium-donker velkleur',
    '🥷🏿' => 'ninja: donker velkleur',
    '👷🏻' => 'konstruksiewerker: ligte velkleur',
    '👷🏼' => 'konstruksiewerker: medium-ligte velkleur',
    '👷🏽' => 'konstruksiewerker: medium velkleur',
    '👷🏾' => 'konstruksiewerker: medium-donker velkleur',
    '👷🏿' => 'konstruksiewerker: donker velkleur',
    '🫅🏻' => 'persoon met kroon: ligte velkleur',
    '🫅🏼' => 'persoon met kroon: medium-ligte velkleur',
    '🫅🏽' => 'persoon met kroon: medium velkleur',
    '🫅🏾' => 'persoon met kroon: medium-donker velkleur',
    '🫅🏿' => 'persoon met kroon: donker velkleur',
    '🤴🏻' => 'prins: ligte velkleur',
    '🤴🏼' => 'prins: medium-ligte velkleur',
    '🤴🏽' => 'prins: medium velkleur',
    '🤴🏾' => 'prins: medium-donker velkleur',
    '🤴🏿' => 'prins: donker velkleur',
    '👸🏻' => 'prinses: ligte velkleur',
    '👸🏼' => 'prinses: medium-ligte velkleur',
    '👸🏽' => 'prinses: medium velkleur',
    '👸🏾' => 'prinses: medium-donker velkleur',
    '👸🏿' => 'prinses: donker velkleur',
    '👳🏻' => 'persoon met tulband: ligte velkleur',
    '👳🏼' => 'persoon met tulband: medium-ligte velkleur',
    '👳🏽' => 'persoon met tulband: medium velkleur',
    '👳🏾' => 'persoon met tulband: medium-donker velkleur',
    '👳🏿' => 'persoon met tulband: donker velkleur',
    '👲🏻' => 'man met mus: ligte velkleur',
    '👲🏼' => 'man met mus: medium-ligte velkleur',
    '👲🏽' => 'man met mus: medium velkleur',
    '👲🏾' => 'man met mus: medium-donker velkleur',
    '👲🏿' => 'man met mus: donker velkleur',
    '🧕🏻' => 'vrou met kopdoek: ligte velkleur',
    '🧕🏼' => 'vrou met kopdoek: medium-ligte velkleur',
    '🧕🏽' => 'vrou met kopdoek: medium velkleur',
    '🧕🏾' => 'vrou met kopdoek: medium-donker velkleur',
    '🧕🏿' => 'vrou met kopdoek: donker velkleur',
    '🤵🏻' => 'persoon in pak: ligte velkleur',
    '🤵🏼' => 'persoon in pak: medium-ligte velkleur',
    '🤵🏽' => 'persoon in pak: medium velkleur',
    '🤵🏾' => 'persoon in pak: medium-donker velkleur',
    '🤵🏿' => 'persoon in pak: donker velkleur',
    '👰🏻' => 'persoon met sluier: ligte velkleur',
    '👰🏼' => 'persoon met sluier: medium-ligte velkleur',
    '👰🏽' => 'persoon met sluier: medium velkleur',
    '👰🏾' => 'persoon met sluier: medium-donker velkleur',
    '👰🏿' => 'persoon met sluier: donker velkleur',
    '🤰🏻' => 'swanger vrou: ligte velkleur',
    '🤰🏼' => 'swanger vrou: medium-ligte velkleur',
    '🤰🏽' => 'swanger vrou: medium velkleur',
    '🤰🏾' => 'swanger vrou: medium-donker velkleur',
    '🤰🏿' => 'swanger vrou: donker velkleur',
    '🫃🏻' => 'swanger man: ligte velkleur',
    '🫃🏼' => 'swanger man: medium-ligte velkleur',
    '🫃🏽' => 'swanger man: medium velkleur',
    '🫃🏾' => 'swanger man: medium-donker velkleur',
    '🫃🏿' => 'swanger man: donker velkleur',
    '🫄🏻' => 'swanger persoon: ligte velkleur',
    '🫄🏼' => 'swanger persoon: medium-ligte velkleur',
    '🫄🏽' => 'swanger persoon: medium velkleur',
    '🫄🏾' => 'swanger persoon: medium-donker velkleur',
    '🫄🏿' => 'swanger persoon: donker velkleur',
    '🤱🏻' => 'borsvoed: ligte velkleur',
    '🤱🏼' => 'borsvoed: medium-ligte velkleur',
    '🤱🏽' => 'borsvoed: medium velkleur',
    '🤱🏾' => 'borsvoed: medium-donker velkleur',
    '🤱🏿' => 'borsvoed: donker velkleur',
    '👼🏻' => 'baba-engel: ligte velkleur',
    '👼🏼' => 'baba-engel: medium-ligte velkleur',
    '👼🏽' => 'baba-engel: medium velkleur',
    '👼🏾' => 'baba-engel: medium-donker velkleur',
    '👼🏿' => 'baba-engel: donker velkleur',
    '🎅🏻' => 'Kersvader: ligte velkleur',
    '🎅🏼' => 'Kersvader: medium-ligte velkleur',
    '🎅🏽' => 'Kersvader: medium velkleur',
    '🎅🏾' => 'Kersvader: medium-donker velkleur',
    '🎅🏿' => 'Kersvader: donker velkleur',
    '🤶🏻' => 'Moeder Kersfees: ligte velkleur',
    '🤶🏼' => 'Moeder Kersfees: medium-ligte velkleur',
    '🤶🏽' => 'Moeder Kersfees: medium velkleur',
    '🤶🏾' => 'Moeder Kersfees: medium-donker velkleur',
    '🤶🏿' => 'Moeder Kersfees: donker velkleur',
    '🦸🏻' => 'superheld: ligte velkleur',
    '🦸🏼' => 'superheld: medium-ligte velkleur',
    '🦸🏽' => 'superheld: medium velkleur',
    '🦸🏾' => 'superheld: medium-donker velkleur',
    '🦸🏿' => 'superheld: donker velkleur',
    '🦹🏻' => 'superskurk: ligte velkleur',
    '🦹🏼' => 'superskurk: medium-ligte velkleur',
    '🦹🏽' => 'superskurk: medium velkleur',
    '🦹🏾' => 'superskurk: medium-donker velkleur',
    '🦹🏿' => 'superskurk: donker velkleur',
    '🧙🏻' => 'magus: ligte velkleur',
    '🧙🏼' => 'magus: medium-ligte velkleur',
    '🧙🏽' => 'magus: medium velkleur',
    '🧙🏾' => 'magus: medium-donker velkleur',
    '🧙🏿' => 'magus: donker velkleur',
    '🧚🏻' => 'feetjie: ligte velkleur',
    '🧚🏼' => 'feetjie: medium-ligte velkleur',
    '🧚🏽' => 'feetjie: medium velkleur',
    '🧚🏾' => 'feetjie: medium-donker velkleur',
    '🧚🏿' => 'feetjie: donker velkleur',
    '🧛🏻' => 'vampier: ligte velkleur',
    '🧛🏼' => 'vampier: medium-ligte velkleur',
    '🧛🏽' => 'vampier: medium velkleur',
    '🧛🏾' => 'vampier: medium-donker velkleur',
    '🧛🏿' => 'vampier: donker velkleur',
    '🧜🏻' => 'meerpersoon: ligte velkleur',
    '🧜🏼' => 'meerpersoon: medium-ligte velkleur',
    '🧜🏽' => 'meerpersoon: medium velkleur',
    '🧜🏾' => 'meerpersoon: medium-donker velkleur',
    '🧜🏿' => 'meerpersoon: donker velkleur',
    '🧝🏻' => 'elf: ligte velkleur',
    '🧝🏼' => 'elf: medium-ligte velkleur',
    '🧝🏽' => 'elf: medium velkleur',
    '🧝🏾' => 'elf: medium-donker velkleur',
    '🧝🏿' => 'elf: donker velkleur',
    '💆🏻' => 'persoon kry massering: ligte velkleur',
    '💆🏼' => 'persoon kry massering: medium-ligte velkleur',
    '💆🏽' => 'persoon kry massering: medium velkleur',
    '💆🏾' => 'persoon kry massering: medium-donker velkleur',
    '💆🏿' => 'persoon kry massering: donker velkleur',
    '💇🏻' => 'haarsny: ligte velkleur',
    '💇🏼' => 'haarsny: medium-ligte velkleur',
    '💇🏽' => 'haarsny: medium velkleur',
    '💇🏾' => 'haarsny: medium-donker velkleur',
    '💇🏿' => 'haarsny: donker velkleur',
    '🚶🏻' => 'voetganger: ligte velkleur',
    '🚶🏼' => 'voetganger: medium-ligte velkleur',
    '🚶🏽' => 'voetganger: medium velkleur',
    '🚶🏾' => 'voetganger: medium-donker velkleur',
    '🚶🏿' => 'voetganger: donker velkleur',
    '🧍🏻' => 'persoon wat staan: ligte velkleur',
    '🧍🏼' => 'persoon wat staan: medium-ligte velkleur',
    '🧍🏽' => 'persoon wat staan: medium velkleur',
    '🧍🏾' => 'persoon wat staan: medium-donker velkleur',
    '🧍🏿' => 'persoon wat staan: donker velkleur',
    '🧎🏻' => 'persoon wat kniel: ligte velkleur',
    '🧎🏼' => 'persoon wat kniel: medium-ligte velkleur',
    '🧎🏽' => 'persoon wat kniel: medium velkleur',
    '🧎🏾' => 'persoon wat kniel: medium-donker velkleur',
    '🧎🏿' => 'persoon wat kniel: donker velkleur',
    '🏃🏻' => 'persoon wat hardloop: ligte velkleur',
    '🏃🏼' => 'persoon wat hardloop: medium-ligte velkleur',
    '🏃🏽' => 'persoon wat hardloop: medium velkleur',
    '🏃🏾' => 'persoon wat hardloop: medium-donker velkleur',
    '🏃🏿' => 'persoon wat hardloop: donker velkleur',
    '💃🏻' => 'vrou dans: ligte velkleur',
    '💃🏼' => 'vrou dans: medium-ligte velkleur',
    '💃🏽' => 'vrou dans: medium velkleur',
    '💃🏾' => 'vrou dans: medium-donker velkleur',
    '💃🏿' => 'vrou dans: donker velkleur',
    '🕺🏻' => 'man dans: ligte velkleur',
    '🕺🏼' => 'man dans: medium-ligte velkleur',
    '🕺🏽' => 'man dans: medium velkleur',
    '🕺🏾' => 'man dans: medium-donker velkleur',
    '🕺🏿' => 'man dans: donker velkleur',
    '🕴🏻' => 'man in sakepak wat sweef: ligte velkleur',
    '🕴🏼' => 'man in sakepak wat sweef: medium-ligte velkleur',
    '🕴🏽' => 'man in sakepak wat sweef: medium velkleur',
    '🕴🏾' => 'man in sakepak wat sweef: medium-donker velkleur',
    '🕴🏿' => 'man in sakepak wat sweef: donker velkleur',
    '👯🏻' => 'mense met haasore: ligte velkleur',
    '👯🏼' => 'mense met haasore: medium-ligte velkleur',
    '👯🏽' => 'mense met haasore: medium velkleur',
    '👯🏾' => 'mense met haasore: medium-donker velkleur',
    '👯🏿' => 'mense met haasore: donker velkleur',
    '🧖🏻' => 'persoon in stoomkamer: ligte velkleur',
    '🧖🏼' => 'persoon in stoomkamer: medium-ligte velkleur',
    '🧖🏽' => 'persoon in stoomkamer: medium velkleur',
    '🧖🏾' => 'persoon in stoomkamer: medium-donker velkleur',
    '🧖🏿' => 'persoon in stoomkamer: donker velkleur',
    '🧗🏻' => 'persoon wat rotsklim: ligte velkleur',
    '🧗🏼' => 'persoon wat rotsklim: medium-ligte velkleur',
    '🧗🏽' => 'persoon wat rotsklim: medium velkleur',
    '🧗🏾' => 'persoon wat rotsklim: medium-donker velkleur',
    '🧗🏿' => 'persoon wat rotsklim: donker velkleur',
    '🏇🏻' => 'perdewedrenne: ligte velkleur',
    '🏇🏼' => 'perdewedrenne: medium-ligte velkleur',
    '🏇🏽' => 'perdewedrenne: medium velkleur',
    '🏇🏾' => 'perdewedrenne: medium-donker velkleur',
    '🏇🏿' => 'perdewedrenne: donker velkleur',
    '🏂🏻' => 'sneeuplankryer: ligte velkleur',
    '🏂🏼' => 'sneeuplankryer: medium-ligte velkleur',
    '🏂🏽' => 'sneeuplankryer: medium velkleur',
    '🏂🏾' => 'sneeuplankryer: medium-donker velkleur',
    '🏂🏿' => 'sneeuplankryer: donker velkleur',
    '🏌🏻' => 'gholfspeler: ligte velkleur',
    '🏌🏼' => 'gholfspeler: medium-ligte velkleur',
    '🏌🏽' => 'gholfspeler: medium velkleur',
    '🏌🏾' => 'gholfspeler: medium-donker velkleur',
    '🏌🏿' => 'gholfspeler: donker velkleur',
    '🏄🏻' => 'branderplankryer: ligte velkleur',
    '🏄🏼' => 'branderplankryer: medium-ligte velkleur',
    '🏄🏽' => 'branderplankryer: medium velkleur',
    '🏄🏾' => 'branderplankryer: medium-donker velkleur',
    '🏄🏿' => 'branderplankryer: donker velkleur',
    '🚣🏻' => 'persoon in roeiboot: ligte velkleur',
    '🚣🏼' => 'persoon in roeiboot: medium-ligte velkleur',
    '🚣🏽' => 'persoon in roeiboot: medium velkleur',
    '🚣🏾' => 'persoon in roeiboot: medium-donker velkleur',
    '🚣🏿' => 'persoon in roeiboot: donker velkleur',
    '🏊🏻' => 'swemmer: ligte velkleur',
    '🏊🏼' => 'swemmer: medium-ligte velkleur',
    '🏊🏽' => 'swemmer: medium velkleur',
    '🏊🏾' => 'swemmer: medium-donker velkleur',
    '🏊🏿' => 'swemmer: donker velkleur',
    '⛹🏻' => 'persoon hop bal: ligte velkleur',
    '⛹🏼' => 'persoon hop bal: medium-ligte velkleur',
    '⛹🏽' => 'persoon hop bal: medium velkleur',
    '⛹🏾' => 'persoon hop bal: medium-donker velkleur',
    '⛹🏿' => 'persoon hop bal: donker velkleur',
    '🏋🏻' => 'gewigopteller: ligte velkleur',
    '🏋🏼' => 'gewigopteller: medium-ligte velkleur',
    '🏋🏽' => 'gewigopteller: medium velkleur',
    '🏋🏾' => 'gewigopteller: medium-donker velkleur',
    '🏋🏿' => 'gewigopteller: donker velkleur',
    '🚴🏻' => 'fietsryer: ligte velkleur',
    '🚴🏼' => 'fietsryer: medium-ligte velkleur',
    '🚴🏽' => 'fietsryer: medium velkleur',
    '🚴🏾' => 'fietsryer: medium-donker velkleur',
    '🚴🏿' => 'fietsryer: donker velkleur',
    '🚵🏻' => 'bergfietsryer: ligte velkleur',
    '🚵🏼' => 'bergfietsryer: medium-ligte velkleur',
    '🚵🏽' => 'bergfietsryer: medium velkleur',
    '🚵🏾' => 'bergfietsryer: medium-donker velkleur',
    '🚵🏿' => 'bergfietsryer: donker velkleur',
    '🤸🏻' => 'persoon wat ‘n wawiel doen: ligte velkleur',
    '🤸🏼' => 'persoon wat ‘n wawiel doen: medium-ligte velkleur',
    '🤸🏽' => 'persoon wat ‘n wawiel doen: medium velkleur',
    '🤸🏾' => 'persoon wat ‘n wawiel doen: medium-donker velkleur',
    '🤸🏿' => 'persoon wat ‘n wawiel doen: donker velkleur',
    '🤼🏻' => 'stoeiers: ligte velkleur',
    '🤼🏼' => 'stoeiers: medium-ligte velkleur',
    '🤼🏽' => 'stoeiers: medium velkleur',
    '🤼🏾' => 'stoeiers: medium-donker velkleur',
    '🤼🏿' => 'stoeiers: donker velkleur',
    '🤽🏻' => 'waterpolo: ligte velkleur',
    '🤽🏼' => 'waterpolo: medium-ligte velkleur',
    '🤽🏽' => 'waterpolo: medium velkleur',
    '🤽🏾' => 'waterpolo: medium-donker velkleur',
    '🤽🏿' => 'waterpolo: donker velkleur',
    '🤾🏻' => 'persoon wat handbal speel: ligte velkleur',
    '🤾🏼' => 'persoon wat handbal speel: medium-ligte velkleur',
    '🤾🏽' => 'persoon wat handbal speel: medium velkleur',
    '🤾🏾' => 'persoon wat handbal speel: medium-donker velkleur',
    '🤾🏿' => 'persoon wat handbal speel: donker velkleur',
    '🤹🏻' => 'jongleur: ligte velkleur',
    '🤹🏼' => 'jongleur: medium-ligte velkleur',
    '🤹🏽' => 'jongleur: medium velkleur',
    '🤹🏾' => 'jongleur: medium-donker velkleur',
    '🤹🏿' => 'jongleur: donker velkleur',
    '🧘🏻' => 'persoon in die lotusposisie: ligte velkleur',
    '🧘🏼' => 'persoon in die lotusposisie: medium-ligte velkleur',
    '🧘🏽' => 'persoon in die lotusposisie: medium velkleur',
    '🧘🏾' => 'persoon in die lotusposisie: medium-donker velkleur',
    '🧘🏿' => 'persoon in die lotusposisie: donker velkleur',
    '🛀🏻' => 'persoon wat bad: ligte velkleur',
    '🛀🏼' => 'persoon wat bad: medium-ligte velkleur',
    '🛀🏽' => 'persoon wat bad: medium velkleur',
    '🛀🏾' => 'persoon wat bad: medium-donker velkleur',
    '🛀🏿' => 'persoon wat bad: donker velkleur',
    '🛌🏻' => 'persoon in bed: ligte velkleur',
    '🛌🏼' => 'persoon in bed: medium-ligte velkleur',
    '🛌🏽' => 'persoon in bed: medium velkleur',
    '🛌🏾' => 'persoon in bed: medium-donker velkleur',
    '🛌🏿' => 'persoon in bed: donker velkleur',
    '👭🏻' => 'twee vroue wat hande vashou: ligte velkleur',
    '👭🏼' => 'twee vroue wat hande vashou: medium-ligte velkleur',
    '👭🏽' => 'twee vroue wat hande vashou: medium velkleur',
    '👭🏾' => 'twee vroue wat hande vashou: medium-donker velkleur',
    '👭🏿' => 'twee vroue wat hande vashou: donker velkleur',
    '👫🏻' => 'man en vrou wat hande vashou: ligte velkleur',
    '👫🏼' => 'man en vrou wat hande vashou: medium-ligte velkleur',
    '👫🏽' => 'man en vrou wat hande vashou: medium velkleur',
    '👫🏾' => 'man en vrou wat hande vashou: medium-donker velkleur',
    '👫🏿' => 'man en vrou wat hande vashou: donker velkleur',
    '👬🏻' => 'twee mans wat hande vashou: ligte velkleur',
    '👬🏼' => 'twee mans wat hande vashou: medium-ligte velkleur',
    '👬🏽' => 'twee mans wat hande vashou: medium velkleur',
    '👬🏾' => 'twee mans wat hande vashou: medium-donker velkleur',
    '👬🏿' => 'twee mans wat hande vashou: donker velkleur',
    '💏🏻' => 'soen: ligte velkleur',
    '💏🏼' => 'soen: medium-ligte velkleur',
    '💏🏽' => 'soen: medium velkleur',
    '💏🏾' => 'soen: medium-donker velkleur',
    '💏🏿' => 'soen: donker velkleur',
    '💑🏻' => 'paartjie met hartjie: ligte velkleur',
    '💑🏼' => 'paartjie met hartjie: medium-ligte velkleur',
    '💑🏽' => 'paartjie met hartjie: medium velkleur',
    '💑🏾' => 'paartjie met hartjie: medium-donker velkleur',
    '💑🏿' => 'paartjie met hartjie: donker velkleur',
    '🇦🇨' => 'vlag: Ascensioneiland',
    '🇦🇩' => 'vlag: Andorra',
    '🇦🇪' => 'vlag: Verenigde Arabiese Emirate',
    '🇦🇫' => 'vlag: Afganistan',
    '🇦🇬' => 'vlag: Antigua en Barbuda',
    '🇦🇮' => 'vlag: Anguilla',
    '🇦🇱' => 'vlag: Albanië',
    '🇦🇲' => 'vlag: Armenië',
    '🇦🇴' => 'vlag: Angola',
    '🇦🇶' => 'vlag: Antarktika',
    '🇦🇷' => 'vlag: Argentinië',
    '🇦🇸' => 'vlag: Amerikaanse Samoa',
    '🇦🇹' => 'vlag: Oostenryk',
    '🇦🇺' => 'vlag: Australië',
    '🇦🇼' => 'vlag: Aruba',
    '🇦🇽' => 'vlag: Ålandeilande',
    '🇦🇿' => 'vlag: Azerbeidjan',
    '🇧🇦' => 'vlag: Bosnië en Herzegowina',
    '🇧🇧' => 'vlag: Barbados',
    '🇧🇩' => 'vlag: Bangladesj',
    '🇧🇪' => 'vlag: België',
    '🇧🇫' => 'vlag: Burkina Faso',
    '🇧🇬' => 'vlag: Bulgarye',
    '🇧🇭' => 'vlag: Bahrein',
    '🇧🇮' => 'vlag: Burundi',
    '🇧🇯' => 'vlag: Benin',
    '🇧🇱' => 'vlag: Sint Barthélemy',
    '🇧🇲' => 'vlag: Bermuda',
    '🇧🇳' => 'vlag: Broenei',
    '🇧🇴' => 'vlag: Bolivië',
    '🇧🇶' => 'vlag: Karibiese Nederland',
    '🇧🇷' => 'vlag: Brasilië',
    '🇧🇸' => 'vlag: Bahamas',
    '🇧🇹' => 'vlag: Bhoetan',
    '🇧🇻' => 'vlag: Bouvet-eiland',
    '🇧🇼' => 'vlag: Botswana',
    '🇧🇾' => 'vlag: Belarus',
    '🇧🇿' => 'vlag: Belize',
    '🇨🇦' => 'vlag: Kanada',
    '🇨🇨' => 'vlag: Kokoseilande',
    '🇨🇩' => 'vlag: Demokratiese Republiek van die Kongo',
    '🇨🇫' => 'vlag: Sentraal-Afrikaanse Republiek',
    '🇨🇬' => 'vlag: Kongo-Brazzaville',
    '🇨🇭' => 'vlag: Switserland',
    '🇨🇮' => 'vlag: Ivoorkus',
    '🇨🇰' => 'vlag: Cookeilande',
    '🇨🇱' => 'vlag: Chili',
    '🇨🇲' => 'vlag: Kameroen',
    '🇨🇳' => 'vlag: China',
    '🇨🇴' => 'vlag: Colombië',
    '🇨🇵' => 'vlag: Clippertoneiland',
    '🇨🇶' => 'vlag: Sark',
    '🇨🇷' => 'vlag: Costa Rica',
    '🇨🇺' => 'vlag: Kuba',
    '🇨🇻' => 'vlag: Kaap Verde',
    '🇨🇼' => 'vlag: Curaçao',
    '🇨🇽' => 'vlag: Kerseiland',
    '🇨🇾' => 'vlag: Siprus',
    '🇨🇿' => 'vlag: Tsjeggië',
    '🇩🇪' => 'vlag: Duitsland',
    '🇩🇬' => 'vlag: Diego Garcia',
    '🇩🇯' => 'vlag: Djiboeti',
    '🇩🇰' => 'vlag: Denemarke',
    '🇩🇲' => 'vlag: Dominica',
    '🇩🇴' => 'vlag: Dominikaanse Republiek',
    '🇩🇿' => 'vlag: Algerië',
    '🇪🇦' => 'vlag: Ceuta en Melilla',
    '🇪🇨' => 'vlag: Ecuador',
    '🇪🇪' => 'vlag: Estland',
    '🇪🇬' => 'vlag: Egipte',
    '🇪🇭' => 'vlag: Wes-Sahara',
    '🇪🇷' => 'vlag: Eritrea',
    '🇪🇸' => 'vlag: Spanje',
    '🇪🇹' => 'vlag: Ethiopië',
    '🇪🇺' => 'vlag: Europese Unie',
    '🇫🇮' => 'vlag: Finland',
    '🇫🇯' => 'vlag: Fidji',
    '🇫🇰' => 'vlag: Falklandeilande',
    '🇫🇲' => 'vlag: Mikronesië',
    '🇫🇴' => 'vlag: Faroëreilande',
    '🇫🇷' => 'vlag: Frankryk',
    '🇬🇦' => 'vlag: Gaboen',
    '🇬🇧' => 'vlag: Verenigde Koninkryk',
    '🇬🇩' => 'vlag: Grenada',
    '🇬🇪' => 'vlag: Georgië',
    '🇬🇫' => 'vlag: Frans-Guyana',
    '🇬🇬' => 'vlag: Guernsey',
    '🇬🇭' => 'vlag: Ghana',
    '🇬🇮' => 'vlag: Gibraltar',
    '🇬🇱' => 'vlag: Groenland',
    '🇬🇲' => 'vlag: Gambië',
    '🇬🇳' => 'vlag: Guinee',
    '🇬🇵' => 'vlag: Guadeloupe',
    '🇬🇶' => 'vlag: Ekwatoriaal-Guinee',
    '🇬🇷' => 'vlag: Griekeland',
    '🇬🇸' => 'vlag: Suid-Georgië en die Suidelike Sandwicheilande',
    '🇬🇹' => 'vlag: Guatemala',
    '🇬🇺' => 'vlag: Guam',
    '🇬🇼' => 'vlag: Guinee-Bissau',
    '🇬🇾' => 'vlag: Guyana',
    '🇭🇰' => 'vlag: Hongkong SAS China',
    '🇭🇲' => 'vlag: Heardeiland en McDonaldeilande',
    '🇭🇳' => 'vlag: Honduras',
    '🇭🇷' => 'vlag: Kroasië',
    '🇭🇹' => 'vlag: Haïti',
    '🇭🇺' => 'vlag: Hongarye',
    '🇮🇨' => 'vlag: Kanariese Eilande',
    '🇮🇩' => 'vlag: Indonesië',
    '🇮🇪' => 'vlag: Ierland',
    '🇮🇱' => 'vlag: Israel',
    '🇮🇲' => 'vlag: Eiland Man',
    '🇮🇳' => 'vlag: Indië',
    '🇮🇴' => 'vlag: Brits-Indiese Oseaangebied',
    '🇮🇶' => 'vlag: Irak',
    '🇮🇷' => 'vlag: Iran',
    '🇮🇸' => 'vlag: Ysland',
    '🇮🇹' => 'vlag: Italië',
    '🇯🇪' => 'vlag: Jersey',
    '🇯🇲' => 'vlag: Jamaika',
    '🇯🇴' => 'vlag: Jordanië',
    '🇯🇵' => 'vlag: Japan',
    '🇰🇪' => 'vlag: Kenia',
    '🇰🇬' => 'vlag: Kirgistan',
    '🇰🇭' => 'vlag: Kambodja',
    '🇰🇮' => 'vlag: Kiribati',
    '🇰🇲' => 'vlag: Comore',
    '🇰🇳' => 'vlag: Sint Kitts en Nevis',
    '🇰🇵' => 'vlag: Noord-Korea',
    '🇰🇷' => 'vlag: Suid-Korea',
    '🇰🇼' => 'vlag: Koeweit',
    '🇰🇾' => 'vlag: Kaaimanseilande',
    '🇰🇿' => 'vlag: Kazakstan',
    '🇱🇦' => 'vlag: Laos',
    '🇱🇧' => 'vlag: Libanon',
    '🇱🇨' => 'vlag: Sint Lucia',
    '🇱🇮' => 'vlag: Liechtenstein',
    '🇱🇰' => 'vlag: Sri Lanka',
    '🇱🇷' => 'vlag: Liberië',
    '🇱🇸' => 'vlag: Lesotho',
    '🇱🇹' => 'vlag: Litaue',
    '🇱🇺' => 'vlag: Luxemburg',
    '🇱🇻' => 'vlag: Letland',
    '🇱🇾' => 'vlag: Libië',
    '🇲🇦' => 'vlag: Marokko',
    '🇲🇨' => 'vlag: Monaco',
    '🇲🇩' => 'vlag: Moldowa',
    '🇲🇪' => 'vlag: Montenegro',
    '🇲🇫' => 'vlag: Sint Martin',
    '🇲🇬' => 'vlag: Madagaskar',
    '🇲🇭' => 'vlag: Marshalleilande',
    '🇲🇰' => 'vlag: Noord-Macedonië',
    '🇲🇱' => 'vlag: Mali',
    '🇲🇲' => 'vlag: Mianmar (Birma)',
    '🇲🇳' => 'vlag: Mongolië',
    '🇲🇴' => 'vlag: Macau SAS China',
    '🇲🇵' => 'vlag: Noord-Mariane-eilande',
    '🇲🇶' => 'vlag: Martinique',
    '🇲🇷' => 'vlag: Mauritanië',
    '🇲🇸' => 'vlag: Montserrat',
    '🇲🇹' => 'vlag: Malta',
    '🇲🇺' => 'vlag: Mauritius',
    '🇲🇻' => 'vlag: Maledive',
    '🇲🇼' => 'vlag: Malawi',
    '🇲🇽' => 'vlag: Meksiko',
    '🇲🇾' => 'vlag: Maleisië',
    '🇲🇿' => 'vlag: Mosambiek',
    '🇳🇦' => 'vlag: Namibië',
    '🇳🇨' => 'vlag: Nieu-Kaledonië',
    '🇳🇪' => 'vlag: Niger',
    '🇳🇫' => 'vlag: Norfolkeiland',
    '🇳🇬' => 'vlag: Nigerië',
    '🇳🇮' => 'vlag: Nicaragua',
    '🇳🇱' => 'vlag: Nederland',
    '🇳🇴' => 'vlag: Noorweë',
    '🇳🇵' => 'vlag: Nepal',
    '🇳🇷' => 'vlag: Nauru',
    '🇳🇺' => 'vlag: Niue',
    '🇳🇿' => 'vlag: Nieu-Seeland',
    '🇴🇲' => 'vlag: Oman',
    '🇵🇦' => 'vlag: Panama',
    '🇵🇪' => 'vlag: Peru',
    '🇵🇫' => 'vlag: Frans-Polinesië',
    '🇵🇬' => 'vlag: Papoea-Nieu-Guinee',
    '🇵🇭' => 'vlag: Filippyne',
    '🇵🇰' => 'vlag: Pakistan',
    '🇵🇱' => 'vlag: Pole',
    '🇵🇲' => 'vlag: Sint Pierre en Miquelon',
    '🇵🇳' => 'vlag: Pitcairneilande',
    '🇵🇷' => 'vlag: Puerto Rico',
    '🇵🇸' => 'vlag: Palestynse Grondgebiede',
    '🇵🇹' => 'vlag: Portugal',
    '🇵🇼' => 'vlag: Palau',
    '🇵🇾' => 'vlag: Paraguay',
    '🇶🇦' => 'vlag: Katar',
    '🇷🇪' => 'vlag: Réunion',
    '🇷🇴' => 'vlag: Roemenië',
    '🇷🇸' => 'vlag: Serwië',
    '🇷🇺' => 'vlag: Rusland',
    '🇷🇼' => 'vlag: Rwanda',
    '🇸🇦' => 'vlag: Saoedi-Arabië',
    '🇸🇧' => 'vlag: Salomonseilande',
    '🇸🇨' => 'vlag: Seychelle',
    '🇸🇩' => 'vlag: Soedan',
    '🇸🇪' => 'vlag: Swede',
    '🇸🇬' => 'vlag: Singapoer',
    '🇸🇭' => 'vlag: Sint Helena',
    '🇸🇮' => 'vlag: Slowenië',
    '🇸🇯' => 'vlag: Spitsbergen en Jan Mayen',
    '🇸🇰' => 'vlag: Slowakye',
    '🇸🇱' => 'vlag: Sierra Leone',
    '🇸🇲' => 'vlag: San Marino',
    '🇸🇳' => 'vlag: Senegal',
    '🇸🇴' => 'vlag: Somalië',
    '🇸🇷' => 'vlag: Suriname',
    '🇸🇸' => 'vlag: Suid-Soedan',
    '🇸🇹' => 'vlag: São Tomé en Príncipe',
    '🇸🇻' => 'vlag: El Salvador',
    '🇸🇽' => 'vlag: Sint Maarten',
    '🇸🇾' => 'vlag: Sirië',
    '🇸🇿' => 'vlag: Eswatini',
    '🇹🇦' => 'vlag: Tristan da Cunha',
    '🇹🇨' => 'vlag: Turks- en Caicoseilande',
    '🇹🇩' => 'vlag: Tsjad',
    '🇹🇫' => 'vlag: Franse Suidelike Gebiede',
    '🇹🇬' => 'vlag: Togo',
    '🇹🇭' => 'vlag: Thailand',
    '🇹🇯' => 'vlag: Tadjikistan',
    '🇹🇰' => 'vlag: Tokelau',
    '🇹🇱' => 'vlag: Oos-Timor',
    '🇹🇲' => 'vlag: Turkmenistan',
    '🇹🇳' => 'vlag: Tunisië',
    '🇹🇴' => 'vlag: Tonga',
    '🇹🇷' => 'vlag: Turkye',
    '🇹🇹' => 'vlag: Trinidad en Tobago',
    '🇹🇻' => 'vlag: Tuvalu',
    '🇹🇼' => 'vlag: Taiwan',
    '🇹🇿' => 'vlag: Tanzanië',
    '🇺🇦' => 'vlag: Oekraïne',
    '🇺🇬' => 'vlag: Uganda',
    '🇺🇲' => 'vlag: Klein afgeleë eilande van die VSA',
    '🇺🇳' => 'vlag: Verenigde Nasies',
    '🇺🇸' => 'vlag: Verenigde State van Amerika',
    '🇺🇾' => 'vlag: Uruguay',
    '🇺🇿' => 'vlag: Oesbekistan',
    '🇻🇦' => 'vlag: Vatikaanstad',
    '🇻🇨' => 'vlag: Sint Vincent en die Grenadine',
    '🇻🇪' => 'vlag: Venezuela',
    '🇻🇬' => 'vlag: Britse Maagde-eilande',
    '🇻🇮' => 'vlag: VSA se Maagde-eilande',
    '🇻🇳' => 'vlag: Viëtnam',
    '🇻🇺' => 'vlag: Vanuatu',
    '🇼🇫' => 'vlag: Wallis en Futuna',
    '🇼🇸' => 'vlag: Samoa',
    '🇽🇰' => 'vlag: Kosovo',
    '🇾🇪' => 'vlag: Jemen',
    '🇾🇹' => 'vlag: Mayotte',
    '🇿🇦' => 'vlag: Suid-Afrika',
    '🇿🇲' => 'vlag: Zambië',
    '🇿🇼' => 'vlag: Zimbabwe',
    '🔟' => 'knoppiesimbool: 10',
    '🏻' => 'ligte velkleur',
    '🏼' => 'medium-ligte velkleur',
    '🏽' => 'medium velkleur',
    '🏾' => 'medium-donker velkleur',
    '🏿' => 'donker velkleur',
    '😀' => 'grinnikende gesig',
    '😃' => 'grinnikende gesiggie met groot oë',
    '😄' => 'grinnikende gesiggie met glimlaggende oë',
    '😁' => 'stralende gesiggie met glimlaggende oë',
    '😆' => 'grynslaggesiggie met toegeknypte oë',
    '😅' => 'lag gesig met sweet',
    '🤣' => 'gesig wat hard lag',
    '😂' => 'gesig met trane van vreugde',
    '🙂' => 'gesig wat effens glimlag',
    '🙃' => 'onderstebo gesig',
    '🫠' => 'gesig wat smelt',
    '😉' => 'gesig wat knipoog',
    '😊' => 'glimlaggende gesig met glimlaggende oë',
    '😇' => 'glimlaggende gesig met stralekrans',
    '🥰' => 'glimlaggende gesig met 3 hartjies',
    '😍' => 'glimlaggende gesig met hartvormige oë',
    '🤩' => 'sterre in die oë',
    '😘' => 'gesig wat ‘n soentjie blaas',
    '😗' => 'gesig wat soen',
    '☺' => 'glimlaggende gesig',
    '😚' => 'gesig wat soen met toe oë',
    '😙' => 'gesig wat soen met glimlaggende oë',
    '🥲' => 'glimlaggende gesig met traan',
    '😋' => 'gesig wat heerlike kos geniet',
    '😛' => 'gesig met tong wat uitsteek',
    '😜' => 'gesig met tong wat uitsteek en wat knipoog',
    '🤪' => 'mal gesig',
    '😝' => 'gesig met tong wat uitsteek en oë styf toe',
    '🤑' => 'gesig met geldmond',
    '🤗' => 'gesig wat drukkie gee',
    '🤭' => 'gesig met hand oor die mond',
    '🫢' => 'gesig met hand oor mond',
    '🫣' => 'gesiggie met een oog wat loer',
    '🤫' => 'stilmaak gesig',
    '🤔' => 'gesig wat dink',
    '🫡' => 'saluut',
    '🤐' => 'gesig met ritssluitermond',
    '🤨' => 'gesig met geligte wenkbroue',
    '😐' => 'neutrale gesig',
    '😑' => 'uitdrukkinglose gesig',
    '😶' => 'gesig sonder mond',
    '🫥' => 'gesig met stippellyn',
    '😏' => 'gesig wat grynslag',
    '😒' => 'ontevrede gesig',
    '🙄' => 'gesig met oë wat rol',
    '😬' => 'grynsende gesig',
    '🤥' => 'gesig wat jok',
    '🫨' => 'gesig wat skud',
    '😌' => 'verligte gesig',
    '😔' => 'peinsende gesig',
    '😪' => 'vaak gesig',
    '🤤' => 'gesig wat kwyl',
    '😴' => 'gesig wat slaap',
    '🫩' => 'gesig met sakke onder oë',
    '😷' => 'gesig met mediese masker',
    '🤒' => 'gesig met koorspen',
    '🤕' => 'gesig met kopverband',
    '🤢' => 'naar gesig',
    '🤮' => 'gesig wat opgooi',
    '🤧' => 'gesig wat nies',
    '🥵' => 'warm gesig',
    '🥶' => 'koue gesig',
    '🥴' => 'dronk gesig',
    '😵' => 'duiselig gesig',
    '🤯' => 'kop wat ontplof',
    '🤠' => 'gesig met cowboy-hoed',
    '🥳' => 'partytjie gesig',
    '🥸' => 'vermomde gesig',
    '😎' => 'glimlaggende gesig met sonbril',
    '🤓' => 'bleeksielgesig',
    '🧐' => 'gesig met oogglas',
    '😕' => 'verwarde gesig',
    '🫤' => 'gesig met dwars mond',
    '😟' => 'bekommerde gesig',
    '🙁' => 'gesig wat effens frons',
    '☹' => 'gesig wat frons',
    '😮' => 'gesig met oop mond',
    '😯' => 'gedempte gesig',
    '😲' => 'verstomde gesig',
    '😳' => 'blosende gesig',
    '🫪' => 'verwronge gesiggie',
    '🥺' => 'soebat gesig',
    '🥹' => 'gesig wat wil huil',
    '😦' => 'fronsende gesig met oop mond',
    '😧' => 'beangste gesig',
    '😨' => 'bang gesig',
    '😰' => 'gesig met oop mond en koue sweet',
    '😥' => 'teleurgestelde maar verligte gesig',
    '😢' => 'gesig wat huil',
    '😭' => 'gesig wat hard huil',
    '😱' => 'gesig wat beangs skree',
    '😖' => 'oorblufte gesig',
    '😣' => 'gesig wat vasbyt',
    '😞' => 'teleurgestelde gesig',
    '😓' => 'gesig met koue sweet',
    '😩' => 'uitgeputte gesig',
    '😫' => 'moeë gesig',
    '🥱' => 'gapende gesig',
    '😤' => 'gesig met stoom uit neus',
    '😡' => 'pruilende gesig',
    '😠' => 'kwaai gesig',
    '🤬' => 'gesig met simbole op mond',
    '😈' => 'glimlaggende gesig met horings',
    '👿' => 'duiwel',
    '💀' => 'kopbeen',
    '☠' => 'kopbeen en gekruiste beendere',
    '💩' => 'mishoop',
    '🤡' => 'hansworsgesig',
    '👹' => 'mensvreter',
    '👺' => 'tokkelos',
    '👻' => 'spook',
    '👽' => 'buiteruimtelike wese',
    '👾' => 'buiteruimtelike monster',
    '🤖' => 'robotgesig',
    '😺' => 'glimlaggende katgesig met oopmond',
    '😸' => 'grinnikende katgesig met glimlaggende oë',
    '😹' => 'katgesig met trane van vreugde',
    '😻' => 'glimlaggende katgesig met hartvormige oë',
    '😼' => 'katgesig met wrang glimlag',
    '😽' => 'katgesig met geslote oë wat soen',
    '🙀' => 'vermoeide katgesig',
    '😿' => 'katgesig wat huil',
    '😾' => 'pruilende katgesig',
    '🙈' => 'sien geen kwaad nie',
    '🙉' => 'hoor geen kwaad nie',
    '🙊' => 'praat geen kwaad nie',
    '💌' => 'liefdesbrief',
    '💘' => 'hartjie met pyl',
    '💝' => 'hartjie met lint',
    '💖' => 'sprankelende hartjie',
    '💗' => 'groeiende hartjie',
    '💓' => 'kloppende hartjie',
    '💞' => 'wentelende hartjies',
    '💕' => 'twee hartjies',
    '💟' => 'hartversiering',
    '❣' => 'dik hartuitroepteken',
    '💔' => 'gebroke hartjie',
    '❤' => 'rooi hartjie',
    '🩷' => 'pienk hart',
    '🧡' => 'oranje hartjie',
    '💛' => 'geel hartjie',
    '💚' => 'groen hartjie',
    '💙' => 'blou hartjie',
    '🩵' => 'ligblou hart',
    '💜' => 'pers hartjie',
    '🤎' => 'bruin hartjie',
    '🖤' => 'swart hartjie',
    '🩶' => 'grys hart',
    '🤍' => 'wit hartjie',
    '💋' => 'soenmerk',
    '💯' => 'honderd punte',
    '💢' => 'woedesimbool',
    '🫯' => 'bakleiwolkie',
    '💥' => 'botsing',
    '💫' => 'duiselig',
    '💦' => 'sweetdruppels',
    '💨' => 'blitsig',
    '🕳' => 'gat',
    '💬' => 'spraakballon',
    '🗨' => 'spraakborrel links',
    '🗯' => 'woedeborrel regs',
    '💭' => 'dinkballon',
    '💤' => 'zzz',
    '👋' => 'wuiwende hand',
    '🤚' => 'handrug',
    '🖐' => 'hand in die lug met vingers oopgesprei',
    '✋' => 'hand in die lug',
    '🖖' => 'vulkansaluut',
    '🫱' => 'hand na regs',
    '🫲' => 'hand na links',
    '🫳' => 'hand met palm ondertoe',
    '🫴' => 'hand met palm boontoe',
    '🫷' => 'hand wat linkswaarts druk',
    '🫸' => 'regswaarts drukkende hand',
    '👌' => 'ok-handteken',
    '🤌' => 'vingerpunte saamgedruk',
    '🤏' => 'knypende hand',
    '✌' => 'oorwinninghandteken',
    '🤞' => 'duim vashou',
    '🫰' => 'hand met duim en wysvinger gekruis',
    '🤟' => 'lief-vir-jou-gebaar',
    '🤘' => 'horingteken',
    '🤙' => 'bel my hand',
    '👈' => 'wysvingerrughand wat links wys',
    '👉' => 'wysvingerrughand wat regs wys',
    '👆' => 'wysvingerrughand wat op wys',
    '🖕' => 'middelvinger',
    '👇' => 'wysvingerrughand wat af wys',
    '☝' => 'wysvinger wat op wys',
    '🫵' => 'wysvinger na kyker',
    '👍' => 'laaik baie',
    '👎' => 'laaik niks',
    '✊' => 'vuis in die lug',
    '👊' => 'vuishou',
    '🤛' => 'vuis links',
    '🤜' => 'vuis regs',
    '👏' => 'handeklap',
    '🙌' => 'persoon met hande in die lug',
    '🫶' => 'handhartjie',
    '👐' => 'oop hande',
    '🤲' => 'palms op teen mekaar',
    '🤝' => 'handskud',
    '🙏' => 'gevoude hande',
    '✍' => 'hand wat skryf',
    '💅' => 'naellak',
    '🤳' => 'selfie',
    '💪' => 'gebulte biseps',
    '🦾' => 'meganiese arm',
    '🦿' => 'meganiese been',
    '🦵' => 'been',
    '🦶' => 'voet',
    '👂' => 'oor',
    '🦻' => 'oor met gehoorapparaat',
    '👃' => 'neus',
    '🧠' => 'brein',
    '🫀' => 'orgaanhart',
    '🫁' => 'longe',
    '🦷' => 'tand',
    '🦴' => 'vleislose been',
    '👀' => 'oë',
    '👁' => 'oog',
    '👅' => 'tong',
    '👄' => 'mond',
    '🫦' => 'byt lip',
    '👶' => 'baba',
    '🧒' => 'kind',
    '👦' => 'seun',
    '👧' => 'meisie',
    '🧑' => 'volwassene',
    '👱' => 'persoon met blonde hare',
    '👨' => 'man',
    '🧔' => 'bebaarde persoon',
    '👩' => 'vrou',
    '🧓' => 'ouer volwassene',
    '👴' => 'ou man',
    '👵' => 'ou vrou',
    '🙍' => 'persoon wat frons',
    '🙎' => 'dikbek persoon',
    '🙅' => 'persoon wat NEE wys',
    '🙆' => 'persoon wys als is goed',
    '💁' => 'persoon hou hand geknak',
    '🙋' => 'persoon wat hand opsteek',
    '🧏' => 'dowe persoon',
    '🙇' => 'persoon wat buig',
    '🤦' => 'hand teen voorkop slaan',
    '🤷' => 'persoon skouerophaal',
    '👮' => 'polisiebeampte',
    '🕵' => 'speurder',
    '💂' => 'gardeoffisier',
    '🥷' => 'ninja',
    '👷' => 'konstruksiewerker',
    '🫅' => 'persoon met kroon',
    '🤴' => 'prins',
    '👸' => 'prinses',
    '👳' => 'persoon met tulband',
    '👲' => 'man met mus',
    '🧕' => 'vrou met kopdoek',
    '🤵' => 'persoon in pak',
    '👰' => 'persoon met sluier',
    '🤰' => 'swanger vrou',
    '🫃' => 'swanger man',
    '🫄' => 'swanger persoon',
    '🤱' => 'borsvoed',
    '👼' => 'baba-engel',
    '🎅' => 'Kersvader',
    '🤶' => 'Moeder Kersfees',
    '🦸' => 'superheld',
    '🦹' => 'superskurk',
    '🧙' => 'magus',
    '🧚' => 'feetjie',
    '🧛' => 'vampier',
    '🧜' => 'meerpersoon',
    '🧝' => 'elf',
    '🧞' => 'towergees',
    '🧟' => 'zombie',
    '🧌' => 'trol',
    '🫈' => 'harige skepsel',
    '💆' => 'persoon kry massering',
    '💇' => 'haarsny',
    '🚶' => 'voetganger',
    '🧍' => 'persoon wat staan',
    '🧎' => 'persoon wat kniel',
    '🏃' => 'persoon wat hardloop',
    '💃' => 'vrou dans',
    '🕺' => 'man dans',
    '🕴' => 'man in sakepak wat sweef',
    '👯' => 'mense met haasore',
    '🧖' => 'persoon in stoomkamer',
    '🧗' => 'persoon wat rotsklim',
    '🤺' => 'skermvegter',
    '🏇' => 'perdewedrenne',
    '⛷' => 'skiër',
    '🏂' => 'sneeuplankryer',
    '🏌' => 'gholfspeler',
    '🏄' => 'branderplankryer',
    '🚣' => 'persoon in roeiboot',
    '🏊' => 'swemmer',
    '⛹' => 'persoon hop bal',
    '🏋' => 'gewigopteller',
    '🚴' => 'fietsryer',
    '🚵' => 'bergfietsryer',
    '🤸' => 'persoon wat ‘n wawiel doen',
    '🤼' => 'stoeiers',
    '🤽' => 'waterpolo',
    '🤾' => 'persoon wat handbal speel',
    '🤹' => 'jongleur',
    '🧘' => 'persoon in die lotusposisie',
    '🛀' => 'persoon wat bad',
    '🛌' => 'persoon in bed',
    '👭' => 'twee vroue wat hande vashou',
    '👫' => 'man en vrou wat hande vashou',
    '👬' => 'twee mans wat hande vashou',
    '💏' => 'soen',
    '💑' => 'paartjie met hartjie',
    '🗣' => 'kop wat praat',
    '👤' => 'borssilhoeët',
    '👥' => 'borssilhoeëtte',
    '🫂' => 'mense wat mekaar druk',
    '👪' => 'gesin',
    '👣' => 'voetspore',
    '🫆' => 'vingerafdruk',
    '🦰' => 'rooi hare',
    '🦱' => 'krulhare',
    '🦳' => 'wit hare',
    '🦲' => 'bles',
    '🐵' => 'aapgesig',
    '🐒' => 'aap',
    '🦍' => 'gorilla',
    '🦧' => 'oerangoetang',
    '🐶' => 'hondgesig',
    '🐕' => 'hond',
    '🦮' => 'gidshond',
    '🐩' => 'poedel',
    '🐺' => 'wolf',
    '🦊' => 'jakkals',
    '🦝' => 'wasbeer',
    '🐱' => 'katgesig',
    '🐈' => 'kat',
    '🦁' => 'leeugesig',
    '🐯' => 'tiergesig',
    '🐅' => 'tier',
    '🐆' => 'luiperd',
    '🐴' => 'perdgesig',
    '🫎' => 'eland',
    '🫏' => 'donkie',
    '🐎' => 'perd',
    '🦄' => 'eenhoringgesig',
    '🦓' => 'sebra',
    '🦌' => 'wildsbok',
    '🦬' => 'Amerikaanse buffel',
    '🐮' => 'koeigesig',
    '🐂' => 'os',
    '🐃' => 'waterbuffel',
    '🐄' => 'koei',
    '🐷' => 'varkgesig',
    '🐖' => 'vark',
    '🐗' => 'varkbeer',
    '🐽' => 'varksnoet',
    '🐏' => 'ram',
    '🐑' => 'skaapooi',
    '🐐' => 'bok',
    '🐪' => 'kameel',
    '🐫' => 'kameel met twee boggels',
    '🦙' => 'lama',
    '🦒' => 'kameelperd',
    '🐘' => 'olifant',
    '🦣' => 'mammoet',
    '🦏' => 'renoster',
    '🦛' => 'seekoei',
    '🐭' => 'muisgesig',
    '🐁' => 'muis',
    '🐀' => 'rot',
    '🐹' => 'hamstergesig',
    '🐰' => 'haasgesig',
    '🐇' => 'haas',
    '🐿' => 'grondeekhoring',
    '🦫' => 'bewer',
    '🦔' => 'krimpvarkie',
    '🦇' => 'vlermuis',
    '🐻' => 'beergesig',
    '🐨' => 'koala',
    '🐼' => 'pandagesig',
    '🦥' => 'luidier',
    '🦦' => 'otter',
    '🦨' => 'muishond',
    '🦘' => 'kangaroe',
    '🦡' => 'ratel',
    '🐾' => 'pootafdrukke',
    '🦃' => 'kalkoen',
    '🐔' => 'hoender',
    '🐓' => 'haan',
    '🐣' => 'kuiken wat uitbroei',
    '🐤' => 'babakuiken',
    '🐥' => 'kuiken wat vorentoe kyk',
    '🐦' => 'voël',
    '🐧' => 'pikkewyn',
    '🕊' => 'duif',
    '🦅' => 'arend',
    '🦆' => 'eend',
    '🦢' => 'swaan',
    '🦉' => 'uil',
    '🦤' => 'dodo',
    '🪶' => 'veer',
    '🦩' => 'flamink',
    '🦚' => 'pou',
    '🦜' => 'papegaai',
    '🪽' => 'vlerk',
    '🪿' => 'gans',
    '🐸' => 'padda',
    '🐊' => 'krokodil',
    '🐢' => 'waterskilpad',
    '🦎' => 'akkedis',
    '🐍' => 'slang',
    '🐲' => 'draakgesig',
    '🐉' => 'draak',
    '🦕' => 'souropode',
    '🦖' => 'T-Rex',
    '🐳' => 'walvis wat spuit',
    '🐋' => 'walvis',
    '🐬' => 'dolfyn',
    '🫍' => 'moordvis',
    '🦭' => 'rob',
    '🐟' => 'vis',
    '🐠' => 'tropiese vis',
    '🐡' => 'blaasoppie',
    '🦈' => 'haai',
    '🐙' => 'seekat',
    '🐚' => 'spiraalskulp',
    '🪸' => 'koraal',
    '🪼' => 'jellievis',
    '🦀' => 'krap',
    '🦞' => 'kreef',
    '🦐' => 'garnaal',
    '🦑' => 'inkvis',
    '🦪' => 'oester',
    '🐌' => 'slak',
    '🦋' => 'skoenlapper',
    '🐛' => 'gogga',
    '🐜' => 'mier',
    '🐝' => 'heuningby',
    '🪲' => 'kewer',
    '🐞' => 'liewenheersbesie',
    '🦗' => 'kriek',
    '🪳' => 'kakkerlak',
    '🕷' => 'spinnekop',
    '🕸' => 'spinnerak',
    '🦂' => 'skerpioen',
    '🦟' => 'muskiet',
    '🪰' => 'vlieg',
    '🪱' => 'wurm',
    '🦠' => 'mikrobe',
    '💐' => 'ruiker',
    '🌸' => 'kersiebloeisel',
    '💮' => 'wit blom',
    '🪷' => 'lotus',
    '🏵' => 'roset',
    '🌹' => 'roos',
    '🥀' => 'verlepte blom',
    '🌺' => 'hibiskus',
    '🌻' => 'sonneblom',
    '🌼' => 'bloeisel',
    '🌷' => 'tulp',
    '🪻' => 'hiasint',
    '🌱' => 'saailing',
    '🪴' => 'potplant',
    '🌲' => 'immergroen boom',
    '🌳' => 'bladwisselende boom',
    '🌴' => 'palmboom',
    '🌵' => 'kaktus',
    '🌾' => 'rysgerf',
    '🌿' => 'krui',
    '☘' => 'klawer',
    '🍀' => 'vierblaarklawer',
    '🍁' => 'esdoringblaar',
    '🍂' => 'vallende blaar',
    '🍃' => 'blaar wat in die wind fladder',
    '🪹' => 'leë nes',
    '🪺' => 'nes met eiers',
    '🍄' => 'sampioen',
    '🪾' => 'blaarlose boom',
    '🍇' => 'druiwe',
    '🍈' => 'spanspek',
    '🍉' => 'waatlemoen',
    '🍊' => 'nartjie',
    '🍋' => 'suurlemoen',
    '🍌' => 'piesang',
    '🍍' => 'pynappel',
    '🥭' => 'mango',
    '🍎' => 'rooi appel',
    '🍏' => 'groen appel',
    '🍐' => 'peer',
    '🍑' => 'perske',
    '🍒' => 'kersies',
    '🍓' => 'aarbei',
    '🫐' => 'bloubessies',
    '🥝' => 'kiwivrug',
    '🍅' => 'tamatie',
    '🫒' => 'olyf',
    '🥥' => 'kokosneut',
    '🥑' => 'avokado',
    '🍆' => 'eiervrug',
    '🥔' => 'aartappel',
    '🥕' => 'wortel',
    '🌽' => 'mielie',
    '🌶' => 'brandrissie',
    '🫑' => 'soetrissie',
    '🥒' => 'komkommer',
    '🥬' => 'groen blare',
    '🥦' => 'broccoli',
    '🧄' => 'knoffel',
    '🧅' => 'ui',
    '🥜' => 'grondboontjies',
    '🫘' => 'boontjies',
    '🌰' => 'kastaiing',
    '🫚' => 'gemmerwortel',
    '🫛' => 'ertjiepeul',
    '🫜' => 'wortelgroente',
    '🍞' => 'brood',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'platbrood',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'pannekoeke',
    '🧇' => 'wafel',
    '🧀' => 'kaaswiggie',
    '🍖' => 'vleis aan been',
    '🍗' => 'pluimveeboudjie',
    '🥩' => 'vleissnit',
    '🥓' => 'spek',
    '🍔' => 'hamburger',
    '🍟' => 'aartappelskyfies',
    '🍕' => 'pizza',
    '🌭' => 'worsbroodjie',
    '🥪' => 'toebroodjie',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'wrap',
    '🧆' => 'falafel',
    '🥚' => 'eier',
    '🍳' => 'gebakte eier in pan',
    '🥘' => 'vlak pan met kos',
    '🍲' => '‘n pot kos',
    '🫕' => 'fondue',
    '🥣' => 'bakkie met lepel',
    '🥗' => 'groenslaai',
    '🍿' => 'springmielies',
    '🧈' => 'botter',
    '🧂' => 'sout',
    '🥫' => 'geblikte kos',
    '🍱' => 'bentoboks',
    '🍘' => 'rysbeskuitjie',
    '🍙' => 'rysbal',
    '🍚' => 'gekookte rys',
    '🍛' => 'kerrierys',
    '🍜' => 'stomende bak',
    '🍝' => 'spaghetti',
    '🍠' => 'gebraaide patat',
    '🍢' => 'oden',
    '🍣' => 'soesji',
    '🍤' => 'gebraaide garnaal',
    '🍥' => 'viskoekie met spiraal',
    '🥮' => 'maankoek',
    '🍡' => 'dango',
    '🥟' => 'kluitjie',
    '🥠' => 'fortuinkoekie',
    '🥡' => 'wegneemeteboks',
    '🍦' => 'sagte roomys',
    '🍧' => 'ysskaafsels',
    '🍨' => 'roomys',
    '🍩' => 'oliebol',
    '🍪' => 'koekie',
    '🎂' => 'verjaardagkoek',
    '🍰' => 'broskoek',
    '🧁' => 'kolwyntjie',
    '🥧' => 'pastei',
    '🍫' => 'sjokoladestaaf',
    '🍬' => 'lekker',
    '🍭' => 'suiglekker',
    '🍮' => 'vla',
    '🍯' => 'heuningpot',
    '🍼' => 'bababottel',
    '🥛' => 'glas melk',
    '☕' => 'warm drankie',
    '🫖' => 'teepot',
    '🍵' => 'teekoppie sonder handvatsel',
    '🍶' => 'sake',
    '🍾' => 'bottel met prop wat uitskiet',
    '🍷' => 'wynglas',
    '🍸' => 'skemerkelkieglas',
    '🍹' => 'tropiese drankie',
    '🍺' => 'bierbeker',
    '🍻' => 'klinkende bierbekers',
    '🥂' => 'gesondheid',
    '🥃' => 'whiskeyglas',
    '🫗' => 'gooi vloeistof',
    '🥤' => 'beker met strooitjie',
    '🧋' => 'borreltee',
    '🧃' => 'koeldrankboksie',
    '🧉' => 'maté',
    '🧊' => 'ysblokkie',
    '🥢' => 'eetstokkies',
    '🍽' => 'bord met mes en vurk',
    '🍴' => 'mes en vurk',
    '🥄' => 'lepel',
    '🔪' => 'kombuismes',
    '🫙' => 'fles',
    '🏺' => 'amfoor',
    '🌍' => 'aardbol met Europa en Afrika',
    '🌎' => 'aardbol met Amerikas',
    '🌏' => 'aardbol met Asië en Australië',
    '🌐' => 'aardbol met kringlyne',
    '🗺' => 'wêreldkaart',
    '🗾' => 'kaart van Japan',
    '🧭' => 'kompas',
    '🏔' => 'berg met sneeu op',
    '⛰' => 'berg',
    '🛘' => 'grondstorting',
    '🌋' => 'vulkaan',
    '🗻' => 'berg foedji',
    '🏕' => 'kampeer',
    '🏖' => 'strand met sambreel',
    '🏜' => 'woestyn',
    '🏝' => 'woestyneiland',
    '🏞' => 'nasionale park',
    '🏟' => 'stadion',
    '🏛' => 'klassieke gebou',
    '🏗' => 'konstruksie',
    '🧱' => 'baksteenmuur',
    '🪨' => 'rots',
    '🪵' => 'hout',
    '🛖' => 'hut',
    '🏘' => 'huise',
    '🏚' => 'vervalle huis',
    '🏠' => 'huis',
    '🏡' => 'huis met tuin',
    '🏢' => 'kantoorgebou',
    '🏣' => 'Japanse poskantoor',
    '🏤' => 'poskantoor',
    '🏥' => 'hospitaal',
    '🏦' => 'bank',
    '🏨' => 'hotel',
    '🏩' => 'liefdeshotel',
    '🏪' => 'geriefswinkel',
    '🏫' => 'skool',
    '🏬' => 'afdelingswinkel',
    '🏭' => 'fabriek',
    '🏯' => 'Japanse kasteel',
    '🏰' => 'kasteel',
    '💒' => 'troue',
    '🗼' => 'Tokio-toring',
    '🗽' => 'vryheidstandbeeld',
    '⛪' => 'kerk',
    '🕌' => 'moskee',
    '🛕' => 'Hindoetempel',
    '🕍' => 'sinagoge',
    '⛩' => 'sjinto-altaar',
    '🕋' => 'Kaäba',
    '⛲' => 'fontein',
    '⛺' => 'tent',
    '🌁' => 'mistig',
    '🌃' => 'nag met sterre',
    '🏙' => 'stadslandskap',
    '🌄' => 'sonsopkoms oor berge',
    '🌅' => 'sonsopkoms',
    '🌆' => 'skemer stadslandskap',
    '🌇' => 'sonsondergang',
    '🌉' => 'brug in die aand',
    '♨' => 'warmbron',
    '🎠' => 'mallemeuleperd',
    '🛝' => 'glyplank',
    '🎡' => 'ferriswiel',
    '🎢' => 'tuimeltrein',
    '💈' => 'barbierpaal',
    '🎪' => 'sirkustent',
    '🚂' => 'lokomotief',
    '🚃' => 'treintrok',
    '🚄' => 'sneltrein',
    '🚅' => 'supersneltrein',
    '🚆' => 'trein',
    '🚇' => 'moltrein',
    '🚈' => 'smalspoortrein',
    '🚉' => 'stasie',
    '🚊' => 'trem',
    '🚝' => 'enkelspoortrein',
    '🚞' => 'bergtreinspoor',
    '🚋' => 'tremwa',
    '🚌' => 'bus',
    '🚍' => 'aankomende bus',
    '🚎' => 'trembus',
    '🚐' => 'minibus',
    '🚑' => 'ambulans',
    '🚒' => 'brandweerwa',
    '🚓' => 'polisiemotor',
    '🚔' => 'aankomende polisiemotor',
    '🚕' => 'taxi',
    '🚖' => 'aankomende taxi',
    '🚗' => 'motor',
    '🚘' => 'aankomende motor',
    '🚙' => 'ontspanningvoertuig',
    '🛻' => 'bakkie',
    '🚚' => 'afleweringswa',
    '🚛' => 'gelede voertuig',
    '🚜' => 'trekker',
    '🏎' => 'resiesmotor',
    '🏍' => 'motorfiets',
    '🛵' => 'bromponie',
    '🦽' => 'handgedrewe rolstoel',
    '🦼' => 'motoraangedrewe rolstoel',
    '🛺' => 'outoriksja',
    '🚲' => 'fiets',
    '🛴' => 'skopfiets',
    '🛹' => 'skaatsplank',
    '🛼' => 'Rolskaats',
    '🚏' => 'bushalte',
    '🛣' => 'snelweg',
    '🛤' => 'treinspoor',
    '🛢' => 'oliedrom',
    '⛽' => 'petrolpomp',
    '🛞' => 'wiel',
    '🚨' => 'polisiemotor se lig',
    '🚥' => 'horisontale verkeerslig',
    '🚦' => 'vertikale verkeerslig',
    '🛑' => 'stopteken',
    '🚧' => 'konstruksieteken',
    '⚓' => 'anker',
    '🛟' => 'boei',
    '⛵' => 'seilboot',
    '🛶' => 'kano',
    '🚤' => 'snelboot',
    '🛳' => 'passasierskip',
    '⛴' => 'veerboot',
    '🛥' => 'motorboot',
    '🚢' => 'skip',
    '✈' => 'vliegtuig',
    '🛩' => 'klein vliegtuig',
    '🛫' => 'vliegtuig styg op',
    '🛬' => 'vliegtuig land',
    '🪂' => 'valskerm',
    '💺' => 'sitplek',
    '🚁' => 'helikopter',
    '🚟' => 'hangspoor',
    '🚠' => 'bergkabelspoor',
    '🚡' => 'sweefspoor',
    '🛰' => 'satelliet',
    '🚀' => 'vuurpyl',
    '🛸' => 'vlieënde piering',
    '🛎' => 'klokkie vir hoteljoggie',
    '🧳' => 'bagasie',
    '⌛' => 'leë uurglas',
    '⏳' => 'uurglas met sand wat uitloop',
    '⌚' => 'horlosie',
    '⏰' => 'wekker',
    '⏱' => 'stophorlosie',
    '⏲' => 'afteller',
    '🕰' => 'kaggelklok',
    '🕛' => 'twaalfuur',
    '🕧' => 'halfeen',
    '🕐' => 'eenuur',
    '🕜' => 'halftwee',
    '🕑' => 'tweeuur',
    '🕝' => 'halfdrie',
    '🕒' => 'drieuur',
    '🕞' => 'halfvier',
    '🕓' => 'vieruur',
    '🕟' => 'halfvyf',
    '🕔' => 'vyfuur',
    '🕠' => 'halfses',
    '🕕' => 'sesuur',
    '🕡' => 'halfsewe',
    '🕖' => 'seweuur',
    '🕢' => 'halfagt',
    '🕗' => 'agtuur',
    '🕣' => 'halfnege',
    '🕘' => 'negeuur',
    '🕤' => 'halftien',
    '🕙' => 'tienuur',
    '🕥' => 'halfelf',
    '🕚' => 'elfuur',
    '🕦' => 'halftwaalf',
    '🌑' => 'nuwemaan',
    '🌒' => 'groeiende sekelmaan',
    '🌓' => 'eerstekwartiermaan',
    '🌔' => 'groeiende bolmaan',
    '🌕' => 'volmaan',
    '🌖' => 'afnemende bolmaan',
    '🌗' => 'laastekwartiermaan',
    '🌘' => 'afnemende sekelmaan',
    '🌙' => 'sekelmaan',
    '🌚' => 'nuwemaangesig',
    '🌛' => 'eerstekwartiermaan met gesig',
    '🌜' => 'laastekwartiermaan met gesig',
    '🌡' => 'termometer',
    '☀' => 'son',
    '🌝' => 'volmaan met gesig',
    '🌞' => 'son met gesig',
    '🪐' => 'planeet met ring om',
    '⭐' => 'ster',
    '🌟' => 'gloeiende ster',
    '🌠' => 'verskietende ster',
    '🌌' => 'melkweg',
    '☁' => 'wolk',
    '⛅' => 'son agter wolk',
    '⛈' => 'wolk met weerlig en reën',
    '🌤' => 'son agter klein wolk',
    '🌥' => 'son agter groot wolk',
    '🌦' => 'son agter wolk met reën',
    '🌧' => 'wolk met reën',
    '🌨' => 'wolk met sneeu',
    '🌩' => 'wolk met weerlig',
    '🌪' => 'tornado',
    '🌫' => 'mis',
    '🌬' => 'windgesig',
    '🌀' => 'sikloon',
    '🌈' => 'reënboog',
    '🌂' => 'opgevoude sambreel',
    '☂' => 'sambreel',
    '☔' => 'sambreel met reëndruppels',
    '⛱' => 'sambreel op die grond',
    '⚡' => 'hoogspanning',
    '❄' => 'sneeuvlokkie',
    '☃' => 'sneeuman',
    '⛄' => 'sneeuman sonder sneeu',
    '☄' => 'komeet',
    '🔥' => 'vuur',
    '💧' => 'druppel',
    '🌊' => 'brander',
    '🎃' => 'pampoenlantern',
    '🎄' => 'kersboom',
    '🎆' => 'vuurwerke',
    '🎇' => 'vonkstok',
    '🧨' => 'klapper',
    '✨' => 'vonke',
    '🎈' => 'ballon',
    '🎉' => 'partytjieklapper',
    '🎊' => 'konfettibal',
    '🎋' => 'tanabataboom',
    '🎍' => 'denneversiering',
    '🎎' => 'Japanse poppe',
    '🎏' => 'karpbanier',
    '🎐' => 'windklokkie',
    '🎑' => 'maankykseremonie',
    '🧧' => 'rooi koevert',
    '🎀' => 'lint',
    '🎁' => 'toegedraaide geskenk',
    '🎗' => 'herinneringslint',
    '🎟' => 'toegangskaartjie',
    '🎫' => 'kaartjie',
    '🎖' => 'militêre medalje',
    '🏆' => 'trofee',
    '🏅' => 'sportmedalje',
    '🥇' => 'goudmedalje',
    '🥈' => 'silwermedalje',
    '🥉' => 'bronsmedalje',
    '⚽' => 'sokkerbal',
    '⚾' => 'bofbal',
    '🥎' => 'sagtebal',
    '🏀' => 'basketbal',
    '🏐' => 'vlugbal',
    '🏈' => 'amerikaanse voetbal',
    '🏉' => 'rugbyvoetbal',
    '🎾' => 'tennis',
    '🥏' => 'diskus',
    '🎳' => 'kegelbal',
    '🏏' => 'krieket',
    '🏑' => 'hokkie',
    '🏒' => 'yshokkie',
    '🥍' => 'lacrosse',
    '🏓' => 'tafeltennis',
    '🏸' => 'pluimbal',
    '🥊' => 'bokshandskoen',
    '🥋' => 'gevegskunsuniform',
    '🥅' => 'doelhok',
    '⛳' => 'vlag in putjie',
    '⛸' => 'ysskaats',
    '🎣' => 'visstok',
    '🤿' => 'duikmasker',
    '🎽' => 'drafhemp',
    '🎿' => 'ski’s',
    '🛷' => 'slee',
    '🥌' => 'ysbal',
    '🎯' => 'kolskoot',
    '🪀' => 'jojo',
    '🪁' => 'vlieër',
    '🔫' => 'rewolwer',
    '🎱' => 'biljart',
    '🔮' => 'kristalbal',
    '🪄' => 'towerstaf',
    '🎮' => 'videospeletjie',
    '🕹' => 'speelstok',
    '🎰' => 'muntoutomaat',
    '🎲' => 'dobbelsteen',
    '🧩' => 'legkaartstuk',
    '🧸' => 'teddiebeer',
    '🪅' => 'piñata',
    '🪩' => 'diskobal',
    '🪆' => 'ineenpassende poppe',
    '♠' => 'skoppens',
    '♥' => 'harte',
    '♦' => 'diamante',
    '♣' => 'klawers',
    '♟' => 'skaakpion',
    '🃏' => 'joker',
    '🀄' => 'mahjong rooi draak',
    '🎴' => 'blomspeelkaarte',
    '🎭' => 'uitvoerende kunste',
    '🖼' => 'raam met prent',
    '🎨' => 'kunstenaarpalet',
    '🧵' => 'garing',
    '🪡' => 'naaldwerknaald',
    '🧶' => 'wol',
    '🪢' => 'knoop',
    '👓' => 'bril',
    '🕶' => 'sonbril',
    '🥽' => 'skermbril',
    '🥼' => 'laboratoriumjas',
    '🦺' => 'veiligheidsonderbaadjie',
    '👔' => 'das',
    '👕' => 't-hemp',
    '👖' => 'jean',
    '🧣' => 'serp',
    '🧤' => 'handskoene',
    '🧥' => 'jas',
    '🧦' => 'sokkies',
    '👗' => 'rok',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'eenstukswembroek',
    '🩲' => 'mansportswembroek',
    '🩳' => 'manswembroek',
    '👙' => 'bikini',
    '👚' => 'vroueklere',
    '🪭' => 'handwaaier wat vou',
    '👛' => 'beursie',
    '👜' => 'handsak',
    '👝' => 'palmtassie',
    '🛍' => 'winkelsakke',
    '🎒' => 'rugsak',
    '🩴' => 'tussentoonplakkie',
    '👞' => 'manskoen',
    '👟' => 'hardloopskoen',
    '🥾' => 'stapskoen',
    '🥿' => 'plat skoen',
    '👠' => 'hoëhakskoen',
    '👡' => 'vrouesandaal',
    '🩰' => 'balletskoene',
    '👢' => 'vrouestewel',
    '🪮' => 'haarnaald',
    '👑' => 'kroon',
    '👒' => 'vrouehoed',
    '🎩' => 'keil',
    '🎓' => 'gradeplegtigheidsmus',
    '🧢' => 'hardepuntpet',
    '🪖' => 'militêre helm',
    '⛑' => 'helm met wit kruis',
    '📿' => 'bidkrale',
    '💄' => 'lipstiffie',
    '💍' => 'ring',
    '💎' => 'edelsteen',
    '🔇' => 'luidspreker af',
    '🔈' => 'luidspreker sag',
    '🔉' => 'luidspreker medium volume',
    '🔊' => 'luidspreker hard',
    '📢' => 'aankondigingsluidspreker',
    '📣' => 'megafoon',
    '📯' => 'poshoring',
    '🔔' => 'klokkie',
    '🔕' => 'klok verbode',
    '🎼' => 'musiekbalk',
    '🎵' => 'musieknoot',
    '🎶' => 'musieknote',
    '🎙' => 'ateljeemikrofoon',
    '🎚' => 'vlakglyer',
    '🎛' => 'kontroleknoppe',
    '🎤' => 'mikrofoon',
    '🎧' => 'oorfoon',
    '📻' => 'radio',
    '🎷' => 'saxofoon',
    '🎺' => 'trompet',
    '🪊' => 'tromboon',
    '🪗' => 'trekklavier',
    '🎸' => 'kitaar',
    '🎹' => 'klawerbord',
    '🎻' => 'viool',
    '🪕' => 'banjo',
    '🥁' => 'trom',
    '🪘' => 'lang drom',
    '🪇' => 'marakkas',
    '🪈' => 'fluit',
    '🪉' => 'harp',
    '📱' => 'selfoon',
    '📲' => 'selfoon met pyl',
    '☎' => 'telefoon',
    '📞' => 'telefoongehoorstuk',
    '📟' => 'roeper',
    '📠' => 'faksmasjien',
    '🔋' => 'battery',
    '🪫' => 'lae battery',
    '🔌' => 'elektriese prop',
    '💻' => 'skootrekenaar',
    '🖥' => 'tafelrekenaar',
    '🖨' => 'drukker',
    '⌨' => 'sleutelbord',
    '🖱' => 'rekenaarmuis',
    '🖲' => 'stuurbal',
    '💽' => 'miniskyf',
    '💾' => 'slapskyf',
    '💿' => 'optiese skyf',
    '📀' => 'dvd',
    '🧮' => 'telraam',
    '🎥' => 'rolprentkamera',
    '🎞' => 'filmraampies',
    '📽' => 'rolprentprojektor',
    '🎬' => 'klapbord',
    '📺' => 'televisie',
    '📷' => 'kamera',
    '📸' => 'kamera met flits',
    '📹' => 'videokamera',
    '📼' => 'videokasset',
    '🔍' => 'vergrootglas na links',
    '🔎' => 'vergrootglas na regs',
    '🕯' => 'kers',
    '💡' => 'gloeilamp',
    '🔦' => 'flits',
    '🏮' => 'rooi papierlantern',
    '🪔' => 'Indiese olielamp',
    '📔' => 'notaboek met sieromslag',
    '📕' => 'geslote boek',
    '📖' => 'oop boek',
    '📗' => 'groen boek',
    '📘' => 'blou boek',
    '📙' => 'oranje boek',
    '📚' => 'boeke',
    '📓' => 'notaboek',
    '📒' => 'lêer',
    '📃' => 'bladsy met krul',
    '📜' => 'boekrol',
    '📄' => 'bladsy na bo',
    '📰' => 'koerant',
    '🗞' => 'opgerolde koerant',
    '📑' => 'boekmerkoortjies',
    '🔖' => 'boekmerk',
    '🏷' => 'etiket',
    '🪙' => 'muntstuk',
    '💰' => 'geldsak',
    '🪎' => 'skatkis',
    '💴' => 'jenbanknoot',
    '💵' => 'dollarbanknoot',
    '💶' => 'eurobanknoot',
    '💷' => 'pondbanknoot',
    '💸' => 'geld met vlerke',
    '💳' => 'kredietkaart',
    '🧾' => 'kwitansie',
    '💹' => 'grafiek met stygende jen',
    '✉' => 'koevert',
    '📧' => 'e-pos',
    '📨' => 'inkomende koevert',
    '📩' => 'koevert met pyl',
    '📤' => 'uitkassie',
    '📥' => 'inkassie',
    '📦' => 'pakket',
    '📫' => 'geslote posbus met vlag omhoog',
    '📪' => 'geslote posbus met vlag plat',
    '📬' => 'oop posbos met vlag omhoog',
    '📭' => 'oop posbus met vlag plat',
    '📮' => 'posbus',
    '🗳' => 'stembus met stembriefie',
    '✏' => 'potlood',
    '✒' => 'swart penpunt',
    '🖋' => 'vulpen',
    '🖊' => 'pen',
    '🖌' => 'verfkwas',
    '🖍' => 'vetkryt',
    '📝' => 'aantekening',
    '💼' => 'aktetas',
    '📁' => 'lêervouer',
    '📂' => 'oop lêervouer',
    '🗂' => 'kaartindeksverdelers',
    '📅' => 'kalender',
    '📆' => 'afskeurkalender',
    '🗒' => 'spiraalnotaboek',
    '🗓' => 'spiraalkalender',
    '📇' => 'kaartindeks',
    '📈' => 'grafiek wat styg',
    '📉' => 'grafiek wat daal',
    '📊' => 'staafgrafiek',
    '📋' => 'knypbord',
    '📌' => 'duimspyker',
    '📍' => 'ronde duimspyker',
    '📎' => 'skuifspeld',
    '🖇' => 'ingehaakte skuifspeld',
    '📏' => 'liniaal',
    '📐' => 'driekantliniaal',
    '✂' => 'skêr',
    '🗃' => 'kaartlêerboks',
    '🗄' => 'lêerkabinet',
    '🗑' => 'snippermandjie',
    '🔒' => 'slot',
    '🔓' => 'oop slot',
    '🔏' => 'slot met pen',
    '🔐' => 'toe slot met sleutel',
    '🔑' => 'sleutel',
    '🗝' => 'ou sleutel',
    '🔨' => 'hamer',
    '🪓' => 'byl',
    '⛏' => 'pik',
    '⚒' => 'hamer en pik',
    '🛠' => 'hamer en moersleutel',
    '🗡' => 'dolk',
    '⚔' => 'gekruiste swaarde',
    '💣' => 'bom',
    '🪃' => 'boemerang',
    '🏹' => 'pyl en boog',
    '🛡' => 'skild',
    '🪚' => 'houtsaag',
    '🔧' => 'moersleutel',
    '🪛' => 'skroewedraaier',
    '🔩' => 'bout en moer',
    '⚙' => 'rat',
    '🗜' => 'klamp',
    '⚖' => 'weegskaal',
    '🦯' => 'gidsstok',
    '🔗' => 'skakel',
    '⛓' => 'kettings',
    '🪝' => 'hoek',
    '🧰' => 'gereedskaptrommel',
    '🧲' => 'magneet',
    '🪜' => 'leer',
    '🪏' => 'graaf',
    '⚗' => 'alembiek',
    '🧪' => 'proefbuis',
    '🧫' => 'petribakkie',
    '🧬' => 'dna',
    '🔬' => 'mikroskoop',
    '🔭' => 'teleskoop',
    '📡' => 'satellietantenna',
    '💉' => 'inspuiting',
    '🩸' => 'bloeddruppel',
    '💊' => 'pil',
    '🩹' => 'plakpleister',
    '🩼' => 'kruk',
    '🩺' => 'stetoskoop',
    '🩻' => 'x-straal',
    '🚪' => 'deur',
    '🛗' => 'hysbak',
    '🪞' => 'spieël',
    '🪟' => 'venster',
    '🛏' => 'bed',
    '🛋' => 'rusbank en lamp',
    '🪑' => 'stoel',
    '🚽' => 'toilet',
    '🪠' => 'druksuier',
    '🚿' => 'stort',
    '🛁' => 'bad',
    '🪤' => 'muisvalletjie',
    '🪒' => 'skeermes',
    '🧴' => 'lyfroombottel',
    '🧷' => 'haakspeld',
    '🧹' => 'besem',
    '🧺' => 'mandjie',
    '🧻' => 'papierrol',
    '🪣' => 'emmer',
    '🧼' => 'seep',
    '🫧' => 'borrels',
    '🪥' => 'tandeborsel',
    '🧽' => 'spons',
    '🧯' => 'vuurblusser',
    '🛒' => 'winkeltrollie',
    '🚬' => 'rook',
    '⚰' => 'doodskis',
    '🪦' => 'grafsteen',
    '⚱' => 'begrafniskruik',
    '🧿' => 'nazar-gelukbringer',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'plakkaat',
    '🪪' => 'id-kaart',
    '🏧' => 'OTM-teken',
    '🚮' => '"vullis in drom"-teken',
    '🚰' => 'drinkbare water',
    '♿' => 'rolstoel-simbool',
    '🚹' => 'manskleedkamer',
    '🚺' => 'vrouekleedkamer',
    '🚻' => 'kleedkamer',
    '🚼' => 'babasimbool',
    '🚾' => 'WC',
    '🛂' => 'paspoortkontrole',
    '🛃' => 'doeane',
    '🛄' => 'bagasiesaal',
    '🛅' => 'bagasiesluitkas',
    '⚠' => 'waarskuwing',
    '🚸' => 'kinders stap oor',
    '⛔' => 'geen toegang',
    '🚫' => 'verbode',
    '🚳' => 'fietse verbode',
    '🚭' => 'rook verbode',
    '🚯' => 'moenie rommel strooi nie',
    '🚱' => 'niedrinkbare water',
    '🚷' => 'voetgangers verbode',
    '📵' => 'selfone verbode',
    '🔞' => 'jonger as agtien verbode',
    '☢' => 'radioaktief',
    '☣' => 'biogevaar',
    '⬆' => 'pyl na bo',
    '↗' => 'pyl na regs bo',
    '➡' => 'pyl na regs',
    '↘' => 'pyl na regs onder',
    '⬇' => 'pyl na onder',
    '↙' => 'pyl na links onder',
    '⬅' => 'pyl na links',
    '↖' => 'pyl na links bo',
    '↕' => 'pyl op en af',
    '↔' => 'pyl links en regs',
    '↩' => 'pyl na regs buig na links',
    '↪' => 'pyl na links buig na regs',
    '⤴' => 'pyl na regs buig op',
    '⤵' => 'pyl na regs buig af',
    '🔃' => 'kloksgewyse vertikale pyle',
    '🔄' => 'knoppie vir teenkloksgewyse pyle',
    '🔙' => 'terugpyl',
    '🔚' => 'eindpyl',
    '🔛' => 'aan!-pyl',
    '🔜' => 'binnekortpyl',
    '🔝' => 'toppyl',
    '🛐' => 'plek van aanbidding',
    '⚛' => 'atoomsimbool',
    '🕉' => 'om',
    '✡' => 'Dawidster',
    '☸' => 'dharmawiel',
    '☯' => 'jin-jang',
    '✝' => 'Latynse kruis',
    '☦' => 'ortodokse kruis',
    '☪' => 'ster en sekelmaan',
    '☮' => 'vredesimbool',
    '🕎' => 'menora',
    '🔯' => 'sespuntster met kol',
    '🪯' => 'khanda',
    '♈' => 'Ram-sterrebeeld',
    '♉' => 'Bul-sterrebeeld',
    '♊' => 'Tweeling-sterrebeeld',
    '♋' => 'Kreef-sterrebeeld',
    '♌' => 'Leeu-sterrebeeld',
    '♍' => 'Maagd-sterrebeeld',
    '♎' => 'Weegskaal-sterrebeeld',
    '♏' => 'Skerpioen-sterrebeeld',
    '♐' => 'Boogskutter-sterrebeeld',
    '♑' => 'Steenbok-sterrebeeld',
    '♒' => 'Waterdraer-sterrebeeld',
    '♓' => 'Visse-sterrebeeld',
    '⛎' => 'Slangdraer-sterrebeeld',
    '🔀' => 'skommelsnitteknoppie',
    '🔁' => 'herhaalknoppie',
    '🔂' => 'herhaalsnitknoppie',
    '▶' => 'speelknoppie',
    '⏩' => 'spoelvorentoe-knoppie',
    '⏭' => 'volgendesnit-knoppie',
    '⏯' => 'speel-of-onderbreekknoppie',
    '◀' => 'speelterug-knoppie',
    '⏪' => 'spoelterug-knoppie',
    '⏮' => 'vorigesnit-knoppie',
    '🔼' => 'opknoppie',
    '⏫' => 'vinnig-op-knoppie',
    '🔽' => 'afknoppie',
    '⏬' => 'vinnig-af-knoppie',
    '⏸' => 'onderbreekknoppie',
    '⏹' => 'stopknoppie',
    '⏺' => 'opneemknoppie',
    '⏏' => 'uitskietknoppie',
    '🎦' => 'bioskoop',
    '🔅' => 'verdofknoppie',
    '🔆' => 'helderknoppie',
    '📶' => 'antennastawe',
    '🛜' => 'draadloos',
    '📳' => 'vibrasiemodus',
    '📴' => 'selfoon af',
    '♀' => 'vroulik-teken',
    '♂' => 'manlik-teken',
    '⚧' => 'transgendersimbool',
    '✖' => 'maal',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'deel',
    '🟰' => 'gelykaanteken',
    '♾' => 'oneindigheid',
    '‼' => 'dubbeluitroepteken',
    '⁉' => 'uitroep-vraagteken',
    '❓' => 'rooi vraagteken',
    '❔' => 'wit vraagteken',
    '❕' => 'wit uitroepteken',
    '❗' => 'rooi uitroepteken',
    '〰' => 'golfstreep',
    '💱' => 'wisselkoers',
    '💲' => 'dik dollarteken',
    '⚕' => 'mediese simbool',
    '♻' => 'herwinningsimbool',
    '⚜' => 'fleur de lis',
    '🔱' => 'drietandvurkembleem',
    '📛' => 'naametiket',
    '🔰' => 'japanse beginnersimbool',
    '⭕' => 'hol rooi sirkel',
    '✅' => 'regmerkknoppie',
    '☑' => 'merkblokkie met regmerk',
    '✔' => 'regmerk',
    '❌' => 'kruismerkie',
    '❎' => 'kruismerkknoppie',
    '➰' => 'krullus',
    '➿' => 'dubbelkrullus',
    '〽' => 'stembeginteken',
    '✳' => 'agtspeekasterisk',
    '✴' => 'agtpuntster',
    '❇' => 'vonkster',
    '™' => 'handelmerk',
    '🫟' => 'spat',
    '🔠' => 'invoer- Latynse bokas',
    '🔡' => 'invoer- Latynse onderkas',
    '🔢' => 'invoersyfers',
    '🔣' => 'invoersimbole',
    '🔤' => 'invoer- Latynse letters',
    '🅰' => 'A-knopie (bloedgroep)',
    '🆎' => 'AB-knopie (bloedgroep)',
    '🅱' => 'B-knopie (bloedgroep)',
    '🆑' => 'CL-knopie',
    '🆒' => 'COOL-knopie',
    '🆓' => 'FREE-knopie',
    'ℹ' => 'inligting',
    '🆔' => 'ID-knopie',
    'Ⓜ' => 'M in sirkel',
    '🆕' => 'NEW-knopie',
    '🆖' => 'NG-knopie',
    '🅾' => 'O-knopie (bloedgroep)',
    '🆗' => 'OK-knopie',
    '🅿' => 'P-knopie',
    '🆘' => 'SOS-knopie',
    '🆙' => 'UP!-knopie',
    '🆚' => 'VS-knopie',
    '🈁' => 'Japannese “hier”-knopie',
    '🈂' => 'Japannese “diensfooi”-knopie',
    '🈷' => 'Japannese “maandrekening”-knoppie',
    '🈶' => 'Japannese “nie gratis nie”-knoppie',
    '🈯' => 'Japannese “gereserveer”-knoppie',
    '🉐' => 'Japannese “winskopie”-knoppie',
    '🈹' => 'Japannese “afslag”-knoppie',
    '🈚' => 'Japannese “gratis”-knoppie',
    '🈲' => 'Japannese “verbode”-knoppie',
    '🉑' => 'Japannese “aanvaarbaar”-knoppie',
    '🈸' => 'Japannese "aansoek"-knoppie',
    '🈴' => 'Japannese "slaagsyfer"-knoppie',
    '🈳' => 'Japannese "vakant"-knoppie',
    '㊗' => 'Japannese "veels geluk"-knoppie',
    '㊙' => 'Japannese "geheim"-knoppie',
    '🈺' => 'Japannese "oop vir besigheid"-knoppie',
    '🈵' => 'Japannese "geen vakant"-knoppie',
    '🔴' => 'rooi sirkel',
    '🟠' => 'oranje sirkel',
    '🟡' => 'geel sirkel',
    '🟢' => 'groen sirkel',
    '🔵' => 'blou sirkel',
    '🟣' => 'pers sirkel',
    '🟤' => 'bruin sirkel',
    '⚫' => 'swart sirkel',
    '⚪' => 'wit sirkel',
    '🟥' => 'rooi vierkant',
    '🟧' => 'oranje vierkant',
    '🟨' => 'geel vierkant',
    '🟩' => 'groen vierkant',
    '🟦' => 'blou vierkant',
    '🟪' => 'pers vierkant',
    '🟫' => 'bruin vierkant',
    '⬛' => 'groot swart vierkant',
    '⬜' => 'groot wit vierkant',
    '◼' => 'swart mediumvierkant',
    '◻' => 'wit mediumvierkant',
    '◾' => 'swart mediumklein vierkant',
    '◽' => 'wit mediumklein vierkant',
    '▪' => 'klein swart vierkant',
    '▫' => 'klein wit vierkant',
    '🔶' => 'groot oranje diamant',
    '🔷' => 'groot blou diamant',
    '🔸' => 'klein oranje diamant',
    '🔹' => 'klein blou diamant',
    '🔺' => 'rooi driehoek wat op wys',
    '🔻' => 'rooi driehoek wat af wys',
    '💠' => 'diamant met ‘n kol',
    '🔘' => 'radioknoppie',
    '🔳' => 'wit vierkant-knoppie',
    '🔲' => 'swart vierkant-knoppie',
    '🏁' => 'ruitvlag',
    '🚩' => 'driehoekige vlag',
    '🎌' => 'gekruiste vlae',
    '🏴' => 'swart vlag',
    '🏳' => 'wit vlag',
];
